<?php
namespace Elementor;

class Related_Posts extends Widget_Base {
	
	public function get_name() {
		return 'related-post';
	}
	
	public function get_title() {
		return  __( 'Related Posts', 'sigma-theme' );
	}
	
	public function get_icon() {
		return 'eicon-gallery-grid';
	}
	
	public function get_categories() {
		return [ 'Sigma-Single' ];
	}
    
	protected function _register_controls() {
		
        $this->start_controls_section(
        	'section_content_style',
        	[
				'label' => __( 'Related Posts', 'sigma-theme' ),
        		'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        	]
        );	 
		
		$this->add_control(
			'active_related',
			[
				'label'   => esc_html__( 'Active Related Post', 'sigma-theme' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

 		$this->add_control(
			'related_title',
			[
				'label' => __( 'Related Posts Title', 'sigma-theme' ),
				'label_block' => true,
				'type' => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter Related Posts Title', 'sigma-theme' ),
                'condition' => [
                    'active_related' => 'yes',
                ],      	                
                'default' => __( 'Be sure to read the following:', 'sigma-theme' ),
                'condition' => [ 'active_related' => 'yes', ],
			]
		);

		$this->add_control(
			'number_post',
			[
				'label' => __( 'Number Of Related Post', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 30,
				'step' => 1,
				'default' => 12,
				'condition' => [ 'active_related' => 'yes', ],
			]
		);
		
        $this->end_controls_section();       

		
        $this->start_controls_section(
        	'style_section',
        	[
				'label' => __( 'Related Posts', 'sigma-theme' ),
        		'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        	]
        );	 

		$this->add_control(
			'related_post_title_bg_color',
			[
				'label' => __( 'Related Post Title Background Color', 'sigma-theme' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
					],
				'selectors' => [
					'{{WRAPPER}} .ralated-post h4' => 'background: {{VALUE}}',
				],			
				'condition' => [ 'active_related' => 'yes', ],
				'default' => '#fff'
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'related_post_title_type',
				'label' => __( 'Related Post Title Typography', 'sigma-theme' ),
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .ralated-post h4',
				'condition' => [ 'active_related' => 'yes', ],
			]
		);
		
		$this->add_control(
			'related_post_title_color',
			[
				'label' => __( 'Related Post Title Color', 'sigma-theme' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .ralated-post h4' => 'color: {{VALUE}}',
				],			
				'default' => '#333333',
				'condition' => [ 'active_related' => 'yes', ],
			]
		);

		$this->add_control(
			'related_post_title_border_color',
			[
				'label' => __( 'Related Post Title Border Color', 'sigma-theme' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .ralated-post h4' => 'border-right: 3px solid {{VALUE}}',
				],			
				'default' => '#ff5721',
				'condition' => [ 'active_related' => 'yes', ],
			]
		);

		$this->add_control(
			'related_post_bg',
			[
				'label' => __( 'Related Post Background Color', 'sigma-theme' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
					],
				'selectors' => [
					'{{WRAPPER}} div#related ' => 'background: {{VALUE}}',
				],			
				'condition' => [ 'active_related' => 'yes', ],
				'default' => '#fff'
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'relate_post_bx_shdw',
				'label' => __( 'Box Shadow', 'sigma-theme' ),
				'selector' => '{{WRAPPER}} .ralated-post-elementor',
				'condition' => [ 'active_related' => 'yes', ],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Border', 'sigma-theme' ),
				'selector' => '{{WRAPPER}} .ralated-post-elementor',
                'condition' => [ 'active_related' => 'yes', ],					
			]
		);
		
        $this->end_controls_section();       
        
	}

    protected function render() {
        $settings = $this->get_settings_for_display();
        $template = \SigmaCore\SigmaTemplateBuilder\SigmaTemplateBuilder::GetInstance();
        if($template->IsRealRender())
        {
            echo'<div class="darkeble ralated-post ralated-post-elementor">
            <h4>'.$settings['related_title'].'</h4>
             <div id="related" class="owl-carousel owl-theme"> '?>
                
                <?php $related=get_posts(array('category__in'=>wp_get_post_categories($template->GetRelatedPostId()),
                'orderby'=>'rand','numberposts'=>$settings['number_post'],'post__not_in'=>array($template->GetRelatedPostId())));
                if($related) foreach($related as $post){ setup_postdata($post);
                $post_views = get_post_meta($template->GetRelatedPostId(),"post_views_count",true);
                $post_comment = $template->GetRelatedPostField("comment_count");                
                ?>
            <?php echo'<div class="col-lg-12 last-posts last-posts-elementor">
            <a href="'. get_the_permalink() . '"> '. get_the_post_thumbnail(get_the_ID(),'index') .'</a>
                        <div class="post-meta post-meta-elementor">
                        <div class="title-post"><h2><a href="'. get_the_permalink() .'">'. get_the_title() .'</a></h2></div>
                        <p class="elementor-post-related-dec">'. wp_trim_words( get_the_content(), 30, '...' ) .'</p>
                    <div class="row">
                    <div class="cat-post col-lg-6 col-8"><i class="fa fa-folder"></i>'.$post_comment.' دیدگاه </div>
                    <div class="cat-post col-lg-6 col-4"><i class="fa fa-eye"></i>'.$post_views. ' بازدید </div></div>
                    <div class="post-more-btn-ralated"><a class="more-post" href="'. get_the_permalink() .'" target="_blank"><i class="fa fa-list-ul"></i>توضیحات بیشتر</a></div></div></div>'?>
            <?php
                } wp_reset_postdata(); ?>
            <?php echo'</div>
            </div>';
        }
        else
        {
            
            global $sigma;
            get_template_part($sigma['post_style_loop'] );
    
        }
    }
}