<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "sigma";

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('sigma/opt_name', $opt_name);

/*
		 *
		 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
		 *
		 */

$sampleHTML = '';
if (file_exists(dirname(__FILE__) . '/info-html.html')) {
    Redux_Functions::initWpFilesystem();

    global $wp_filesystem;

    $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
}

// Background Patterns Reader
$sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
$sample_patterns_url = ReduxFramework::$_url . '../sample/patterns/';
$sample_patterns = array();

if (is_dir($sample_patterns_path)) {

    if ($sample_patterns_dir = opendir($sample_patterns_path)) {
        $sample_patterns = array();

        while (($sample_patterns_file = readdir($sample_patterns_dir)) !== false) {

            if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                $name = explode('.', $sample_patterns_file);
                $name = str_replace('.' . end($name), '', $sample_patterns_file);
                $sample_patterns[] = array(
                    'alt' => $name,
                    'img' => $sample_patterns_url . $sample_patterns_file
                );
            }
        }
    }
}

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => __('تنظیمات سیگما', 'redux-framework-demo'),
    'page_title' => __('تنظیمات سیگما', 'redux-framework-demo'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,        // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => false,
    // Enable basic customizer support
    //'open_expanded'     => true,        // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,        // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',       // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for button_set2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);
// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$args['admin_bar_links'][] = array(
    'id' => 'redux-docs',
    'href' => 'http://doc.hamkarwp.com/sigma/',
    'title' => __('پایگاه دانش سیگما', 'redux-framework-demo'),
);

$args['admin_bar_links'][] = array(
    //'id'    => 'redux-support',
    'href' => 'https://zhaket.com/product/sigma-wordpress-theme/support',
    'title' => __('پشتیبانی همکار وردپرس', 'redux-framework-demo'),
);

$args['admin_bar_links'][] = array(
    'id' => 'redux-extensions',
    'href' => 'http://hamkarwp.com',
    'title' => __('وب سایت توسعه دهنده', 'redux-framework-demo'),
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
    'url' => 'https://www.facebook.com/pages/hamkarwp/243141545850368',
    'title' => 'Like us on Facebook',
    'icon' => 'el el-facebook'
);
$args['share_icons'][] = array(
    'url' => 'http://twitter.com/hamkarwp',
    'title' => 'Follow us on Twitter',
    'icon' => 'el el-twitter'
);
$args['share_icons'][] = array(
    'url' => 'http://www.linkedin.com/company/hamkarwp',
    'title' => 'Find us on LinkedIn',
    'icon' => 'el el-linkedin'
);

// Panel Intro text -> before the form
if (!isset($args['global_variable']) || $args['global_variable'] !== false) {
    if (!empty($args['global_variable'])) {
        $v = $args['global_variable'];
    } else {
        $v = str_replace('-', '_', $args['opt_name']);
    }
    $args['intro_text'] = sprintf(__('intro text', 'redux-framework-demo'), $v);
} else {
    $args['intro_text'] = __('<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo');
}

// Add content after the form.
$args['footer_text'] = __('تمامی حقوق قالب سیگما پلاس برای مجموعه همکار وردپرس محفوظ است.', 'redux-framework-demo');
//echo '<div class="fix-disimce"><a id="remove" class="is-dismissible-alert"> مشاهده تنظیمات </a><a href="http://doc.hamkarwp.com/sigma/faq-sigma/training-video-works-with-the-new-features-of-sigma-plus/" target="_blank" class="go-video-alert"> مشاهده ویدئو آموزشی </a></div>';
Redux::setArgs($opt_name, $args);

/*
		 * ---> END ARGUMENTS
		 */


/*
		 * ---> START HELP TABS
		 */

$tabs = array(
    array(
        'id' => 'redux-help-tab-1',
        'title' => __('راهنمای شماره یک', 'redux-framework-demo'),
        'content' => __('<p>با انتخاب هر طرح تنظیمات مربوطه نمایش داده شده و آن طرح به عنوان استایل پیشفرض انتخاب میشود!</p>', 'redux-framework-demo')
    ),
    array(
        'id' => 'redux-help-tab-2',
        'title' => __('راهنمای شماره دو', 'redux-framework-demo'),
        'content' => __('<p>تنظیمات قالب سیگما پلاس قابل انتقال به قالب دیگر نمیباشد.</p>', 'redux-framework-demo')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = __('<p>این قالب در وب سایت معتبر ژاکت به فروش میرسد!</p>', 'redux-framework-demo');
Redux::setHelpSidebar($opt_name, $content);


/*
		 * <--- END HELP TABS
		 */


/*
		 *
		 * ---> START SECTIONS
		 *
		 */

/*

			As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


		 */

// -> START Generan Setting

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات همگانی',
    'id' => 'generan-setting',
    'customizer_width' => '700px',
));
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات اولیه',
    'subsection' => true,
    'id' => 'public_options',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_02',
            'title' => 'تنظیمات همگانی',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true
        ),
        array(
            'id' => 'dark_version',
            'type' => 'button_set',
            'title' => 'نسخه تیره / شب',
            'subtitle' => 'از این قسمت میتوانید نسخه تیره / شب را برای کل سایت خود خود فعال یا غیرفعال نمایید.',
            'default' => 'light-sigma',
            'options' => array(
                'dark-sigma' => 'فعال',
                'light-sigma' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'dark_version_img_filter',
            'type' => 'button_set',
            'title' => 'فیلتر تصاویر در نسخه تیره',
            'subtitle' => 'در صورت فعال سازی این گزینه تصاویر در نسخه تیره بصورت سیاه و سفید نمایش داده خواهد شد!',
            'default' => 'grayscale(100%) !important',
            'options' => array(
                'grayscale(100%) !important' => 'فعال',
                'none !important' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'socials_box',
            'type' => 'button_set',
            'title' => 'دکمه آیکون های اجتماعی ثابت',
            'subtitle' => 'از این بخش میتوانید آیکون ثابت سمت چپ سایت را مدیریت کنید.!',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'social_style',
            'type' => 'select',
            'required' => array('socials_box', '=', 'inherit'),
            'title' => 'انتخاب طرح آیکون های ثابت شبکه های اجتماعی  ',
            'subtitle' => 'یک طرح از بین طرح های موجود برای آیکون های ثابت شبکه های اجتماعی سایت خود انتخاب کنید..',
            'options' => array(
                'template-part/fix-bars' => 'طرح پیشفرض',
                'template-part/fix-bars-light' => 'طرح متریال',
            ),
            'default' => 'template-part/fix-bars-light'
        ),        
        array(
            'id' => 'cart_active',
            'type' => 'button_set',
            'title' => 'آیکون سبد خرید  ',
            'subtitle' => 'از این بخش میتوانید آیکون ثابت سبد خرید را مدیریت کنید.!',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'cart_style',
            'required' => array('cart_active', '=', 'inherit'),
            'type' => 'select',
            'title' => 'انتخاب طرح سبد خرید ثابت',
            'subtitle' => 'یک طرح از بین طرح های موجود برای سبد خرید ثابت سایت خود انتخاب کنید..',
            'options' => array(
                'template-part/cart-fix' => 'طرح پیشفرض',
                'template-part/cart-fix-light' => 'طرح متریال',
            ),
            'default' => 'template-part/cart-fix-light'
        ),
        array(
            'id' => 'cart_fix_bg_style01',
            'title' => 'رنگ پس زمینه آیکون سبد خرید',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'subtitle' => 'رنگ مورد نظر را برای پس زمینه آیکون سبد خرید استایل پیشفرض انتخاب کنید!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#0da3f4',),
        ),
        array(
            'id' => 'cart_fix_count_style01',
            'title' => 'رنگ پس زمینه تعداد محصول',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'subtitle' => 'رنگ پس زمینه تعداد محصول موجود در سبد خرید را انتخاب کنید!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#0b7cb9',),
        ),
        array(
            'id' => 'cart_fix_color_style01',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'رنگ آیکون و تعداد محصول',
            'subtitle' => 'رنگ آیکون تعداد محصول موجود در سبد خرید را از انجام مشخص کنید!',
            'default' => '#FFFFFF',
        ),
        array(
            'id' => 'cart_fix_count_style022',
            'title' => 'رنگ پس زمینه تعداد محصول',
            'required' => array('cart_style', '=', 'template-part/cart-fix-light'),
            'subtitle' => 'رنگ پس زمینه تعداد محصول موجود در سبد خرید را انتخاب کنید!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ff5722',),
        ),
        array(
            'id' => 'cart_fix_color_style02',
            'required' => array('cart_style', '=', 'template-part/cart-fix-light'),
            'type' => 'color',
            'title' => 'رنگ تعداد محصول',
            'subtitle' => 'رنگ تعداد محصول موجود در سبد خرید را از انجام مشخص کنید!',
            'default' => '#FFFFFF',
        ),
        array(
            'id' => 'cart_fix_count_style02',
            'title' => 'رنگ حاشیه و آیکون سبد خرید',
            'required' => array('cart_style', '=', 'template-part/cart-fix-light'),
            'subtitle' => 'رنگ حاشبه آیکون سبد خرید را انتخاب کنید!',
            'type' => 'color',
            'default' => '#ff5722',
        ),

        array(
            'id' => 'cart_poss_fix',
            'required' => array('cart_active', '=', 'inherit'),
            'title' => 'موقعیت سبد خرید ثابت',
            'subtitle' => 'موقعیت سبد خرید ثابت را انتخاب کنید..',
            'type' => 'button_set',
            'default' => 'right',
            'options' => array(
                'left' => 'پایین چپ',
                'right' => 'پایین راست',
            ),
        ),
        array(
            'id' => 'ajax_login_bg',
            'title' => 'پس زمینه فرم ایجکس ورود و عضویت',
            'subtitle' => 'از این قسمت میتوانید تصویر فرم ورود و عضویت ایجکس را تغییر دهید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-color' => false,
            'background-attachment' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/bg_login_popup.png'
            )
        ),
        array(
            'id' => 'link_color',
            'type' => 'color',
            'title' => 'رنگ لینک های سایت',
            'class' => 'dnone_v5',
            'subtitle' => 'رنگ مورد نظر برای تمامی لینک های سایت خود را مشخص کنید.. رنگ لینک های منوها و فوتر ها که تنظیمات رنگ بندی جدا دارند از این قسمت تغییر پیدا نمیکند.',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'body_back',
            'title' => 'رنگ پس زمینه سایت',
            'subtitle' => 'رنگ پس زمینه سایت را انتخاب کنید.. این رنگ تنها در حالت باکسی قابل تنظیم است.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fafafc',),
        ),
        array(
            'id' => 'backtop_show',
            'type' => 'button_set',
            'title' => 'نمایش دکمه بازگشت به بالا',
            'default' => 'inherit',
            'class' => 'dnone_v5',
            'subtitle' => 'از این بخش میتوانید نمایش دکمه بازگشت به بالای سایت را مدیریت کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'role_comment_pro',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'نمایش قوانین ارسال دیدگاه',
            'subtitle' => 'قوانین ارسال دیدگاه در پایین توضیحات مطالب و محصولات نمایش داده شود یا خیر؟.',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'role_post_content',
            'title' => 'محتوای قوانین دیدگاه ها',
            'subtitle' => 'محتوای قوانین ارسال دیدگاه ها در پایین نوشته ها و محصولات سایت نمایش داده میشود را تغییر دهید.!',
            'required' => array('role_comment_pro', '=', 'inherit'),
            'default' => '<h4>قوانین ارسال دیدگاه در سایت</h4>
	<ul class="before-note">
		<li class="before-comment"><i class="fal fa-caret-left"></i> چنانچه دیدگاهی توهین آمیز باشد و متوجه اشخاص مدیر، نویسندگان و سایر کاربران باشد تایید نخواهد شد.</li>
		<li class="before-comment"><i class="fal fa-caret-left"></i> چنانچه دیدگاه شما جنبه ی تبلیغاتی داشته باشد تایید نخواهد شد.</li>
		<li class="before-comment"><i class="fal fa-caret-left"></i>  چنانچه از لینک سایر وبسایت ها و یا وبسایت خود در دیدگاه استفاده کرده باشید تایید نخواهد شد.</li>
		<li class="before-comment"><i class="fal fa-caret-left"></i>  		چنانچه در دیدگاه خود از شماره تماس، ایمیل و آیدی تلگرام استفاده کرده باشید تایید نخواهد شد.</li>
		<li class="before-comment"><i class="fal fa-caret-left"></i>  چنانچه دیدگاهی بی ارتباط با موضوع آموزش مطرح شود تایید نخواهد شد.</li>
	</ul>',
            'type' => 'editor',
        ),
        array(
            'id' => 'share_posts',
            'default' => 'inherit',
            'type' => 'button_set',
            'title' => 'نمایش دکمه های اشتراک گذاری مطالب',
            'subtitle' => 'دکمه اشتراک گذاری در پایین جزییات محصول و نوشته ها نمایش داده میشود.',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
    ),

));
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات اعلان',
    'subsection' => true,
    'id' => 'alert_options',
    'class' => 'dnone_v5',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_alert_options',
            'title' => 'تنظیمات اعلان',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'alert_content_active',
            'type' => 'button_set',
            'default' => 'none',
            'title' => 'فعال سازی اعلان بالای سایت',
            'subtitle' => 'برای هر کاربر در صورت بسته شدن هر 72 ساعت نمایش داده خواهد شد.',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'alert_content_active_mobile',
            'type' => 'button_set',
            'title' => 'اعلان سایت در موبایل',
            'subtitle' => 'از این بخش میتوانید اعلان در نسخه ریسپانسیو را مدیریت کنید.!',
            'default' => 'none',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'alert_content',
            'title' => 'محتوای اعلان',
            'subtitle' => 'محتوای مورد نظر را برای متن اعلان بالای سایت را در این بخش وارد کنید.!',
            'default' => 'شما در حال مشاهده پیش نمایش قالب ایرانی سیگما پلاس هستید ، تمامی محصولات بصورت دمو میباشد.',
            'type' => 'textarea',
            'required' => array('alert_content_active', '=', 'inherit'),
        ),
        array(
            'id' => 'alert_btn_active',
            'type' => 'button_set',
            'required' => array('alert_content_active', '=', 'inherit'),
            'title' => 'دکمه اعلان',
            'subtitle' => 'از این قسمت میتوانید نمایش دکمه اعلان را فعال یا غیرفعال کنید.',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'alert_btn_text',
            'type' => 'text',
            'title' => 'متن دکمه اعلان ',
            'subtitle' => 'متن مورد نظر برای دکمه اعلان را در این بخش وارد کنید.!',
            'default' => 'اطلاعات بیشتر و خرید',
            'required' => array('alert_content_active', '=', 'inherit'),
            'required' => array('alert_btn_active', '=', 'inline'),
        ),
        array(
            'id' => 'alert_btn_link',
            'title' => 'لینک دکمه اعلان',
            'subtitle' => 'لینک مورد نظر برای دکمه اعلان را در این بخش وارد کنید.!',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://zhaket.com/product/sigma-wordpress-theme/',
            'required' => array('alert_content_active', '=', 'inherit'),
            'required' => array('alert_btn_active', '=', 'inline'),

        ),
        array(
            'id' => 'alert_btn_link_target',
            'title' => 'هدف لینک دکمه اعلان',
            'subtitle' => 'تارگت (هدف ) لینک را مشخص کنید.. پیش فرض : در پنجره جدید',
            'type' => 'button_set',
            'default' => '_blank',
            'required' => array('alert_content_active', '=', 'inherit'),

            'options' => array(
                '_blank' => 'در پنجره جدید',
                '_self' => 'در همان پنجره',

            ),
        ),
        array(
            'id' => 'alert_bg',
            'title' => 'رنگ پس زمینه',
            'subtitle' => 'رنگ پس زمینه اعلان سایت را مشخص کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#00BCD4',),
            'required' => array('alert_content_active', '=', 'inherit'),

        ),
        array(
            'id' => 'alert_btn_bg',
            'title' => 'رنگ پس زمینه دکمه',
            'subtitle' => 'رنگ پس زمینه دکمه اعلان را مشخص کنید.!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#05b1c7',),
            'required' => array('alert_content_active', '=', 'inherit'),

        ),
        array(
            'id' => 'alert_content_color',
            'title' => 'رنگ محتوای اعلان',
            'subtitle' => 'رنگ محتوای اعلان را انتخاب کنید.! این متن برای تمامی متون محتوای اعلان اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#ffffff',
            'required' => array('alert_content_active', '=', 'inherit'),

        ),
        array(
            'id' => 'alert_btn_color',
            'title' => 'رنگ متن دکمه',
            'subtitle' => 'از این قسمت میتوانید رنگ متن دکمه اعلان را تغییر دهید..',
            'type' => 'color',
            'required' => array('alert_content_active', '=', 'inherit'),

            'default' => '#fff'
        ),
        array(
            'id' => 'alert_btn_color_border',
            'title' => 'رنگ متن حاشیه دکمه',
            'subtitle' => 'از این قسمت میتوانید رنگ حاشیه دکمه اعلان را مشخص کنید.!',
            'type' => 'color',
            'required' => array('alert_content_active', '=', 'inherit'),

            'default' => '#ffffff'
        ),
        array(
            'id' => 'alert_close_color',
            'title' => 'رنگ آیکون بستن',
            'subtitle' => 'رنگ مورد نظر را برای این بخش انتخاب کنید.!',
            'type' => 'color',
            'required' => array('alert_content_active', '=', 'inherit'),

            'default' => '#ffffff'
        ),
    )
));


Redux::setSection($opt_name, array(
    'title' => 'تنظیمات لودینگ',
    'subsection' => true,
    'id' => 'loader_options',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_loader_options',
            'title' => 'تنظیمات لودینگ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'page_loader',
            'type' => 'button_set',
            'title' => 'لودر سایت',
            'subtitle' => 'از این بخش می توانید لودر قبل از بارگذاری سایت را فعال / غیر فعال کنید..',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'page_custom_loader',
            'type' => 'button_set',
            'title' => 'فعال سازی لودر سفارشی',
            'subtitle' => 'از این قسمت میتوانید پیش بارگذار سفارش برای سایت خود انتخاب کنید.',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'page_custom_loader_imga',
            'required' => array('page_custom_loader', '=', 'enable'),
            'title' => 'تصویر لودر سفارشی',
            'subtitle' => 'پیشنهاد می شود از تصاویر مربع مانند لوگو یا آیکون سایت خود استفاده کنید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/favicon-sigma.png'),
        ),        
        array(
            'id' => 'page_loader_style',
            'type' => 'image_select',
            'required' => array('page_loader', '=', 'inherit'),
            'required' => array('page_custom_loader', '=', 'disable'),
            'title' => __('طرح پیش بارگذار سایت', 'redux-framework-demo'),
            'subtitle' => __('از بین طرح های موجود یک طرح برای لودر یا پیش بارگذاری سایت خود انتخاب کنید!', 'redux-framework-demo'),
            'options' => array(
                'z' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/loader_00.png'
                ),
                '1' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_1.gif'
                ),
                '2' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_2.gif'
                ),
                '3' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_3.gif'
                ),
                '4' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_4.gif'
                ),
                '5' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_5.gif'
                ),
                '6' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_6.gif'
                ),
                '7' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_7.gif'
                ),
                '8' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_8.gif'
                ),
                '9' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_9.gif'
                ),
                'q' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_10.gif'
                ),
                'o' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_11.gif'
                ),
                't' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_12.gif'
                ),
                'h' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_13.gif'
                ),
                'v' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_14.gif'
                ),
                's' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_15.gif'
                ),
                'a' => array(
                    'img' => ReduxFramework::$_url . 'assets/img/Preloader_16.gif'
                )
            ),
            'default' => 'z'
        ),
        array(
            'id' => 'page_loader_icon',
            'title' => 'رنگ آیکون بارگذاری سایت',
            'subtitle' => 'رنگ آیکون پیش بارگذاری سایت را مشخص کنید.!',
            'type' => 'color',
            'default' => '#ff3547',
            'required' => array('page_loader', '=', 'inherit'),
            'required' => array('page_loader_style', '=', 'z'),
            'required' => array('page_custom_loader', '=', 'disable'),
        ),
        array(
            'id' => 'page_loader_bg',
            'title' => 'رنگ پس زمینه لودر سایت',
            'subtitle' => 'این رنگ برای پس زمینه کل صفحه ساز هنگام بارگذاری نمایش داده میشود.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#FFF'),
            'required' => array('page_loader', '=', 'inherit'),
            'required' => array('page_loader_style', '=', 'z'),
            'required' => array('page_custom_loader', '=', 'disable'),
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات پاپ آپ',
    'subsection' => true,
    'id' => 'popup_options',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'popup_options_options',
            'title' => 'تنظیمات پاپ آپ خبرنامه',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'popup_options_active',
            'type' => 'button_set',
            'title' => 'پاپ آپ خبرنامه',
            'subtitle' => 'برای هر کاربر در صورت بسته شدن هر 72 ساعت نمایش داده خواهد شد.',
            'default' => 'none',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'icon_popup',
            'title' => 'آیکون پاپ آپ خبرنامه',
            'required' => array('popup_options_active', '=', 'block'),
            'subtitle' => 'آیکون پاپ آپ خبرنامه را اینجا انتخاب کنید ، اندازه پیشنهاد 160*160 میباشد.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/newslatter.svg'),
        ),
        array(
            'id' => 'title_popup',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'عنوان عضویت در خبرنامه',
            'subtitle' => 'عنوان فرم پاپ آپ عضویت در خبرنامه را وارد کنید!',
            'type' => 'text',
            'default' => 'عضویت در خبرنامه ویژه مشتریان سیگما پلاس'
        ),
        array(
            'id' => 'subtitle_popup',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'زیر عنوان عضویت در خبرنامه',
            'subtitle' => 'زیر عنوان فرم پاپ آپ عضویت در خبرنامه را وارد کنید!',
            'type' => 'text',
            'default' => 'با عضویت در خبرنامه ویژه سیگما پلاس از آخرین جشنواره های سایت باخبر شوید!'
        ),
        array(
            'id' => 'popup_color_title',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'رنگ عنوان پاپ آپ ',
            'subtitle' => 'این رنگ برای عنوان پنجره عضویت در خبرنامه اعمال میشود',
            'type' => 'color',
            'default' => '#607d8b'
        ),
        array(
            'id' => 'popup_color_subtitle',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'رنگ زیر عنوان پاپ آپ ',
            'subtitle' => 'این رنگ برای زیر عنوان و متن نگهدارنده فرم پنجره عضویت در خبرنامه اعمال میشود',
            'type' => 'color',
            'default' => '#b7b7b7'
        ),
        array(
            'id' => 'popup_color_border',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'رنگ حاشیه پایین فرم خبرنامه',
            'subtitle' => 'این رنگ برای حاشیه پایین فرم خبرنامه اعمال خواهد شد!',
            'type' => 'color',
            'default' => '#ffc107'
        ),
        array(
            'id' => 'popup_color',
            'required' => array('popup_options_active', '=', 'block'),
            'title' => 'رنگ دکمه عضویت پاپ آپ ',
            'subtitle' => 'این رنگ برای دکمه عضویت اعمال میشود.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffc107',),
        ),
    )
));


Redux::setSection($opt_name, array(
    'title' => 'شبکه های اجتماعی',
    'subsection' => true,
    'id' => 'fix_icon_options',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_fix_icon_options',
            'title' => 'شبکه های اجتماعی',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'youtube_show',
            'title' => 'فعال سازی نمایش آیکون یوتیوب در سایت',
            'subtitle' => 'از این بخش می توانید آیکون یوتیوب را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline-block',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'heaader_v1_040',
            'required' => array('youtube_show', '=', 'inline-block'),
            'title' => 'تغییر آیکون یوتیوب  ',
            'subtitle' => 'از این قسمت می توانید آیکون " یوتیوب " را در هدر تغییر دهید.',
            'type' => 'text',
            'default' => 'fab fa-youtube '
        ),
        array(
                'id' => 'heaader_v1_042',
            'required' => array('youtube_show', '=', 'inline-block'),
            'title' => 'لینک صفحه یوتیوب',
            'subtitle' => 'لینک صفحه یوتیوب انتخاب این آیکون در هدر سایت شما و در کنار منوی اصلی نمایش داده میشود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://www.youtube.com/sigma'
        ),
        array(
            'id' => 'instagram_show',
            'title' => 'فعال سازی نمایش آیکون اینستاگرام در سایت',
            'subtitle' => 'از این بخش می توانید آیکون اینستاگرام را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline-block',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'heaader_v1_038',
            'required' => array('instagram_show', '=', 'inline-block'),
            'title' => 'تغییر آیکون اینستاگرام ',
            'subtitle' => 'از این قسمت می توانید آیکون " اینستاگرام " را در هدر تغییر دهید.',
            'type' => 'text',
            'default' => 'fab fa-instagram '
        ),
        array(
            'id' => 'heaader_v1_046',
            'required' => array('instagram_show', '=', 'inline-block'),
            'title' => 'لینک صفحه اینستاگرام',
            'subtitle' => 'لینک صفحه اینستاگرام را انتخاب این آیکون در هدر سایت شما و در کنار منوی اصلی نمایش داده میشود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://instagram.com/hamakrwpcom'
        ),
        array(
            'id' => 'facebook_show',
            'title' => 'فعال سازی نمایش آیکون فیسبوک در سایت',
            'subtitle' => 'از این بخش می توانید آیکون فیسبوک را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline-block',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'heaader_v1_037',
            'required' => array('facebook_show', '=', 'inline-block'),
            'title' => 'تغییر آیکون فیسبوک ',
            'subtitle' => 'از این قسمت می توانید آیکون " فیسبوک " را در هدر تغییر دهید.',
            'type' => 'text',
            'default' => 'fab fa-facebook '
        ),
        array(
            'id' => 'heaader_v1_043',
            'required' => array('facebook_show', '=', 'inline-block'),
            'title' => 'لینک صفحه فیسبوک',
            'subtitle' => 'لینک صفحه فیسبوک را انتخاب این آیکون در هدر سایت شما و در کنار منوی اصلی نمایش داده میشود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://www.facebook.com/sigma'
        ),
        array(
            'id' => 'telegram_show',
            'title' => 'فعال سازی نمایش آیکون تلگرام در سایت',
            'subtitle' => 'از این بخش می توانید آیکون تلگرام را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline-block',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'heaader_v1_039',
            'required' => array('telegram_show', '=', 'inline-block'),
            'title' => 'تغییر آیکون تلگرام ',
            'subtitle' => 'از این قسمت می توانید آیکون " تلگرام " را در هدر تغییر دهید.',
            'type' => 'text',
            'default' => 'fab fa-telegram '
        ),
        array(
            'id' => 'heaader_v1_044',
            'required' => array('telegram_show', '=', 'inline-block'),
            'title' => 'لینک صفحه تلگرام',
            'subtitle' => 'لینک صفحه تلگرام را انتخاب این آیکون در هدر سایت شما و در کنار منوی اصلی نمایش داده میشود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://telegram.me/hamkarwp'
        ),
        array(
            'id' => 'twitter_show',
            'title' => 'فعال سازی نمایش آیکون توییتر در سایت',
            'subtitle' => 'از این بخش می توانید آیکون توییتر را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline-block',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'heaader_v1_041',
            'required' => array('twitter_show', '=', 'inline-block'),
            'title' => 'تغییر آیکون توییتر ',
            'subtitle' => 'از این قسمت می توانید آیکون " توییتر " را در هدر تغییر دهید.',
            'type' => 'text',
            'default' => 'fab fa-twitter '
        ),
        array(
            'id' => 'heaader_v1_045',
            'required' => array('twitter_show', '=', 'inline-block'),
            'title' => 'لینک صفحه توییتر',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://twitter.com/sigma'

        ),        
    )
));

// -> START Home Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات دموها',
    'id' => 'homepage',
    'class' => 'dev-expire',
    'customizer_width' => '400px',
    'icon' => 'el el-home',
    'fields' => array(
        array(
            'id' => 'homepages_style_page',
            'type' => 'select',
            'title' => 'انتخاب دموی سایت',
            'subtitle' => 'یک دمو از بین دمو های موجود برای صفحه اصلی سایت خود انتخاب کنید..',
            'desc' => 'با انتخاب هر دمو تنظیمات مربوطه نمایش داده شده و آن طرح به عنوان صفحه اصلی انتخاب میشود!',
            'options' => array(
                'template-part/content/home/home-v1' => 'دموی سیگما پلاس ',
                'template-part/content/home/home-v2' => 'دموی سیگما رویال',
                'template-part/content/home/home-v3' => 'دموی سیگما کلاسیک',
                'template-part/content/home/home-v4' => 'دموی سیگما مدرن'
            ),
            'default' => 'template-part/content/home/home-v1'
        ),
        array(
            'id' => 'slider_show2',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
            'title' => 'تنظیمات اسلایدر',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true
        ),
        array(
            'id' => 'section_show_001',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی اسلایدر',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'sliders_hp1',
            'type' => 'slides',
            'required' => array('section_show_001', '=', 'inherit'),
            'subtitle' => 'اسلایدهای موجود را از این قسمت مدیریت کنید.',
            'placeholder' => array(
                'title' => 'عنوان اسلایدر را وارد کنید.!',
                'subtitleription' => 'توضیحات اسلایدر را وارد کنید.!',
                'url' => 'لینک اسلایدر را وارد کنید.!',
            ),
        ),
        array(
            'id' => 'service_show',
            'title' => 'تنظیمات آیکون باکس زیر اسلایدر',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
            'indent' => true
        ),
        array(
            'id' => 'service_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی خدمات',
            'subtitle' => 'نمایش یا مخفی سازی خدمات زیر اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'bx_slider_img01',
            'title' => 'آیکون باکس یک پایین اسلایدر',
            'required' => array('service_active', '=', 'inherit'),
            'subtitle' => 'تصویر آیکون باکس یک را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/s1.png'),
        ),
        array(
            'id' => 'bx_slider_txt01',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'عنوان باکس یک پایین اسلایدر',
            'subtitle' => 'عنوان باکس یک پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'طراحی استاندارد'
        ),
        array(
            'id' => 'bx_slider_sub_01',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'زیرعنوان باکس یک پایین اسلایدر',
            'subtitle' => 'زیرعنوان باکس یک پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'طرح های ارائه شده'
        ),
        array(
            'id' => 'bx_slider_img02',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'آیکون باکس دو پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس دو را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/s2.png'),
        ),
        array(
            'id' => 'bx_slider_txt02',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'عنوان باکس دو پایین اسلایدر',
            'subtitle' => 'عنوان باکس دو پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'بازگشت وجه'
        ),
        array(
            'id' => 'bx_slider_sub02',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'زیرعنوان باکس دو پایین اسلایدر',
            'subtitle' => 'زیر عنوان باکس دو پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'تا یک هفته از خرید'
        ),
        array(
            'id' => 'bx_slider_img03',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'آیکون باکس سه پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس سه را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/s3.png'),
        ),
        array(
            'id' => 'bx_slider_txt03',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'عنوان باکس سه پایین اسلایدر',
            'subtitle' => 'عنوان باکس سه پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'نصب آسان'
        ),
        array(
            'id' => 'bx_slider_sub03',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'زیرعنوان باکس سه پایین اسلایدر',
            'subtitle' => 'زیر عنوان باکس سه پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'در تمامی هاست ها'
        ),
        array(
            'id' => 'bx_slider_img04',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'آیکون باکس چهار پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس چهار را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/s4.png'),
        ),
        array(
            'id' => 'bx_slider_txt04',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'عنوان باکس چهار پایین اسلایدر',
            'subtitle' => 'عنوان باکس چهار پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'پرداخت مطمئن'
        ),
        array(
            'id' => 'bx_slider_sub04',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'زیرعنوان باکس چهار پایین اسلایدر',
            'subtitle' => 'زیر عنوان باکس چهار پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'با کلیه کارت های شتاب'
        ),
        array(
            'id' => 'bg_iconbox',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'رنگ پس زمینه آیکون باکس های پایین اسلایدر',
            'subtitle' => 'رنگ پس زمینه آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#fff'
        ),
        array(
            'id' => 'title_iconbox',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'رنگ عناوین آیکون باکس ها',
            'subtitle' => 'رنگ عناوین آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'subtitle_iconbox',
            'required' => array('service_active', '=', 'inherit'),
            'title' => 'رنگ زیر عناوین آیکون باکس ها',
            'subtitle' => 'رنگ زیر عناوین آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'section_show_003',
            'title' => 'تنظیمات بخش آخرین محصولات',
            'type' => 'section',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
            'class' => 'ruby-section-start',
            'indent' => true
        ),
        array(
            'id' => 'last_products_show',
            'type' => 'button_set',
            'default' => 'flex',
            'title' => 'نمایش آخرین محصولات سایت',
            'subtitle' => 'از این قسمت میتوانید نمایش آخرین محصولات صفحه اصلی سبک یک را مدیریت کنید.!',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'last_product_title',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'تغییر عنوان آخرین محصولات سایت',
            'type' => 'text',
            'default' => 'آخرین محصولات سایت'
        ),
        array(
            'id' => 'archive_product_title',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'تغییر عنوان آرشیو محصولات',
            'type' => 'text',
            'default' => 'آرشیو محصولات'
        ),
        array(
            'id' => 'archive_product_link',
            'title' => 'تغییر لینک آرشیو محصولات',
            'subtitle' => 'لینک آرشیو محصولات را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'btn_products',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'تغییر عنوان دکمه خرید آنلاین',

            'type' => 'text',
            'default' => 'خرید آنلاین محصول '
        ),
        array(
            'id' => 'last_product01_count',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'تعداد محصول نمایشی در بخش آخرین محصولات',
            'subtitle' => 'از این قسمت می توانید تعداد محصول نمایشی را مشخص کنید.',
            'type' => 'text',
            'default' => '6'
        ),
        array(
            'id' => 'last_product01_cat',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'دسته بندی دلخواه برای نمایش در بخش آخرین محصولات',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش آخرین محصولات را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'args' => array(
                'taxonomy' => 'product_cat',
            ),
            'default' => '17'
        ),
        array(
            'id' => 'home_v2_970',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'نمایش توضیحات محصولات',
            'subtitle' => 'نمایش یا عدم نمایش توضیحات محصولات را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_971',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'نمایش دسته بندی محصولات',
            'subtitle' => 'نمایش یا عدم نمایش دسته بندی محصولات را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_972',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'نمایش تعداد بازدید محصولات',
            'subtitle' => 'نمایش یا عدم نمایش تعداد بازدید محصولات را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_973',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'نمایش دکمه " خرید آنلاین محصول " محصولات',
            'subtitle' => 'نمایش یا عدم نمایش دکمه سبز رنگ خرید آنلاین محصول را مشخص کنید.!',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_974',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'رنگ پس زمینه هدر بخش آخرین محصولات سایت',
            'subtitle' => 'رنگ پس زمینه بخش آخرین محصولات سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#f9f9f9'
        ),
        array(
            'id' => 'home_v2_975',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'رنگ متن عنوان محصولات سایت',
            'subtitle' => 'رنگ متن عنوان محصولات سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_976',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'رنگ متن توضیحات محصولات سایت',
            'subtitle' => 'رنگ متن توضیحات محصولات سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_979',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'رنگ متن دکمه "خرید آنلاین محصول" محصولات سایت',
            'subtitle' => 'رنگ متن دکمه "خرید آنلاین محصول" در محصولات سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#fff'
        ),
        array(
            'id' => 'home_v2_980',
            'required' => array('last_products_show', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه خرید آنلاین محصولات سایت',
            'subtitle' => 'رنگ پس زمینه دکمه خرید آنلاین محصولات سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#00beaf'
        ),
        array(
            'id' => 'home_v1_002',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
            'title' => 'تنظیمات مطالب محبوب',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'home_v2_1003',
            'title' => 'نمایش مطالب محبوب سایت',
            'subtitle' => 'نمایش یا عدم نمایش مطالب محبوب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'flex',
            'section' => 'homepage',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'last_posts_01_title',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'تغییر عنوان مطالب محبوب سایت',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => ' مطالب محبوب سایت'
        ),
        array(
            'id' => 'btn_posts_01',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'تغییر عنوان توضیحات بیشتر',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'توضیحات بیشتر'
        ),
        array(
            'id' => 'archive_posts_01_title',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'تغییر عنوان آرشیو مطالب محبوب',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'آرشیو مطالب محبوب'
        ),
        array(
            'id' => 'archive_posts_01_link',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'تغییر لینک آرشیو مطالب محبوب',
            'subtitle' => 'از این قسمت می توانید این لینک را تغییر دهید.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . ''
        ),
        array(
            'id' => 'home_v2_1001',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'تعداد محصول نمایشی در بخش مطالب محبوب سایت',
            'subtitle' => 'از این قسمت می توانید تعداد مطالب محبوب سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '3'
        ),
        array(
            'id' => 'home_v2_1002',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'دسته بندی دلخواه برای نمایش در بخش آخرین مطالب محبوب سایت',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش مطالب محبوب سایت را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v2_1006',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'نمایش توضیحات مطالب محبوب سایت',
            'subtitle' => 'نمایش یا عدم نمایش توضیحات مطالب محبوب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'section' => 'homepage',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1007',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'نمایش دسته بندی مطالب محبوب سایت',
            'subtitle' => 'نمایش یا عدم نمایش دسته بندی مطالب محبوب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'section' => 'homepage',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1008',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'نمایش تعداد بازدید مطالب محبوب سایت',
            'subtitle' => 'نمایش یا عدم نمایش تعداد بازدید مطالب محبوب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'section' => 'homepage',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1009',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'نمایش دکمه " توضیحات بیشتر " مطالب محبوب سایت',
            'subtitle' => 'نمایش یا عدم نمایش دکمه توضیحات بیشتر بخش محبوب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'section' => 'homepage',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1010',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ پس زمینه بخش آخرین مطالب محبوب سایت سایت',
            'subtitle' => 'رنگ پس زمینه بخش آخرین مطالب محبوب سایت را مشخص کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fff',),
        ),
        array(
            'id' => 'home_v2_1015',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ متن عنوان مطالب محبوب سایت',
            'subtitle' => 'رنگ متن عنوان مطالب محبوب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1016',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ متن توضیحات مطالب محبوب سایت',
            'subtitle' => 'رنگ متن توضیحات مطالب محبوب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1018',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ متن تعداد بازدید مطالب محبوب سایت',
            'subtitle' => 'رنگ متن تعداد بازدید مطالب محبوب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'btn_home1_post_bg',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه توضیحات بیشتر مطالب محبوب',
            'subtitle' => 'رنگ پس زمینه دکمه توضیحات بیشتر را مشخص کنید.!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f5f5f5',),
        ),
        array(
            'id' => 'home_v2_1019',
            'required' => array('home_v2_1003', '=', 'flex'),
            'title' => 'رنگ متن دکمه توضیحات بیشتر مطالب محبوب سایت',
            'subtitle' => 'رنگ متن دکمه توضیحات بیشتر مطالب محبوب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),


        array(
            'id' => 'home_v1_007',
            'title' => 'تنظیمات آخرین مطالب سایت',
            'type' => 'section',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
            'class' => 'ruby-section-start',
            'indent' => true
        ),
        array(
            'id' => 'home_v2_1103',
            'title' => 'نمایش آخرین مطالب سایت',
            'subtitle' => 'نمایش یا عدم نمایش آخرین مطالب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'last_posts_02_title',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'تغییر عنوان آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین مطالب سایت'
        ),
        array(
            'id' => 'archive_posts_02_title',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'تغییر عنوان آرشیو آخرین مطالب',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'آرشیو آخرین مطالب'
        ),
        array(
            'id' => 'archive_posts_02_link',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'تغییر لینک آرشیو آخرین مطالب',
            'subtitle' => 'از این قسمت می توانید این لینک را تغییر دهید.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'btn_posts_02',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'تغییر عنوان توضیحات بیشتر',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'توضیحات بیشتر'
        ),
        array(
            'id' => 'home_v2_1101',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'تعداد محصول نمایشی در بخش آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید تعداد آخرین آخرین مطالب سایت سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '3'
        ),
        array(
            'id' => 'home_v2_1102',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => ' دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v2_1106',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'نمایش توضیحات آخرین مطالب سایت',
            'subtitle' => 'نمایش یا عدم نمایش توضیحات آخرین مطالب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1107',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'نمایش دسته بندی آخرین مطالب سایت',
            'subtitle' => 'نمایش یا عدم نمایش دسته بندی آخرین مطالب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1108',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'نمایش تعداد بازدید آخرین مطالب سایت',
            'subtitle' => 'نمایش یا عدم نمایش تعداد بازدید آخرین مطالب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1109',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'نمایش دکمه " توضیحات بیشتر " آخرین مطالب سایت',
            'subtitle' => 'نمایش یا عدم نمایش دکمه توضیحات بیشتر آخرین مطالب سایت را مشخص کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_1110',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ پس زمینه بخش آخرین مطالب سایت',
            'subtitle' => 'رنگ پس زمینه بخش آخرین مطالب سایت را مشخص کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fff',),
        ),
        array(
            'id' => 'home_v2_1115',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ متن عنوان آخرین مطالب سایت',
            'subtitle' => 'رنگ متن عنوان آخرین مطالب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1116',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ متن توضیحات آخرین مطالب سایت',
            'subtitle' => 'رنگ متن توضیحات آخرین مطالب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1117',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ متن دسته بندی آخرین مطالب سایت',
            'subtitle' => 'رنگ متن توضیحات آخرین مطالب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1118',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ متن تعداد بازدید آخرین مطالب سایت',
            'subtitle' => 'رنگ متن تعداد بازدید آخرین مطالب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v2_1119',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ متن دکمه توضیحات بیشتر آخرین مطالب سایت',
            'subtitle' => 'رنگ متن دکمه توضیحات بیشتر آخرین مطالب سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'btn_home1_section2_post_bg',
            'required' => array('home_v2_1103', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه توضیحات بیشتر',
            'subtitle' => 'رنگ پس زمینه دکمه توضیحات بیشتر را مشخص کنید.!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f5f5f5',),
        ),
        array(
            'id' => 'home_v2_0007',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات اسلایدر',
        ),
        array(
            'id' => 'section_show_002',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی اسلایدر',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'sliders_hp2',
            'required' => array('section_show_002', '=', 'inherit'),
            'type' => 'slides',
            'subtitle' => 'اسلایدهای موجود را از این قسمت مدیریت کنید.',
            'placeholder' => array(
                'title' => 'عنوان اسلایدر را وارد کنید.!',
                'subtitleription' => 'توضیحات اسلایدر را وارد کنید.!',
                'url' => 'لینک اسلایدر را وارد کنید.!',
            ),
        ),
        array(
            'id' => 'service_show2',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات آیکون باکس ها',
        ),
        array(
            'id' => 'iconbox_show',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی آیکون باکس',
            'subtitle' => 'نمایش یا مخفی سازی آیکون باکس های پایین اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'bx_slider_img_01',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'آیکون باکس یک پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس یک را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/icons8-passport-50.png'),
        ),
        array(
            'id' => 'bx_slider_txt_01',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'عنوان باکس یک پایین اسلایدر',
            'subtitle' => 'عنوان باکس یک پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'طراحی استاندارد'
        ),
        array(
            'id' => 'bx_slider_sub_001',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'زیرعنوان باکس یک پایین اسلایدر',
            'subtitle' => 'زیرعنوان باکس یک پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'طرح های ارائه شده'
        ),
        array(
            'id' => 'bx_slider_img_02',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'آیکون باکس دو پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس دو را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/icons8-code-50.png'),
        ),
        array(
            'id' => 'bx_slider_txt_02',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'عنوان باکس دو پایین اسلایدر',
            'subtitle' => 'زیرعنوان باکس دو پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'بازگشت وجه'
        ),
        array(
            'id' => 'bx_slider_sub_02',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'زیرعنوان باکس دو پایین اسلایدر',
            'subtitle' => 'عنوان باکس دو پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'تا یک هفته از خرید'
        ),
        array(
            'id' => 'bx_slider_img_03',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'آیکون باکس سه پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس یک را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/icons8-padlock-50.png'),
        ),
        array(
            'id' => 'bx_slider_txt_03',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'عنوان باکس سه پایین اسلایدر',
            'subtitle' => 'عنوان باکس سه پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'نصب آسان'
        ),
        array(
            'id' => 'bx_slider_sub_03',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'زیرعنوان باکس سه پایین اسلایدر',
            'subtitle' => 'زیرعنوان باکس سه پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'در تمامی هاست ها'
        ),
        array(
            'id' => 'bx_slider_img_04',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'آیکون باکس چهار پایین اسلایدر',
            'subtitle' => 'تصویر آیکون باکس چهار را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/icons8-key-50.png'),
        ),
        array(
            'id' => 'bx_slider_txt_04',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'عنوان باکس چهار پایین اسلایدر',
            'subtitle' => 'عنوان باکس چهار پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'پرداخت مطمئن'
        ),
        array(
            'id' => 'bx_slider_sub_04',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'زیرعنوان باکس چهار پایین اسلایدر',
            'subtitle' => 'زیر عنوان باکس چهار پایین اسلایدر را وارد کنید..',
            'type' => 'text',
            'default' => 'با کلیه کارت های شتاب'
        ),
        array(
            'id' => 'bg_iconbox2',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'رنگ پس زمینه آیکون باکس های پایین اسلایدر',
            'subtitle' => 'رنگ پس زمینه آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'required' => array('iconbox_show', '=', 'inherit'),
            'default' => array(
                'background-color' => '#fff'),
        ),
        array(
            'id' => 'title_iconbox2',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'رنگ عناوین آیکون باکس ها',
            'subtitle' => 'رنگ عناوین آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'subtitle_iconbox_hv2',
            'required' => array('iconbox_show', '=', 'inherit'),
            'title' => 'رنگ زیر عناوین آیکون باکس ها',
            'subtitle' => 'رنگ زیر عناوین آیکون باکس های پایین اسلایدر صفحه اصلی سایت را مشخص کنید..',
            'type' => 'color',
            'default' => '#7a7a7a'
        ),
        array(
            'id' => 'home_v2_0008',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات آخرین مطالب',
        ),
        array(
            'id' => 'home_v2_56',
            'title' => 'نمایش یا پنهان کردن بخش آخرین مطالب سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین مطالب سایت در صفحه اصلی دو',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_last_post_cat',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => ' دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v2_last_post_count',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تعداد مطلب نمایشی در بخش آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید تعداد آخرین آخرین مطالب سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '12'
        ),
        array(
            'id' => 'home_v2_67',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر متن آخرین مطالب دنیای وب',
            'subtitle' => 'از این قسمت می توانید متن" عنوان این باکس " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین مطالب دنیای وب',
        ),
        array(
            'id' => 'home_v2_69',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر متن دکمه مشاهده عناوین بیشتر',
            'subtitle' => 'عنوان دکمه مشاهده عناوین بیشتر را مشخص کنید..',
            'type' => 'text',
            'default' => 'مشاهده عناوین بیشتر',
        ),
        array(
            'id' => 'home_v2_70',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر لینک دکمه مشاهده عناوین بیشتر',
            'subtitle' => 'از این قسمت می توانید لینک دکمه مشاهده عناوین بیشتر را تغییر دهید.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v2_58',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'نمایش یا پنهان کردن توضیحات آخرین مطالب ',
            'default' => 'inherit',
            'subtitle' => 'نمایش / پنهان کردن بخش توضیحات آخرین مطالب  در صفحه اصلی دو',
            'type' => 'button_set',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_59',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'نمایش یا پنهان کردن دکمه " ادامه مطلب " آخرین مطالب ',
            'default' => 'inherit',
            'subtitle' => 'نمایش / پنهان کردن بخش دکمه " ادامه مطلب " مطالب آخرین مطالب در صفحه اصلی دو',
            'type' => 'button_set',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_61',
            'required' => array('home_v2_56', '=', 'inherit'),
            'default' => 'inline',
            'title' => 'نمایش یا پنهان کردن " بخش نظرات " آخرین مطالب ',
            'subtitle' => 'نمایش / پنهان کردن بخش " بخش نظرات "  آخرین مطالب در صفحه اصلی دو',
            'type' => 'button_set',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_62',
            'required' => array('home_v2_56', '=', 'inherit'),
            'default' => 'inherit',
            'title' => 'نمایش یا پنهان کردن " تصویر نویسنده " آخرین مطالب ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تصویر نویسنده " آخرین مطالب در صفحه اصلی دو',
            'type' => 'button_set',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_63',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان "آخرین مطالب دنیای وب"',
            'subtitle' => 'از این قسمت میتوانید عنوان بخش را تغییر دهید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'home_v2_64',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ عنوان مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'home_v2_65',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر رنگ توضیحات مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ توضیحات مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v2_66',
            'required' => array('home_v2_56', '=', 'inherit'),
            'title' => 'تغییر رنگ دکمه ادامه مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ دکمه ادامه مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#e92b5f',
        ),
        array(
            'id' => 'home_v2_banner',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات بنر عریض پایین مطالب',
        ),
        array(
            'id' => 'home_v2_banner_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی بنر عریض پایین مطالب',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_banner_img',
            'required' => array('home_v2_banner_active', '=', 'inherit'),
            'title' => 'آپلود بنر تمام عرض پایین مطالب سایت',
            'subtitle' => 'یک بنر برای بخش پایین مطالب آپلود کنید. ، اندازه پیشنهاد تصویر تمام عرض میباشد. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/2715.jpg'),
        ),
        array(
            'id' => 'home_v2_banner_link',
            'required' => array('home_v2_banner_active', '=', 'inherit'),
            'title' => 'لینک بنر تمام عرض پایین مطالب را وارد کنید.!  ',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),


        array(
            'id' => 'home_v02_001',
            'type' => 'section',
            'class' => 'ruby-section-start',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => ' تنظیمات آخرین محصولات سایت',
        ),
        array(
            'id' => 'home_v2_901',
            'title' => 'نمایش یا پنهان کردن بخش آخرین محصولات سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین محصولات سایت در صفحه اصلی دو',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_908',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر عنوان آخرین محصولات سایت',
            'subtitle' => 'از این قسمت می توانید متن" عنوان این باکس " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین محصولات سایت',
        ),
        array(
            'id' => 'home_v2_909',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر لینک دکمه مشاهده محصولات بیشتر',
            'subtitle' => 'از این قسمت می توانید لینک دکمه مشاهده محصولات بیشتر را تغییر دهید.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v2_9140',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر متن دکمه مشاهده محصولات بیشتر',
            'subtitle' => 'از این قسمت می توانید متن" مشاهده محصولات بیشتر " را تغییر دهید.',
            'type' => 'text',
            'default' => 'مشاهده محصولات بیشتر',
        ),
        array(
            'id' => 'hv2_btn_products',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر عنوان دکمه خرید آنلاین',
            'type' => 'text',
            'default' => 'خرید آنلاین محصول '
        ),
        array(
            'id' => 'homev2_last_product01_count',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تعداد محصول نمایشی در بخش آخرین محصولات',
            'subtitle' => 'از این قسمت می توانید تعداد محصول نمایشی را مشخص کنید.',
            'type' => 'text',
            'default' => '6'
        ),
        array(
            'id' => 'homev2_last_product01_cat',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'دسته بندی دلخواه برای نمایش در بخش آخرین محصولات',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش آخرین محصولات را مشخص کنید. ',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'args' => array(
                'taxonomy' => 'product_cat',
            ),
            'default' => '17'
        ),
        array(
            'id' => 'home_v2_903',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن توضیحات آخرین محصولات سایت ',
            'subtitle' => 'نمایش / پنهان کردن توضیحات آخرین محصولات سایت در صفحه اصلی دو',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_904',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن دکمه " خرید آنلاین محصول " ',
            'subtitle' => 'نمایش / پنهان کردن بخش دکمه " خرید آنلاین محصول "  در صفحه اصلی دو',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_905',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تصویر محصولات " ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تصویر محصولات " در صفحه اصلی دو',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_906',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تعداد بازدید " ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_914',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " دسته بندی"   ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_907',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " قیمت محصول در بالای تصویر "   ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_918',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " قیمت محصول در پایین تصویر "   ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_919',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " دکمه مشاهده عناوین بیشتر "   ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_915',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ دکمه مشاهده عناوین بیشتر',
            'subtitle' => 'از این قسمت می توانید رنگ " مشاهده عناوین بیشتر " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ccc',
        ),
        array(
            'id' => 'home_v2_9198',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه دکمه مشاهده عناوین بیشتر',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه " مشاهده عناوین بیشتر " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff',
        ),
        array(
            'id' => 'home_v2_916',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان اصلی',
            'subtitle' => 'از این قسمت میتوانید رنگ عنوان این بخش را تغییر دهید.',
            'type' => 'color',
            'default' => '#000000',
        ),
        array(
            'id' => 'home_v2_917',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ عنوان مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'home_v2_911',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ توضیحات مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ توضیحات مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#888888',
        ),
        array(
            'id' => 'home_v2_912',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه  دکمه خرید آنلاین',
            'subtitle' => 'از این قسمت می توانید " دکمه خرید آنلاین " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#00beaf',),
        ),
        array(
            'id' => 'home_v2_913',
            'required' => array('home_v2_901', '=', 'flex'),
            'title' => 'تغییر رنگ متن قیمت محصولات',
            'subtitle' => 'از این قسمت می توانید "رنگ متن قیمت محصولات " را تغییر دهید.',
            'type' => 'color',
            'default' => '#000000'
        ),
        array(
            'id' => 'home_v02_004',
            'type' => 'section',
            'required' => array('home_v2_901', '=', 'flex'),
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'indent' => true,
            'title' => 'تنظیمات سایدبار کناری',
        ),
        array(
            'id' => 'home_v02_sidebar_active',
            'type' => 'button_set',
            'default' => 'block',
            'title' => 'فعال یا غیرفعال سازی اسلایدر سمت چپ',
            'subtitle' => 'مشخص کنید که آیا میخواهید اسلایدر سمت چپ نمایش داده شود یا خیر؟',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v02_sidebar',
            'required' => array('home_v2_901', '=', 'flex'),
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'required' => array('home_v02_sidebar_active', '=', 'block'),
            'type' => 'select',
            'subtitle' => 'از این قسمت میتوانید سایدبار سفارشی خود را جهت نمایش در صفحه اصلی دو مشخص کنید!',
            'data' => 'sidebars',
            'default' => 'shop-sidebar',
            'title' => 'مدیریت سایدبار کناری',
        ),
        array(
            'id' => 'home_v02_002',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات برندها',
        ),
        array(
            'id' => 'home_v02_slides_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی اسلایدر برندها',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر برندهای سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v02_002_slides',
            'required' => array('home_v02_slides_active', '=', 'inherit'),
            'type' => 'slides',
            'subtitle' => 'اسلایدهای موجود را از این قسمت مدیریت کنید.',
            'placeholder' => array(
                'title' => 'عنوان اسلایدر را وارد کنید.!',
                'subtitleription' => 'توضیحات اسلایدر را وارد کنید.!',
                'url' => 'لینک اسلایدر را وارد کنید.!',
            ),
        ),


        array(
            'id' => 'home_v02_003',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v2'),
            'title' => 'تنظیمات تصاویر پازلی',
        ),
        array(
            'id' => 'home_v02_pazzel_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی تصاویر پازلی',
            'subtitle' => 'نمایش یا مخفی سازی تصاویر پازلی سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v2_942',
            'title' => 'تصویر شماره یک',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'subtitle' => 'از این قسمت می توانید تصویر " شماره یک " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/1813.jpg'),
        ),
        array(
            'id' => 'home_v2_0942',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'لینک تصویر شماره یک',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v2_943',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'تصویر شماره دو',
            'subtitle' => 'از این قسمت می توانید تصویر " شماره دو " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/1814.jpg'),
        ),
        array(
            'id' => 'home_v2_0943',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'لینک تصویر شماره دو',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v2_944',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'تصویر شماره سه',
            'subtitle' => 'از این قسمت می توانید تصویر " شماره سه " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/1816.jpg'),
        ),
        array(
            'id' => 'home_v2_0944',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'لینک تصویر شماره سه',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v2_945',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'تصویر شماره چهار ',
            'subtitle' => 'از این قسمت می توانید تصویر " شماره چهار " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/2636.jpg'),
        ),
        array(
            'id' => 'home_v2_0945',
            'required' => array('home_v02_pazzel_active', '=', 'inherit'),
            'title' => 'لینک تصویر شماره چهار',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),


        /**
         *************** Start home3 Setting ***************
         */
        array(
            'id' => 'home_1v3_06',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات بخش آغازین صفحه',
        ),
        array(
            'id' => 'home_v3_start_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی بخش آغازین',
            'subtitle' => 'شما میتوانید از این بخش بخش آغازین و جستجوی سایت را غیرفعال کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_21',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر متن عنوان ابتدایی سایت',
            'subtitle' => 'از این قسمت می توانید متن" عنوان ابتدایی سایت " را تغییر دهید.',
            'type' => 'text',
            'default' => 'قالب وردپرس ایرانی فروش فایل سیگما پلاس | بهترین قالب ایرانی',
        ),
        array(
            'id' => 'home_v3_22',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر متن زیر عنوان ابتدایی سایت',
            'subtitle' => 'از این قسمت می توانید متن" زیر عنوان ابتدایی سایت " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش های حرفه ای و متفاوت از ما',
        ),
        array(
            'id' => 'home_v3_bg_full',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییرتصویر پس زمینه بخش جستجو  ',
            'subtitle' => 'از این قسمت می توانید" تصویر پس زمینه پشت جستجو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-color' => false,
            'background-attachment' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/new-mainpage-min.jpg'
            )
        ),
        array(
            'id' => 'home_v3_03',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش عنوان ابتدایی سایت',
            'subtitle' => 'نمایش / پنهان کردن بخش عنوان ابتدایی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_04',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش زیر عنوان ابتدایی سایت',
            'subtitle' => 'نمایش / پنهان کردن زیر عنوان ابتدایی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_05',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش کادر جستجو ابتدایی سایت',
            'subtitle' => 'نمایش / پنهان کردن کادر جستجو ابتدایی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_101',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ عنوان ابتدای صفحه اصلی سه',
            'subtitle' => 'از این قسمت می توانید رنگ " زیر عنوان ابتدای صفحه اصلی سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_11',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ زیر عنوان ابتدای صفحه اصلی سه',
            'subtitle' => 'از این قسمت می توانید رنگ " زیر عنوان ابتدای صفحه اصلی سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_061',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش خدمات سفارشی شماره یک',
            'subtitle' => 'نمایش / پنهان کردن خدمات سفارشی شماره یک در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_14',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ متن خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " متن خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_17',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ اعداد خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " اعداد خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_23',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر متن خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش کاربردی',
        ),
        array(
            'id' => 'home_v3_26',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر اعداد خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید اعداد " خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => '469/569',
        ),
        array(
            'id' => 'home_v3_29',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر آیکون خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید آیکون " خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/students-cap.png'),
        ),
        array(
            'id' => 'home_v3_07',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش خدمات سفارشی شماره دو',
            'subtitle' => 'نمایش / پنهان کردن خدمات سفارشی شماره دو در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_24',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر متن خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'text',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'default' => 'دوره آموزشی',
        ),
        array(
            'id' => 'home_v3_27',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر اعداد خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید اعداد " خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => '43/335',
        ),
        array(
            'id' => 'home_v3_15',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ متن خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " متن خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_18',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ اعداد خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " اعداد خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_30',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر آیکون خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید آیکون " خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/video-camera.png'),
        ),
        array(
            'id' => 'home_v3_08',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'نمایش خدمات سفارشی شماره سه',
            'subtitle' => 'نمایش / پنهان کردن خدمات سفارشی شماره سه در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_25',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر متن خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'نفر ثبت نام',
        ),
        array(
            'id' => 'home_v3_1280',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر اعداد خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید اعداد " خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => '46/775',
        ),
        array(
            'id' => 'home_v3_16',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ متن خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " متن خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),

        array(
            'id' => 'home_v3_19',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'رنگ اعداد خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " اعداد خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_31',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تغییر تصویر خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید تصویر " خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/alarm-clock.png'),
        ),
        array(
            'id' => 'home_v3_06',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات خدمات سفارشی ',
        ),

        array(
            'id' => 'home_v3_46',
            'title' => 'نمایش خدمات سفارشی',
            'subtitle' => 'نمایش / پنهان کردن بخش خدمات سفارشی در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_47',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر تصویر پس زمینه خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید تصویر پس زمینه " خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#f22b60',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/the-tiles-bg.png'
            )
        ),
        array(
            'id' => 'home_v3_48',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر تصویر پس زمینه خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید تصویر پس زمینه " خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#08a343',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/the-tiles-bg.png'
            )
        ),
        array(
            'id' => 'home_v3_49',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر تصویر پس زمینه خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید تصویر پس زمینه " خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#e0b300',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/the-tiles-bg.png'
            )
        ),
        array(
            'id' => 'home_v3_50',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر تصویر پس زمینه خدمات سفارشی شماره چهار',
            'subtitle' => 'از این قسمت می توانید تصویر پس زمینه " خدمات سفارشی شماره چهار " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#00d6d2',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/the-tiles-bg.png'
            )
        ),
        array(
            'id' => 'home_v3_56',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر متن خدمات سفارشی شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش برنامه نویسی',
        ),
        array(
            'id' => 'home_v3_57',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر متن خدمات سفارشی شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش طراحی سایت',
        ),
        array(
            'id' => 'home_v3_58',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر متن خدمات سفارشی شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش بهبود سئو',
        ),
        array(
            'id' => 'home_v3_59',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'تغییر متن خدمات سفارشی شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" خدمات سفارشی شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آموزش کار با وردپرس',
        ),
        array(
            'id' => 'home_v3_0059',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'لینک باکس خدمات سفارشی شماره یک',
            'subtitle' => 'لینک باکس خدمات سفارشی شماره یک را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_0060',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'لینک باکس خدمات سفارشی شماره دو',
            'subtitle' => 'لینک باکس خدمات سفارشی شماره دو را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_0061',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'لینک باکس خدمات سفارشی شماره سه',
            'subtitle' => 'لینک باکس خدمات سفارشی شماره سه را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_0062',
            'required' => array('home_v3_46', '=', 'flex'),
            'title' => 'لینک باکس خدمات سفارشی شماره چهار',
            'subtitle' => 'لینک باکس خدمات سفارشی شماره چهار را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),


        array(
            'id' => 'home_v3_70',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات جداول قیمت',
        ),
        array(
            'id' => 'home_v3_71',
            'title' => 'نمایش بخش جداول قیمت',
            'subtitle' => 'نمایش / پنهان کردن بخش جداول قیمت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_87',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ عنوان بخش تعرفه خدمات',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v3_77',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن عنوان جداول قیمت',
            'subtitle' => 'از این قسمت می توانید متن" عنوان جداول قیمت " را تغییر دهید.',
            'type' => 'text',
            'default' => 'تعرفه خدمات سیگما پلاس',
        ),
        array(
            'id' => 'home_v3_86',
            'required' => array('home_v3_71', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   جدول قیمت شماره یک   ** ',
        ),
        array(
            'id' => 'home_v3_75',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'متن میانی جدول قیمت شماره یک',
            'subtitle' => 'متن میانی جدول قیمت شماره یک را در این بخش وارد کنید. ، از تگ html پشتیبانی میشود.',
            'type' => 'textarea',
            'default' => '<ul>
					  <li><i class="fal fa-check-circle"></i>یک دامنه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 6 ماهه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی تلفنی رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 24 ساعته</li>  
					  <li><i class="fal fa-check-circle"></i>استفاده یک سایت</li>  
					</ul>'
        ),

        array(
            'id' => 'home_v3_78',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن عنوان جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" عنوان جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'پلن برنزی',
        ),
        array(
            'id' => 'home_v3_79',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر عنوان جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" زیر عنوان جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ویژه کسب و کارهای کوچک',
        ),
        array(
            'id' => 'home_v3_80',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر عدد قیمت جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید عدد " قیمت جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => '99',
        ),
        array(
            'id' => 'home_v3_81',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن واحد پولی جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن " واحد پولی جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'هزار تومان',
        ),
        array(
            'id' => 'home_v3_82',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زمان جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن " زمان جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'سالانه',
        ),
        array(
            'id' => 'home_v3_83',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن دکمه خرید جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن " متن دکمه خرید جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن',
        ),
        array(
            'id' => 'home_v3_table_btn_link_t1',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'لینک دکمه خرید جدول شماره یک',
            'subtitle' => 'لینک جدول قمت شماره یک را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_84',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر دکمه خرید جدول قیمت شماره یک',
            'subtitle' => 'از این قسمت می توانید متن " متن زیر دکمه خرید جدول قیمت شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن شامل آپدیت رایگان است.',
        ),
        array(
            'id' => 'home_v3_90',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه عنوان بالایی جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " پس زمینه عنوان بالایی جدول شماره یک " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#555',)
        ),
        array(
            'id' => 'home_v3_91',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه بخش میانی جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_92',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه خرید جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f87700',)
        ),
        array(
            'id' => 'home_v3_93',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن عنوان بالایی جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " متن عنوان بالایی جدول شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_94',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن میانی جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " متن میانی جدول شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v3_95',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن دکمه خرید جدول شماره یک',
            'subtitle' => 'از این قسمت می توانید رنگ " متن دکمه خرید جدول شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_120',
            'required' => array('home_v3_71', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   جدول قیمت شماره دو   ** ',
        ),
        array(
            'id' => 'home_v3_121',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'متن میانی جدول قیمت شماره دو',
            'subtitle' => 'متن میانی جدول قیمت شماره دو را در این بخش وارد کنید. ، از تگ html پشتیبانی میشود.',
            'type' => 'textarea',
            'default' => '<ul>
					  <li><i class="fal fa-check-circle"></i>یک دامنه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 6 ماهه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی تلفنی رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 24 ساعته</li>  
					  <li><i class="fal fa-check-circle"></i>استفاده یک سایت</li>  
					</ul>'
        ),

        array(
            'id' => 'home_v3_122',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن عنوان جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" عنوان جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'پلن طلایی',
        ),
        array(
            'id' => 'home_v3_123',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر عنوان جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" زیر عنوان جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ویژه کسب و کارهای کوچک',
        ),
        array(
            'id' => 'home_v3_124',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر عدد قیمت جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید عدد " قیمت جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => '99',
        ),
        array(
            'id' => 'home_v3_125',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن واحد پولی جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن " واحد پولی جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'هزار تومان',
        ),
        array(
            'id' => 'home_v3_126',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زمان جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن " زمان جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'سالانه',
        ),
        array(
            'id' => 'home_v3_127',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن دکمه خرید جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن " متن دکمه خرید جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن',
        ),
        array(
            'id' => 'home_v3_table_btn_link_t2',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'لینک دکمه خرید جدول شماره دو',
            'subtitle' => 'لینک جدول قمت شماره دو را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_128',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر دکمه خرید جدول قیمت شماره دو',
            'subtitle' => 'از این قسمت می توانید متن " متن زیر دکمه خرید جدول قیمت شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن شامل آپدیت رایگان است.',
        ),
        array(
            'id' => 'home_v3_129',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه عنوان بالایی جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " پس زمینه عنوان بالایی جدول شماره دو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#0b7cb9',)
        ),
        array(
            'id' => 'home_v3_130',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه بخش میانی جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_131',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه خرید جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#0b7cb9',)
        ),
        array(
            'id' => 'home_v3_132',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن عنوان بالایی جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " متن عنوان بالایی جدول شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_133',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن میانی جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " متن میانی جدول شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v3_134',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن دکمه خرید جدول شماره دو',
            'subtitle' => 'از این قسمت می توانید رنگ " متن دکمه خرید جدول شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_200',
            'required' => array('home_v3_71', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   جدول قیمت شماره سه   ** ',
        ),
        array(
            'id' => 'home_v3_153',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'متن میانی جدول قیمت شماره سه',
            'subtitle' => 'متن میانی جدول قیمت شماره سه را در این بخش وارد کنید. ، از تگ html پشتیبانی میشود.',
            'type' => 'textarea',
            'default' => '<ul>
					  <li><i class="fal fa-check-circle"></i>یک دامنه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 6 ماهه رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی تلفنی رایگان</li>  
					  <li><i class="fal fa-check-circle"></i>پشتیبانی 24 ساعته</li>  
					  <li><i class="fal fa-check-circle"></i>استفاده یک سایت</li>  
					</ul>'
        ),

        array(
            'id' => 'home_v3_154',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن عنوان جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" عنوان جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'پلن نقره ای',
        ),
        array(
            'id' => 'home_v3_155',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر عنوان جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" زیر عنوان جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ویژه کسب و کارهای کوچک',
        ),
        array(
            'id' => 'home_v3_156',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر عدد قیمت جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید عدد " قیمت جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => '99',
        ),
        array(
            'id' => 'home_v3_157',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن واحد پولی جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن " واحد پولی جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'هزار تومان',
        ),
        array(
            'id' => 'home_v3_158',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زمان جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن " زمان جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'سالانه',
        ),
        array(
            'id' => 'home_v3_159',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن دکمه خرید جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن " متن دکمه خرید جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن',
        ),
        array(
            'id' => 'home_v3_table_btn_link_t3',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'لینک دکمه خرید جدول شماره سه',
            'subtitle' => 'لینک جدول قمت شماره سه را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_160',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'تغییر متن زیر دکمه خرید جدول قیمت شماره سه',
            'subtitle' => 'از این قسمت می توانید متن " متن زیر دکمه خرید جدول قیمت شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'خرید این پلن شامل آپدیت رایگان است.',
        ),
        array(
            'id' => 'home_v3_161',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه عنوان بالایی جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " پس زمینه عنوان بالایی جدول شماره سه " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#555555',)
        ),
        array(
            'id' => 'home_v3_162',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه بخش میانی جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_163',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه خرید جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان بخش تعرفه خدمات " را تغییر دهید.',
            'type' => 'color',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f87700',)
        ),
        array(
            'id' => 'home_v3_164',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن عنوان بالایی جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " متن عنوان بالایی جدول شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v3_165',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن میانی جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " متن میانی جدول شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v3_166',
            'required' => array('home_v3_71', '=', 'flex'),
            'title' => 'رنگ متن دکمه خرید جدول شماره سه',
            'subtitle' => 'از این قسمت می توانید رنگ " متن دکمه خرید جدول شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),


        array(
            'id' => 'home_v3_170',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات اسلایدر',
        ),
        array(
            'id' => 'home_v3_171',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی اسلایدر',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_172',
            'required' => array('home_v3_171', '=', 'inherit'),
            'type' => 'slides',
            'subtitle' => 'اسلایدهای موجود را از این قسمت مدیریت کنید.',
            'placeholder' => array(
                'title' => 'عنوان اسلایدر را وارد کنید.!',
                'subtitleription' => 'توضیحات اسلایدر را وارد کنید.!',
                'url' => 'لینک اسلایدر را وارد کنید.!',
            ),
        ),


        array(
            'id' => 'home_v3_301',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات فیلیپ باکس',
        ),
        array(
            'id' => 'home_v3_250',
            'title' => 'نمایش یا پنهان کردن بخش فیلیپ باکس',
            'subtitle' => 'نمایش / پنهان کردن بخش فیلیپ باکس در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_0251',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر عنوان فیلیپ باکس ',
            'subtitle' => 'از این قسمت می توانید متن" عنوان فیلیپ باکس   " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ویژگی های سیگما پلاس',
        ),
        array(
            'id' => 'home_v3_2554',
            'required' => array('home_v3_250', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   فیلیپ باکس شماره یک   ** ',
        ),
        array(
            'id' => 'home_v3_259',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر آیکون فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید آیکون فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'fal fa-photo',
        ),
        array(
            'id' => 'home_v3_251',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" عنوان فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'بازگشت وجه',
        ),
        array(
            'id' => 'home_v3_252',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ضمانت بازگشت وجه به مدت یک ماه برای تمامی محصولات بدون قید و شرط فراهم می باشد.',
        ),
        array(
            'id' => 'home_v3_253',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان پشت فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" عنوان پشت فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'عودت وجه',
        ),
        array(
            'id' => 'home_v3_254',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات پشت فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات پشت فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'در هر زمان که بخواهید کافیست یک درخواست عودت وجه ثبت کنید. تا به درخواست شما رسیدگی شود.',
        ),
        array(
            'id' => 'home_v3_2540',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن دکمه پشت فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید متن" دکمه پشت فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ثبت درخواست وجه',
        ),
        array(
            'id' => 'home_v3_2550',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'لینک دکمه فیلیپ باکس شماره یک',
            'subtitle' => 'لینک دکمه فیلیپ باکس شماره یک را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_255',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_256',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه پشت فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه پشت فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#607d8b',)
        ),
        array(
            'id' => 'home_v3_257',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ متن فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید " رنگ متن فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v3_260',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه آیکون فیلیپ باکس شماره یک',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه آیکون فیلیپ باکس شماره یک " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#4CAF50',)
        ),


        array(
            'id' => 'home_v3_2555',
            'required' => array('home_v3_250', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   فیلیپ باکس شماره دو   ** ',
        ),
        array(
            'id' => 'home_v3_276',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر آیکون فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید آیکون فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'fal fa-headphones',
        ),
        array(
            'id' => 'home_v3_266',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" عنوان فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'بازگشت وجه',
        ),
        array(
            'id' => 'home_v3_267',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ضمانت بازگشت وجه به مدت یک ماه برای تمامی محصولات بدون قید و شرط فراهم می باشد.',
        ),
        array(
            'id' => 'home_v3_268',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان پشت فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" عنوان پشت فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'عودت وجه',
        ),
        array(
            'id' => 'home_v3_269',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات پشت فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات پشت فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'در هر زمان که بخواهید کافیست یک درخواست عودت وجه ثبت کنید. تا به درخواست شما رسیدگی شود.',
        ),
        array(
            'id' => 'home_v3_270',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن دکمه پشت فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید متن" دکمه پشت فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ثبت درخواست وجه',
        ),
        array(
            'id' => 'home_v3_2551',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'لینک دکمه فیلیپ باکس شماره دو',
            'subtitle' => 'لینک دکمه فیلیپ باکس شماره دو را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_271',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_272',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه پشت فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه پشت فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#607d8b',)
        ),
        array(
            'id' => 'home_v3_273',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ متن فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید " رنگ متن فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v3_274',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه آیکون فیلیپ باکس شماره دو',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه آیکون فیلیپ باکس شماره دو " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f44336',)
        ),


        array(
            'id' => 'home_v3_2556',
            'required' => array('home_v3_250', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   فیلیپ باکس شماره سه   ** ',
        ),
        array(
            'id' => 'home_v3_290',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر آیکون فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید آیکون فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'fal fa-shopping-bag',
        ),
        array(
            'id' => 'home_v3_281',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" عنوان فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'بازگشت وجه',
        ),
        array(
            'id' => 'home_v3_282',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ضمانت بازگشت وجه به مدت یک ماه برای تمامی محصولات بدون قید و شرط فراهم می باشد.',
        ),
        array(
            'id' => 'home_v3_283',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان پشت فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" عنوان پشت فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'عودت وجه',
        ),
        array(
            'id' => 'home_v3_284',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات پشت فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات پشت فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'در هر زمان که بخواهید کافیست یک درخواست عودت وجه ثبت کنید. تا به درخواست شما رسیدگی شود.',
        ),
        array(
            'id' => 'home_v3_285',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن دکمه پشت فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید متن" دکمه پشت فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ثبت درخواست وجه',
        ),
        array(
            'id' => 'home_v3_2552',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'لینک دکمه فیلیپ باکس شماره سه',
            'subtitle' => 'لینک دکمه فیلیپ باکس شماره سه را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_286',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_287',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه پشت فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه پشت فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#607d8b',)
        ),
        array(
            'id' => 'home_v3_288',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ متن فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید " رنگ متن فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777',
        ),
        array(
            'id' => 'home_v3_289',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه آیکون فیلیپ باکس شماره سه',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه آیکون فیلیپ باکس شماره سه " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#FF9800',)
        ),

        array(
            'id' => 'home_v3_2557',
            'required' => array('home_v3_250', '=', 'flex'),
            'type' => 'button_set',
            'title' => '**   فیلیپ باکس شماره چهار   ** ',
        ),
        array(
            'id' => 'home_v3_300',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر آیکون فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید آیکون فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'fal fa-html5 ',
        ),

        array(
            'id' => 'home_v3_292',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" عنوان فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'بازگشت وجه',
        ),
        array(
            'id' => 'home_v3_293',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ضمانت بازگشت وجه به مدت یک ماه برای تمامی محصولات بدون قید و شرط فراهم می باشد.',
        ),
        array(
            'id' => 'home_v3_294',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن عنوان پشت فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" عنوان پشت فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'عودت وجه',
        ),
        array(
            'id' => 'home_v3_295',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن توضیحات پشت فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" توضیحات پشت فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'در هر زمان که بخواهید کافیست یک درخواست عودت وجه ثبت کنید. تا به درخواست شما رسیدگی شود.',
        ),
        array(
            'id' => 'home_v3_296',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر متن دکمه پشت فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید متن" دکمه پشت فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'text',
            'default' => 'ثبت درخواست وجه',
        ),
        array(
            'id' => 'home_v3_2553',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'لینک دکمه فیلیپ باکس شماره چهار',
            'subtitle' => 'لینک دکمه فیلیپ باکس شماره چهار را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v3_297',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'home_v3_2970',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه پشت فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه پشت فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#607d8b',)
        ),
        array(
            'id' => 'home_v3_298',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ متن فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید " رنگ متن فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v3_299',
            'required' => array('home_v3_250', '=', 'flex'),
            'title' => 'تغییر رنگ پس زمینه آیکون فیلیپ باکس شماره چهار',
            'subtitle' => 'از این قسمت می توانید " رنگ پس زمینه آیکون فیلیپ باکس شماره چهار " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#00bcd4',)
        ),


        array(
            'id' => 'home_v3_362',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات آخرین مطالب سایت',
        ),
        array(
            'id' => 'home_v3_350',
            'title' => 'نمایش یا پنهان کردن بخش آخرین مطالب آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_361',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تغییر متن آخرین مطالب آموزشی سایت',
            'subtitle' => 'از این قسمت می توانید متن" عنوان این باکس " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین مطالب آموزشی سایت',
        ),
        array(
            'id' => 'home_v2_11001',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تعداد مطلب نمایشی در بخش آخرین مطالب آموزشی سایت',
            'subtitle' => 'از این قسمت می توانید تعداد آخرین مطالب آموزشی سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '10'
        ),
        array(
            'id' => 'home_v2_11002',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => ' دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید ت دسته بندی دلخواه برای نمایش در بخش آخرین مطالب آموزشی سایت را مشخص کنید. در صورت عدم انتخاب هیچ دسته بندی تمامی دسته بندی ها نمایش داده میشود.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v3_352',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن توضیحات مطالب آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش عنوان مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_353',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن دکمه " ادامه مطلب " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش دکمه " ادامه مطلب " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_354',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تاریخ انتشار " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تاریخ انتشار " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_355',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " بخش نظرات " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " بخش نظرات " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_356',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تصویر نویسنده " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تصویر نویسنده " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_357',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان اصلی',
            'subtitle' => 'از این قسمت میتوانید عنوان بخش را تغییر دهید.',
            'type' => 'color',
            'default' => '#666666',
        ),
        array(
            'id' => 'home_v3_358',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ عنوان مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'home_v3_359',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تغییر رنگ توضیحات مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ توضیحات مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v3_360',
            'required' => array('home_v3_350', '=', 'flex'),
            'title' => 'تغییر رنگ دکمه ادامه مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ دکمه ادامه مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#e92b5f',
        ),


        array(
            'id' => 'home_v3_500',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v3'),
            'title' => ' تنظیمات آخرین محصولات آموزشی سایت',
        ),
        array(
            'id' => 'home_v3_501',
            'title' => 'نمایش یا پنهان کردن بخش آخرین محصولات آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین محصولات آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_520',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'آخرین محصولات آموزشی سایت',
            'subtitle' => 'از این قسمت می توانید متن" عنوان این باکس " را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین محصولات آموزشی سایت',
        ),
        array(
            'id' => 'home_v3_5000',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تعداد محصول نمایشی در بخش آخرین محصولات آموزشی سایت',
            'subtitle' => 'از این قسمت می توانید تعداد آخرین محصولات را مشخص کنید.',
            'type' => 'text',
            'default' => '9'
        ),
        array(
            'id' => 'home_v3_10002',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => ' دسته بندی دلخواه برای نمایش در بخش آخرین محصولات آموزشی سایت',
            'subtitle' => 'از این قسمت می توانید ت دسته بندی دلخواه برای نمایش در بخش آخرین محصولات آموزشی سایت را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'args' => array(
                'taxonomy' => 'product_cat',
            ),
            'default' => '17'
        ),
        array(
            'id' => 'home_v3_503',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن توضیحات محصولات آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش عنوان محصولات آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_504',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن دکمه " خرید آنلاین محصول " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش دکمه " خرید آنلاین محصول "  در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_505',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تصویر محصولات " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تصویر محصولات " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_506',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " تعداد بازدید " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " تعداد بازدید " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_507',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " قیمت محصول در بالای تصویر " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " قیمت محصول در بالای تصویر " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_508',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'نمایش یا پنهان کردن " قیمت محصول در پایین تصویر " آموزشی سایت ',
            'subtitle' => 'نمایش / پنهان کردن بخش " قیمت محصول در پایین تصویر " مطالب آموزشی سایت در صفحه اصلی سه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v3_510',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان اصلی',
            'subtitle' => 'از این قسمت میتوانید عنوان بخش را تغییر دهید.',
            'type' => 'color',
            'default' => '#666666',
        ),
        array(
            'id' => 'home_v3_511',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تغییر رنگ عنوان مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ عنوان مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'home_v3_512',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تغییر رنگ توضیحات مطالب',
            'subtitle' => 'از این قسمت می توانید " رنگ توضیحات مطالب " را تغییر دهید.',
            'type' => 'color',
            'default' => '#777777',
        ),
        array(
            'id' => 'home_v3_513',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تغییر رنگ دکمه خرید آنلاین',
            'subtitle' => 'از این قسمت می توانید " دکمه خرید آنلاین " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'required' => array('home_v3_71', '=', 'inherit'),
            'default' => array(
                'background-color' => '#00beaf'),
        ),
        array(
            'id' => 'home_v3_514',
            'required' => array('home_v3_501', '=', 'flex'),
            'title' => 'تغییر رنگ متن قیمت محصولات',
            'subtitle' => 'از این قسمت می توانید "رنگ متن قیمت محصولات " را تغییر دهید.',
            'type' => 'color',
            'default' => '#000000'
        ),


        /**
         *************** Start home4 Setting ***************
         */


        array(
            'id' => 'heaader_v3_010003',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات بخش جستجو در صفحه اصلی چهار',
        ),
        array(
            'id' => 'searcharea_active',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی بخش جستجوی ابتدایی',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'box_1__icon_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر آیکون باکس شماره یک زیر جستجو',
            'subtitle' => 'از این قسمت می توانید آیکون باکس شماره یک را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => ' fal fa-download',
        ),
        array(
            'id' => 'box_1__text_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر متن باکس شماره یک زیر جستجو',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان باکس شماره یک قرار دهید.. ',
            'type' => 'text',
            'default' => 'دانلود رایگان',
        ),
        array(
            'id' => 'register_link_1v4_homepage',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'لینک دلخواه برای باکس شماره یک',
            'type' => 'text',
            'validate' => 'url', 'subtitle' => 'از این بخش می توانید لینک دلخواه برای این باکس را وارد کنید..',
            'default' => '' . get_site_url() . '/product-category/books'
        ),
        array(
            'id' => 'box_2__icon_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر آیکون باکس شماره دو زیر جستجو',
            'subtitle' => 'از این قسمت می توانید آیکون باکس شماره دو را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => ' fal fa-user-graduate',
        ),
        array(
            'id' => 'box_2__text_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر متن باکس شماره دو زیر جستجو',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان باکس شماره دو قرار دهید.. ',
            'type' => 'text',
            'default' => 'آموزش رایگان',
        ),
        array(
            'id' => 'register_link_2v4_homepage',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'لینک دلخواه برای باکس شماره دو',
            'type' => 'text',
            'validate' => 'url',
            'subtitle' => 'از این بخش می توانید لینک دلخواه برای این باکس را وارد کنید..',
            'default' => '' . get_site_url() . '/product-category/packeges'
        ),
        array(
            'id' => 'box_3__icon_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر آیکون باکس شماره سه زیر جستجو',
            'subtitle' => 'از این قسمت می توانید آیکون باکس شماره سه را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => ' fal fa-paperclip',
        ),
        array(
            'id' => 'box_3__text_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر متن باکس شماره سه زیر جستجو',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان باکس شماره سه قرار دهید.. ',
            'type' => 'text',
            'default' => 'کتاب رایگان',
        ),
        array(
            'id' => 'register_link_3v4_homepage',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'لینک دلخواه برای باکس شماره سه',
            'type' => 'text',
            'validate' => 'url',
            'subtitle' => 'از این بخش می توانید لینک دلخواه برای این باکس را وارد کنید..',
            'default' => '' . get_site_url() . '/product-category/class'
        ),
        array(
            'id' => 'box_4__icon_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر آیکون باکس شماره چهار زیر جستجو',
            'subtitle' => 'از این قسمت می توانید آیکون باکس شماره چهار را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => ' fal fa-play',
        ),
        array(
            'id' => 'box_4__text_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر متن باکس شماره چهار زیر جستجو',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان باکس شماره چهار قرار دهید.. ',
            'type' => 'text',
            'default' => 'ویدئوی آموزشی',
        ),
        array(
            'id' => 'register_link_4v4_homepage',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'لینک دلخواه برای باکس شماره چهار',
            'type' => 'text',
            'validate' => 'url',
            'subtitle' => 'از این بخش می توانید لینک دلخواه برای این باکس را وارد کنید..',
            'default' => '' . get_site_url() . '/product-category/videos'
        ),
        array(
            'id' => 'box_5__icon_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر آیکون باکس شماره پنج زیر جستجو',
            'subtitle' => 'از این قسمت می توانید آیکون باکس شماره پنج را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => ' fal fa-unlock',
        ),
        array(
            'id' => 'box_5__text_right_v4',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'تغییر متن باکس شماره پنج زیر جستجو',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان باکس شماره پنج قرار دهید.. ',
            'type' => 'text',
            'default' => 'محتوای ویژه',
        ),
        array(
            'id' => 'register_link_5v4_homepage',
            'required' => array('searcharea_active', '=', 'inherit'),
            'title' => 'لینک دلخواه برای باکس شماره پنج',
            'type' => 'text',
            'validate' => 'url',
            'subtitle' => 'از این بخش می توانید لینک دلخواه برای این باکس را وارد کنید..',
            'default' => '' . get_site_url() . '/product-category/videos'
        ),

        array(
            'id' => 'homepage_101',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات محصولات پرفروش',
        ),
        array(
            'id' => 'hiden_box1_v4',
            'title' => 'نمایش بخش محصولات پرفروش',
            'subtitle' => 'نمایش / پنهان کردن بخش محصولات پرفروش در صفحه اصلی چهار',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'hiden_more_bot_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'دکمه مشاهده محصولات بیشتر',
            'subtitle' => 'نمایش / پنهان کردن دکمه مشاهده محصولات بیشتر در بخش محصولات پرفروش',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'box_1__text_more_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'required' => array('hiden_more_bot_v4', '=', 'inherit'),
            'title' => 'تغییر متن دکمه " مشاهده محصولات بیشتر "',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را دکمه " مشاهده محصولات بیشتر " در بخش محصولات پرفروش قرار دهید.. ',
            'type' => 'text',
            'default' => 'مشاهده محصولات بیشتر',
        ),
        array(
            'id' => 'box_1__link_more_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'required' => array('hiden_more_bot_v4', '=', 'inherit'),
            'title' => 'لینک دکمه مطالب بیشتر',
            'subtitle' => 'لینک دکمه مطالب بیشتر را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'cat_1_title_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر عنوان بخش محبوب ترین محصولات',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان بخش محبوب ترین محصولات قرار دهید.. ',
            'type' => 'text',
            'default' => 'محبوب ترین محصولات',
        ),
        array(
            'id' => 'cat_1_subtitle_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر زیر عنوان بخش محبوب ترین محصولات',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای زیر عنوان بخش محبوب ترین محصولات قرار دهید.. ',
            'type' => 'text',
            'default' => 'Best Selling Products',
        ),
        array(
            'id' => 'cat_1_id_v4',
            'title' => 'دسته بندی محصولات پرفروش',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'subtitle' => 'در این قسمت شناسه یا  یک دسته بندی دلخواه را وارد نمایید. توجه فرمایید در این بخش محصولات پرفروش دسته بندی انتخابی شما نمایش داده می شود.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'args' => array(
                'taxonomy' => 'product_cat',
            ),
            'default' => '17'
        ),
        array(
            'id' => 'cat_1_num_prod_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تعداد محصول برای نمایش در بخش محصولات پرفروش',
            'subtitle' => 'در این قسمت تعداد محصول نمایش داده شده در این بخش را وارد نمایید.',
            'type' => 'text',
            'default' => '12',
        ),
        array(
            'id' => 'cat_1_title_color_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان بخش محبوب ترین محصولات',
            'subtitle' => 'رنگ عنوان بخش محبوب ترین محصولات را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'cat_1_subtitle_color_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر رنگ زیر عنوان بخش محبوب ترین محصولات',
            'subtitle' => 'رنگ زیر عنوان بخش محبوب ترین محصولات را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'cat_1_title_prod_color_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان محصول در بخش محبوب ترین محصولات',
            'subtitle' => 'رنگ عنوان محصول در بخش محبوب ترین محصولات را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'cat_1_subtitle_prod_color_v4',
            'required' => array('hiden_box1_v4', '=', 'inherit'),
            'title' => 'تغییر رنگ توضیحات محصول در بخش محبوب ترین محصولات',
            'subtitle' => 'رنگ توضیحات محصول در بخش محبوب ترین محصولات را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),


        array(
            'id' => 'homepage_102',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات اسلایدر',
        ),
        array(
            'id' => 'slider_1_target_v4',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی اسلایدر',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'slider_one_show_v4',
            'required' => array('slider_1_target_v4', '=', 'inherit'),
            'type' => 'slides',
            'subtitle' => 'اسلایدهای موجود را از این قسمت مدیریت کنید.',
            'placeholder' => array(
                'title' => 'عنوان اسلایدر را وارد کنید.!',
                'subtitleription' => 'توضیحات اسلایدر را وارد کنید.!',
                'url' => 'لینک اسلایدر را وارد کنید.!',
            ),
        ),


        array(
            'id' => 'homepage_103',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات آخرین مطالب',
        ),
        array(
            'id' => 'home_v4_1',
            'title' => 'نمایش بخش آخرین مطالب سایت',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین مطالب سایت در صفحه اصلی چهار',
            'type' => 'button_set',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v44_title',
            'title' => 'تغییر عنوان آخرین مطالب سایت',
            'required' => array('home_v4_1', '=', 'flex'),
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'آخرین مطالب سایت'
        ),
        array(
            'id' => 'home_v44_subtitle',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'تغییر زیر عنوان آخرین آموزش های سایت',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'Last Blog Posts'
        ),
        array(
            'id' => 'home_v4_1100001',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'تعداد مطالب جهت نمایش در این بخش',
            'subtitle' => 'از این قسمت می توانید تعداد  مطالب سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '8'
        ),
        array(
            'id' => 'home_v4_1100002',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => ' دسته بندی دلخواه برای نمایش ',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در این بخش را مشخص کنید. در صورت عدم انتخاب هیچ دسته بندی تمامی دسته بندی ها نمایش داده میشود.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v4_4',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'نمایش دکمه " مطالب بیشتر وبلاگ " در بخش آخرین مطالب سایت',
            'subtitle' => 'نمایش / پنهان کردن دکمه " مطالب بیشتر وبلاگ " در بخش آخرین مطالب سایت در صفحه اصلی چهار',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'post_date_v3_d4',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'نمایش تاریخ ارسال مطالب ',
            'subtitle' => 'نمایش / پنهان کردن تاریخ ارسال مطالب این بخش را مشخص کنید!',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'post_views_v3_d4',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'نمایش تعداد بازدید مطالب ',
            'subtitle' => 'نمایش / پنهان کردن تعداد بازدید مطالب این بخش را مشخص کنید!',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v44_btn_title',
            'required' => array('home_v4_1', '=', 'flex'),
            'required' => array('home_v4_4', '=', 'inherit'),
            'title' => 'تغییر متن دکمه مطالب بیشتر وبلاگ',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'مطالب بیشتر وبلاگ'
        ),
        array(
            'id' => 'home_v44_btn',
            'required' => array('home_v4_1', '=', 'flex'),
            'required' => array('home_v4_4', '=', 'inherit'),
            'title' => 'لینک دکمه مطالب بیشتر',
            'subtitle' => 'لینک دکمه مطالب بیشتر را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . ''
        ),
        array(
            'id' => 'home_v4_12',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ عنوان آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_13',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ زیر عنوان آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " زیر عنوان آخرین مطالب سایت" را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_14',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ متن دکمه مطالب بیشتر وبلاگ',
            'subtitle' => 'از این قسمت می توانید رنگ " متن دکمه مطالب بیشتر وبلاگ " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v4_15',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ پس زمینه دکمه مطالب بیشتر وبلاگ',
            'subtitle' => 'از این قسمت می توانید رنگ " پس زمینه دکمه مطالب بیشتر وبلاگ " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#b5b5b5',)
        ),
        array(
            'id' => 'home_v4_16',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ متن عنوان آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " متن عنوان آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v4_17',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ توضیحات آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " توضیحات آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#999'
        ),
        array(
            'id' => 'home_v4_19',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ تعداد بازدید آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " تاریخ آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#999'
        ),
        array(
            'id' => 'home_v4_20',
            'required' => array('home_v4_1', '=', 'flex'),
            'title' => 'رنگ نام نویسنده آخرین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " نام نویسنده آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),


        array(
            'id' => 'home_v4_41',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات آخرین محصولات سایت',
        ),
        array(
            'id' => 'home_v4_42',
            'title' => 'نمایش بخش آخرین محصولات سایت',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین محصولات سایت در صفحه اصلی چهار',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v4_55',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'دسته بندی آخرین محصولات سایت',
            'subtitle' => 'دسته بندی مورد نظر را برای نمایش آخرین محصولات سایت انتخاب کنید!',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'args' => array(
                'taxonomy' => 'product_cat',
            ),
            'default' => '17'
        ),
        array(
            'id' => 'home_v4_56',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تعداد محصول برای نمایش در بخش آخرین محصولات سایت',
            'subtitle' => 'در این قسمت تعداد محصول نمایش داده شده در این بخش را وارد نمایید.',
            'type' => 'text',
            'default' => '10',
        ),
        array(
            'id' => 'home_v4_49',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر عنوان بخش آخرین محصولات سایت',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای عنوان بخش آخرین محصولات سایت قرار دهید.. ',
            'type' => 'text',
            'default' => 'آخرین محصولات سایت',
        ),
        array(
            'id' => 'home_v4_50',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر زیر عنوان بخش آخرین محصولات سایت',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را برای زیر عنوان بخش آخرین محصولات سایت قرار دهید.. ',
            'type' => 'text',
            'default' => 'Best Selling Products',
        ),
        array(
            'id' => 'home_v4_71',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'دکمه اضافه کردن محصول به سبد خرید',
            'subtitle' => 'نمایش / پنهان کردن دکمه اضافه کردن محصول به سبد خرید در بخش آخرین محصولات سایت',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v4_72',
            'required' => array('home_v4_42', '=', 'inherit'),
            'required' => array('home_v4_71', '=', 'inherit'),
            'title' => 'تغییر متن دکمه " اضافه کردن محصول به سبد خرید "',
            'subtitle' => 'از این قسمت می توانید متن دلخواهی را دکمه " اضافه کردن محصول به سبد خرید " در بخش آخرین محصولات سایت قرار دهید.. ',
            'type' => 'text',
            'default' => 'اضافه کردن محصول به سبد خرید',
        ),
        array(
            'id' => 'home_v4_51',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان بخش آخرین محصولات سایت',
            'subtitle' => 'رنگ عنوان بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_52',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ زیر عنوان بخش آخرین محصولات سایت',
            'subtitle' => 'رنگ زیر عنوان بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_53',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان محصول در بخش آخرین محصولات سایت',
            'subtitle' => 'رنگ عنوان محصول در بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_54',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ توضیحات محصول در بخش آخرین محصولات سایت',
            'subtitle' => 'رنگ توضیحات محصول در بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v4_999',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ پس زمینه دکمه اضافه کردن محصول به سبد خرید',
            'subtitle' => 'رنگ پس زمینه دکمه اضافه کردن محصول به سبد خرید در بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fcfcfc',)
        ),
        array(
            'id' => 'home_v4_998',
            'required' => array('home_v4_42', '=', 'inherit'),
            'title' => 'تغییر رنگ متن دکمه اضافه کردن محصول به سبد خرید',
            'subtitle' => 'رنگ متن دکمه اضافه کردن محصول به سبد خرید در بخش آخرین محصولات سایت را انتخاب کنید..',
            'type' => 'color',
            'default' => '#3e3e3e'
        ),


        array(
            'id' => 'home_v4_80',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات خدمات سفارشی',
        ),
        array(
            'id' => 'home_v4_79',
            'title' => 'نمایش باکس خدمات سفارشی',
            'subtitle' => 'نمایش / مخفی سازی باکس خدمات سفارشی',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v4_81',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'آیکون باکس یک خدمات سفارشی',
            'subtitle' => 'تصویر آیکون باکس یک باکس خدمات سفارشی را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 64*64',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/code.png'),
        ),
        array(
            'id' => 'home_v4_82',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'عنوان باکس یک خدمات سفارشی',
            'subtitle' => 'عنوان باکس یک خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'طراحی استاندارد'
        ),
        array(
            'id' => 'home_v4_83',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'زیرعنوان باکس یک خدمات سفارشی',
            'subtitle' => 'زیرعنوان باکس یک خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'طرح های ارائه شده'
        ),
        array(
            'id' => 'home_v4_84',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان باکس یک خدمات سفارشی',
            'subtitle' => 'عنوان باکس یک خدمات سفارشی را وارد کنید..',
            'type' => 'color',
            'default' => '#777'
        ),
        array(
            'id' => 'home_v4_85',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ زیرعنوان باکس یک خدمات سفارشی',
            'subtitle' => 'یک رنگ دلخواه برای متن زیرعنوان باکس یک خدمات سفارشی را وارد کنید.',
            'type' => 'color',
            'default' => '#d4a44e'
        ),
        array(
            'id' => 'home_v4_90',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'آیکون باکس دو خدمات سفارشی',
            'subtitle' => 'تصویر آیکون باکس دو باکس خدمات سفارشی را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 64*64',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/qr-code.png'),
        ),
        array(
            'id' => 'home_v4_91',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'عنوان باکس دو خدمات سفارشی',
            'subtitle' => 'عنوان باکس دو خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'بازگشت وجه'
        ),
        array(
            'id' => 'home_v4_92',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'زیرعنوان باکس دو خدمات سفارشی',
            'subtitle' => 'زیرعنوان باکس دو خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'تا یک هفته از خرید'
        ),
        array(
            'id' => 'home_v4_93',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان باکس دو خدمات سفارشی',
            'type' => 'color',
            'default' => '#777'
        ),
        array(
            'id' => 'home_v4_94',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ زیرعنوان باکس دو خدمات سفارشی',
            'subtitle' => 'یک رنگ دلخواه برای متن زیرعنوان باکس دو خدمات سفارشی را وارد کنید.',
            'type' => 'color',
            'default' => '#d4a44e'
        ),
        array(
            'id' => 'home_v4_95',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'آیکون باکس سه خدمات سفارشی',
            'subtitle' => 'تصویر آیکون باکس سه باکس خدمات سفارشی را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 64*64',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/purchase.png'),
        ),
        array(
            'id' => 'home_v4_96',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'عنوان باکس سه خدمات سفارشی',
            'subtitle' => 'عنوان باکس سه خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'نصب آسان'
        ),
        array(
            'id' => 'home_v4_97',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'زیرعنوان باکس سه خدمات سفارشی',
            'subtitle' => 'زیرعنوان باکس سه خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'در تمامی هاست ها'
        ),
        array(
            'id' => 'home_v4_98',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان باکس سه خدمات سفارشی',
            'type' => 'color',
            'default' => '#777'
        ),
        array(
            'id' => 'home_v4_99',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ زیرعنوان باکس سه خدمات سفارشی',
            'subtitle' => 'یک رنگ دلخواه برای متن زیرعنوان باکس سه خدمات سفارشی را وارد کنید.',
            'type' => 'color',
            'default' => '#d4a44e'
        ),
        array(
            'id' => 'home_v4_100',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'آیکون باکس چهار خدمات سفارشی',
            'subtitle' => 'تصویر آیکون باکس چهار باکس خدمات سفارشی را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 64*64',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/saving.png'),
        ),
        array(
            'id' => 'home_v4_101',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'عنوان باکس چهار خدمات سفارشی',
            'subtitle' => 'عنوان باکس چهار خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'پرداخت مطمئن'
        ),
        array(
            'id' => 'home_v4_102',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'زیرعنوان باکس چهار خدمات سفارشی',
            'subtitle' => 'زیرعنوان باکس چهار خدمات سفارشی را وارد کنید..',
            'type' => 'text',
            'default' => 'با کلیه کارت های شتاب'
        ),
        array(
            'id' => 'home_v4_103',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ عنوان باکس چهار خدمات سفارشی',
            'type' => 'color',
            'default' => '#777'
        ),
        array(
            'id' => 'home_v4_104',
            'required' => array('home_v4_79', '=', 'inherit'),
            'title' => 'تغییر رنگ زیرعنوان باکس چهار خدمات سفارشی',
            'subtitle' => 'یک رنگ دلخواه برای متن زیرعنوان باکس چهار خدمات سفارشی را وارد کنید.',
            'type' => 'color',
            'default' => '#d4a44e'
        ),


        array(
            'id' => 'home_v44_80',
            'type' => 'section',
            'indent' => true,
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v4'),
            'title' => ' تنظیمات محبوب ترین مطالب سایت',
        ),
        array(
            'id' => 'home_v44_1',
            'title' => 'نمایش بخش محبوب ترین مطالب سایت',
            'subtitle' => 'نمایش / پنهان کردن بخش آخرین محبوب ترین سایت در صفحه اصلی چهار',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v44_801',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'تغییر عنوان محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'محبوب ترین مطالب سایت'
        ),
        array(
            'id' => 'home_v44_802',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'تغییر زیر عنوان پربازدید ترین آموزش های سایت',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'Most Popular Posts'
        ),
        array(
            'id' => 'home_v44_803',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'تغییر متن دکمه مطالب بیشتر وبلاگ',
            'subtitle' => 'از این قسمت می توانید این متن را تغییر دهید.',
            'type' => 'text',
            'default' => 'مطالب بیشتر وبلاگ'
        ),
        array(
            'id' => 'home_v44_8003',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'لینک دکمه مطالب بیشتر',
            'subtitle' => 'لینک دکمه مطالب بیشتر را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'home_v4_1102',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'دسته بندی دلخواه برای نمایش در بخش محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید دسته بندی دلخواه برای نمایش در بخش آخرین مطالب سایت را مشخص کنید.',
            'type' => 'select',
            'multi' => true,
            'data' => 'categories',
            'default' => '43'
        ),
        array(
            'id' => 'home_v4_11001',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'تعداد محصول نمایشی در بخش محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید تعداد محبوب ترین مطالب سایت را مشخص کنید.',
            'type' => 'text',
            'default' => '9'
        ),
        array(
            'id' => 'post_date_v3_d5',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'نمایش تاریخ ارسال مطالب ',
            'subtitle' => 'نمایش / پنهان کردن تاریخ ارسال مطالب این بخش را مشخص کنید!',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'post_views_v3_d5',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'نمایش تعداد بازدید مطالب ',
            'subtitle' => 'نمایش / پنهان کردن تعداد بازدید این بخش را مشخص کنید!',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'home_v44_12',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'رنگ عنوان محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " عنوان محبوب ترین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v44_13',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'رنگ زیر عنوان محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " زیر عنوان محبوب ترین مطالب سایت" را تغییر دهید.',
            'type' => 'color',
            'default' => '#666'
        ),
        array(
            'id' => 'home_v44_14',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'رنگ متن دکمه مطالب بیشتر وبلاگ',
            'subtitle' => 'از این قسمت می توانید رنگ " متن دکمه مطالب بیشتر وبلاگ " را تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'home_v44_16',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'رنگ متن عنوان محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " متن عنوان آخرین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#333'
        ),
        array(
            'id' => 'home_v44_19',
            'required' => array('home_v44_1', '=', 'inherit'),
            'title' => 'رنگ تعداد بازدید محبوب ترین مطالب سایت',
            'subtitle' => 'از این قسمت می توانید رنگ " تاریخ محبوب ترین مطالب سایت " را تغییر دهید.',
            'type' => 'color',
            'default' => '#999'
        ),


    ),
));


// -> START Header Setting

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات هدر',
    'id' => 'headers',
    'class' => 'blur-panel',
    'customizer_width' => '400px',
    'icon' => 'el el-list',
    'fields' => array(
        array(
            'id' => 'def_header_all_pages_activator',
            'title' => 'فعال سازی هدر های سفارشی',
            'subtitle' => 'با فعال سازی این بخش هدر هایی که با المنتور طراحی شده است به عنوان هدر پیشفرض تمامی صفحاتی که هدر آن ها در حالت پیشفرض باشد نمایش داده خواهد شد.',
            'type' => 'button_set',
            'default' => 'disable',
             'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'header_style_page',
            'type' => 'select',
            'title' => 'طرح هدر پیش ساخته',
            'subtitle'      => 'یک هدر از بین ۳ هدر پیش ساخته برای هدر انتخاب کنید. توصیه ما استفاده از هدر های ساخته شده با المنتور است.',
            'options' => array(
                'template-part/headers/header-v1' => 'استایل یک',
                'template-part/headers/header-v2' => 'استایل دو',
                'template-part/headers/header-v3' => 'استایل سه',
            ),
            'default' => 'template-part/headers/header-v1',
            'required' => array('def_header_all_pages_activator', '=', 'disable'),
        ),
        array(
        'id'       => 'def_header_all_pages',
        'type'     => 'select',
        'multi'    => false,
        'data'     => 'posts',
        'args'     => array( 'post_type' =>  array( 'sigma-header' ), 'numberposts' => -1 ),
        'title'    => 'هدر پیش فرض صغحات',
        'subtitle' => 'لیست تمامی هدر های ایجاد شده با سیستم هدر ساز سیگما پلاس در مقابل نمایش داده میشود شما میتوانید یک هدر را انتخاب کنید.',
        'default'  => 'null' ,  
            'required' => array('def_header_all_pages_activator', '=', 'enable'),

        ),        
        array(
            'id' => 'heaader_public_setting_section',
            'type' => 'section',
            'indent' => true,
            'title' => ' تنظیمات عمومی هدر سایت',
        ),
        array(
            'id' => 'fix_menu_active',
            'title' => 'منوی چسبان سایت',
            'type' => 'button_set',
            'default' => 'inherit',
            'subtitle' => 'این بخش میتوانید منوی چسبان سایت را فعال یا غیرفعال کنید.',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'class' => 'dnone_v5'
        ),
        array(
            'id' => 'serch_text',
            'title' => 'متن باکس جستجوی هدر',
            'subtitle' => 'شما میتوانید آدرس ایمیل موجود در هدر را از این قسمت مدیریت کنید..',
            'type' => 'text',
            'default' => 'دنبال چی میگردی؟',
            'class' => 'dnone_v5'
        ),
        array(
            'id' => 'register_text_v1_homepage',
            'title' => 'متن دکمه عضویت',
            'type' => 'text',
            'subtitle' => 'از این بخش می توانید متن دکمه عضویت را وارد کنید..',
            'class' => 'dnone_v5',
            'default' => 'عضویت در سایت'
        ),
        array(
            'id' => 'login_text_v1_homepage',
            'title' => 'متن دکمه ورود',
            'type' => 'text',
            'subtitle' => 'از این بخش می توانید متن دکمه ورود را وارد کنید..',
            'class' => 'dnone_v5',
            'default' => 'ورود در سایت'
        ),
        array(
            'id' => 'phone',
            'title' => 'شماره تماس هدر',
            'subtitle' => 'شما میتوانید شماره تماس موجود در هدر را از این قسمت مدیریت کنید..',
            'class' => 'dnone_v5',
            'type' => 'text',
            'default' => '021-33223652'
        ),
        array(
            'id' => 'email_head',
            'title' => 'آدرس ایمیل هدر',
            'subtitle' => 'شما میتوانید آدرس ایمیل موجود در هدر را از این قسمت مدیریت کنید..',
            'class' => 'dnone_v5',
            'type' => 'text',
            'default' => 'info@hamkarwp.com'
        ),
        array(
            'id' => 'heaader_v1_032',
            'title' => 'تغییر آیکون آدرس ایمیل ',
            'subtitle' => 'از این قسمت می توانید آیکون " آدرس ایمیل " را در هدر تغییر دهید.',
            'class' => 'dnone_v5',
            'type' => 'text',
            'default' => 'fal fa-envelope'
        ),
        array(
            'id' => 'heaader_v1_033',
            'title' => 'تغییر آیکون شماره تلفن ',
            'subtitle' => 'از این قسمت می توانید آیکون " شماره تلفن " را در هدر تغییر دهید.',
            'class' => 'dnone_v5',
            'type' => 'text',
            'default' => 'fal fa-phone'
        ),
        array(
            'id' => 'heaader_v1_00001',
            'type' => 'section',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v1'),
            'class' => 'dnone_v5',
            'title' => ' تنظیمات بخش عمومی هدر سبک یک',
        ),
        array(
            'id' => 'logo',
            'title' => 'لوگو',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'class' => 'dnone_v5',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/shoppage_logo.png'),
        ),
        array(
            'id' => 'register_link_v1_homepage',
            'title' => 'برگه دکمه عضویت در هدر سبک یک',
            'type' => 'select',
            'data' => 'pages',
            'default' => '' . get_site_url() . '/?p=1771',
            'subtitle' => 'از این بخش می توانید برگه دکمه عضویت را وارد کنید..',
            'class' => 'dnone_v5',
        ),
        array(
            'id' => 'login_link_v1_homepage',
            'title' => 'برگه ورود در هدر سبک یک',
            'type' => 'select',
            'data' => 'pages',
            'default' => '' . get_site_url() . '/?p=1770',
            'subtitle' => 'از این بخش می توانید لینک برگه ورود را وارد کنید..',
            'class' => 'dnone_v5',
        ),


        array(
            'id' => 'heaader_v1_003',
            'type' => 'section',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v1'),
            'class' => 'dnone_v5',
            'title' => ' مدیریت نمایش / پنهان بخش ها در هدر سبک یک',
        ),
        array(
            'id' => 'heaader_v1_10005',
            'title' => 'بخش تاپ بار در هدر سبک یک',
            'type' => 'button_set',
            'default' => 'inherit',
            'subtitle' => 'از این بخش می توانید تاپ بار  را نمایش یا پنهان کنید..',
            'class' => 'dnone_v5',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0006',
            'title' => 'نمایش ایمیل در تاپ بار',
            'type' => 'button_set',
            'default' => 'inline',
            'subtitle' => 'از این بخش می توانید ایمیل را درتاپ بار نمایش یا پنهان کنید..',
            'class' => 'dnone_v5',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0007',
            'title' => 'نمایش شماره تلفن در تاپ بار',
            'type' => 'button_set',
            'default' => 'inline',
            'subtitle' => 'از این بخش می توانید شماره تلفن در تاپ بار را نمایش یا پنهان کنید..',
            'class' => 'dnone_v5',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0010',
            'title' => 'نمایش باکس جستجو در هدر ',
            'type' => 'button_set',
            'default' => 'inherit',
            'subtitle' => 'از این بخش می توانید باکس جستجو در هدر را نمایش یا پنهان کنید..',
            'class' => 'dnone_v5',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0011',
            'title' => 'نمایش باکس پنل کاربری در هدر ',
            'type' => 'button_set',
            'default' => 'inline',
            'subtitle' => 'از این بخش می توانید باکس پنل کاربری در هدر را نمایش یا پنهان کنید..',
            'class' => 'dnone_v5',
            'required' => array('heaader_v1_003', '=', 'inherit'),
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),


        array(
            'id' => 'heaader_v1_004',
            'type' => 'section',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v1'),
            'class' => 'dnone_v5',
            'title' => ' تنظیمات بخش رنگ بندی در هدر سبک یک',
        ),
        array(
            'id' => 'input_serch_back',
            'title' => 'رنگ پس زمینه اینپوت جستجو',
            'subtitle' => 'رنگ پس زمینه اینپوت جستجوی هدر را انتخاب کنید...',
            'class' => 'dnone_v5',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fafafc',),
        ),
        array(
            'id' => 'topbar_back',
            'title' => 'رنگ پس زمینه نوار بالایی',
            'subtitle' => 'رنگ پس زمینه نوار بالایی سایت را انتخاب کنید...',
            'class' => 'dnone_v5',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
        ),
        array(
            'id' => 'head_back',
            'title' => 'رنگ پس زمینه هدینگ سایت',
            'subtitle' => 'رنگ پس زمینه هدینگ سایت را انتخاب کنید...',
            'class' => 'dnone_v5',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
            'required' => array('heaader_v1_004', '=', 'inherit'),
        ),
        array(
            'id' => 'btn_serch_back',
            'title' => 'رنگ پس زمینه دکمه جستجو',
            'subtitle' => 'رنگ پس زمینه دکمه جستجوی هدر را انتخاب کنید...',
            'class' => 'dnone_v5',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fafafc',),
        ),
        array(
            'id' => 'header_bg_01',
            'title' => 'رنگ پس زمینه هدر اصلی',
            'class' => 'dnone_v5',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
        ),
        array(
            'id' => 'btn_serch_title_01',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون دکمه جستجو',
            'type' => 'color',
            'default' => '#555'
        ),
        array(
            'id' => 'header_user_bg_01',
            'class' => 'dnone_v5',
            'title' => 'رنگ پس زمینه بخش کاربری هدر',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#fafafc',),
        ),
        array(
            'id' => 'header_user_title_01',
            'class' => 'dnone_v5',
            'title' => 'رنگ متن نام و موجودی بخش کاربری هدر',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'header_user_bg_logout_01',
            'class' => 'dnone_v5',
            'title' => 'رنگ پس زمینه دکمه خروج بخش کاربری هدر',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#00BCD4',),
        ),
        array(
            'id' => 'header_user_title_logout_01',
            'class' => 'dnone_v5',
            'title' => 'رنگ متن دکمه خروج بخش کاربری هدر',
            'subtitle' => 'تنظیمات این بخش تنها برای هدر سبک یک اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'header_v2_005',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v2'),
            'title' => ' مدیریت بخش عمومی در هدر سبک دو',
        ),
        array(
            'id' => 'heaader_v2_034',
            'title' => 'تغییر آیکون علاقه مندی ها ',
            'subtitle' => 'از این قسمت می توانید آیکون " شماره تلفن " را در هدر تغییر دهید.',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'fal fa-heart'
        ),
        array(
            'id' => 'heaader_v2_035',
            'title' => 'تغییر آیکون سبد خرید ',
            'subtitle' => 'از این قسمت می توانید آیکون " سبد خرید " را در هدر تغییر دهید.',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'fal fa-shopping-bag'
        ),
        array(
            'id' => 'heaader_v2_003',
            'type' => 'section',
            'indent' => true,
            'class' => 'dnone_v5',
            'required' => array('header_style_page', '=', 'template-part/headers/header-v2'),
            'title' => ' مدیریت نمایش / پنهان بخش ها هدر سبک دو',
        ),
        array(
            'id' => 'logo-v2',
            'title' => 'لوگوی صفحه اصلی',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/logo-v2.png'),
        ),
        array(
            'id' => 'header_v2_hide_topbar',
            'title' => 'بخش تاپ بار در هدر سبک دو',
            'subtitle' => 'از این بخش می توانید تاپ بار  را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_006',
            'title' => 'نمایش ایمیل در تاپ بار',
            'subtitle' => 'از این بخش می توانید ایمیل را درتاپ بار نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_007',
            'title' => 'نمایش شماره تلفن در تاپ بار',
            'subtitle' => 'از این بخش می توانید شماره تلفن در تاپ بار را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_008',
            'title' => 'نمایش سبد خرید در هدر',
            'subtitle' => 'از این بخش می توانید سبد خرید در هدر را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_009',
            'title' => 'نمایش آیکون علاقه مندی در هدر ',
            'subtitle' => 'از این بخش می توانید آیکون علاقه مندی در هدر را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_010',
            'title' => 'نمایش باکس جستجو در هدر ',
            'subtitle' => 'از این بخش می توانید باکس جستجو در هدر را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v2_011',
            'title' => 'نمایش باکس پنل کاربری در هدر ',
            'subtitle' => 'از این بخش می توانید باکس پنل کاربری در هدر را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'flex',
            'options' => array(
                'flex' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),


        array(
            'id' => 'heaader_v2_00053',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v2'),
            'title' => ' مدیریت بخش رنگ بندی هدر سبک دو',
        ),
        array(
            'id' => 'heaader_v2_025',
            'title' => 'رنگ متن شماره تلفن',
            'subtitle' => 'رنگ متن شماره تلفن را از این بخش تنظیم کنید.',
            'type' => 'color',
            'class' => 'dnone_v5',
            'default' => '#ccbaca',
        ),
        array(
            'id' => 'heaader_v2_026',
            'title' => 'رنگ متن آدرس ایمیل',
            'subtitle' => 'رنگ متن آدرس ایمیل را از این بخش تنظیم کنید.',
            'type' => 'color',
            'class' => 'dnone_v5',
            'default' => '#ccbaca',
        ),
        array(
            'id' => 'heaader_v2_027_bg',
            'title' => 'رنگ پس زمینه دکمه خروج',
            'subtitle' => 'رنگ پس زمینه دکمه خروج را از این بخش تنظیم کنید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#902ba1',),
        ),
        array(
            'id' => 'heaader_v2_027',
            'class' => 'dnone_v5',
            'title' => 'رنگ متن دکمه خروج',
            'subtitle' => 'رنگ متن دکمه خروج را از این بخش تنظیم کنید.',
            'type' => 'color',
            'default' => '#ffffff',
        ),
        array(
            'id' => 'heaader_v2_028',
            'class' => 'dnone_v5',
            'title' => 'رنگ متن بخش پنل در هدر ',
            'subtitle' => 'رنگ متن بخش پنل در هدر را از این بخش تنظیم کنید.',
            'type' => 'color',
            'default' => '#8C8B8B',
        ),
        array(
            'id' => 'heaader_v2_029',
            'title' => 'رنگ پس زمینه در هدر ',
            'subtitle' => 'رنگ پس زمینه در هدر را از این بخش تنظیم کنید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',)
        ),
        array(
            'id' => 'heaader_v2_030',
            'title' => 'رنگ پس زمینه تاپ بار ',
            'subtitle' => 'رنگ پس زمینه تاپ بار را از این بخش تنظیم کنید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#33353b',)
        ),
        array(
            'id' => 'heaader_v2_031',
            'title' => 'رنگ پس زمینه منوی اصلی ',
            'subtitle' => 'رنگ پس زمینه منوی اصلی را از این بخش تنظیم کنید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#4a4c51',)
        ),
        array(
            'id' => 'heaader_v3_003',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v3'),
            'title' => '  نمایش / پنهان بخش ها هدر سبک سه',

        ),
        array(
            'id' => 'logo-v3',
            'title' => 'لوگوی صفحه اصلی سه',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/logo-v3.png'),
        ),
        array(
            'id' => 'hiden_search_v4',
            'title' => 'کادر جستجو',
            'subtitle' => 'نمایش / پنهان کردن کادر جستجو در صفحه اصلی چهار',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'hiden_box_v4',
            'title' => 'باکس های زیر جستجو',
            'subtitle' => 'نمایش / پنهان کردن باکس های زیر جستجو در صفحه اصلی چهار',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'menubar_v4_homepage',
            'subtitle' => 'از این بخش می توانید فهرست تاپ بار سایت را نمایش یا پنهان کنید..',
            'title' => 'فهرست بالا در هدر سبک سه',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'nav__main_v4_homepage',
            'title' => 'فهرست میانی در هدر سبک سه',
            'subtitle' => 'از این بخش می توانید فهرست میانی را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'register_v4_homepage',
            'title' => 'دکمه عضویت در هدر سبک سه',
            'subtitle' => 'از این بخش می توانید دکمه عضویت را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'login_v4_homepage',
            'title' => 'دکمه ورود در هدر سبک سه',
            'subtitle' => 'از این بخش می توانید دکمه ورود را نمایش یا پنهان کنید..',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),

        array(
            'id' => 'header_v3_005',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('header_style_page', '=', 'template-part/headers/header-v3'),
            'title' => ' مدیریت بخش استایل در هدر سبک سه',
        ),
        array(
            'id' => 'header_v4_box_back_photo',
            'title' => 'اعمال تصویر برای پس زمینه هدر سبک سه',
            'subtitle' => ' از این قسمت می توانید تصویر برای پس زمینه هدر سبک سه اعمال کنید.',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#2f363e',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/searcharea_bg.jpg'
            )
        ),
        array(
            'id' => 'header_v4_back',
            'title' => 'رنگ پس زمینه دکمه عضویت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه دکمه عضویت عبور را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'required' => array('home_v3_71', '=', 'inherit'),
            'default' => array(
                'background-color' => '#f93c64',)
        ),
        array(
            'id' => 'header_v4_back_border_bottom_color',
            'title' => 'رنگ حاشیه دکمه عضویت',
            'subtitle' => 'از این قسمت می توانید رنگ حاشیه دکمه عضویت عبور را تغییر دهید..',
            'type' => 'color',
            'class' => 'dnone_v5',
            'default' => '#f93c64'
        ),
    ),
));


// -> START Footer Setting

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات فوتر',
    'id' => 'footer_setting',
    'class' => 'blur-panel',
    'class' => 'blur-panel',
    'customizer_width' => '400px',
    'icon' => 'el el-indent-left',
    'fields' => array(
        array(
            'id' => 'def_footer_all_pages_activator',
            'title' => 'فعال سازی فوتر های سفارشی',
            'subtitle' => 'با فعال سازی این بخش فوتر هایی که با المنتور طراحی شده است به عنوان فوتر پیشفرض تمامی صفحاتی که فوتر آن ها در حالت پیشفرض باشد نمایش داده خواهد شد.',
            'type' => 'button_set',
            'default' => 'disable',
             'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'footer_style_page',
            'type' => 'select',
            'title' => 'طرح فوتر پیش ساخته',
            'options' => array(
                'template-part/footers/footer-v1' => 'استایل یک',
                'template-part/footers/footer-v2' => 'استایل دو',
                'template-part/footers/footer-v3' => 'استایل سه',
            ),
            'default' => 'template-part/footers/footer-v1',
            'required' => array('def_footer_all_pages_activator', '=', 'disable'),
        ),
        array(
            'id'       => 'def_footer_all_pages',
            'type'     => 'select',
            'multi'    => false,
            'data'     => 'posts',
            'args'     => array( 'post_type' =>  array( 'sigma-footer' ), 'numberposts' => -1 ),
            'title'    => 'فوتر پیش فرض صغحات',
            'subtitle' => 'لیست تمامی فوتر های ایجاد شده با سیستم فوتر ساز سیگما پلاس در مقابل نمایش داده میشود شما میتوانید یک فوتر را انتخاب کنید.',
                'default'  => 'null' ,  
                'required' => array('def_footer_all_pages_activator', '=', 'enable'),
    
        ),        
        array(
            'id' => 'footer_v2_00001001',
            'type' => 'section',
            'indent' => true,
            'class' => 'dnone_v5',
            'title' => ' تنظیمات فوتر بخش عمومی',
        ),

        array(
            'id' => 'address',
            'title' => 'متن آدرس فوتر',
            'subtitle' => 'آدرس کسب و کار خود را در این قسمت وارد کنید. . این آدرس در فوتر سایت و پایین منوی فوتر نمایش داده میشود.',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'آدرس: تهران - میدان انقلاب - خیابان انفلاب - کوچه قالب وردپرس - بن بست افزونه وردپرس - پلاک 158 '
        ),
        array(
            'id' => 'support',
            'title' => 'متن بخش پشتیبانی',
            'subtitle' => 'متن بخش پشتیبانی و شماره تماس پشتیبانی یا هر متن دلخوان را وارد کنید.. این متن در پایین متن آدرس نمایش داده میشود.',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'پشتیبانی 24 ساعته مشتریان : 2365-021'
        ),
        array(
            'id' => 'remove_cpright',
            'title' => 'بخش کپی رایت',
            'subtitle' => 'با استفاده از این بخش میتوانید کپی رایت سایت را بصورت کامل غیرفعال کنید..',
            'default' => 'inline-block',
            'class' => 'dnone_v5',
            'type' => 'button_set',
            'options' => array(
                'inline-block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'cpright',
            'title' => 'متن کپی رایت',
            'required' => array('remove_cpright', '=', 'inline-block'),
            'subtitle' => 'متن کپی را وارد کنید. ، شما میتوانید از تگ های html برای این قسمت استفاده کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => '© کليه حقوق محصولات و محتوای اين سایت متعلق به مدیر سایت می باشد و هر گونه کپی برداری از محتوا و محصولات سایت پیگرد قانونی دارد.'

        ),
        array(
            'id' => 'author_name',
            'title' => 'عنوان طراح',
            'required' => array('remove_cpright', '=', 'inline-block'),
            'subtitle' => 'عنوان طراح را از این قسمت میتوانید تغییر دهید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'طراحی و کدنویسی : همکار وردپرس'

        ),
        array(
            'id' => 'author_link',
            'title' => 'لینک طراح',
            'required' => array('remove_cpright', '=', 'inline-block'),
            'subtitle' => 'لینک طراح را از این قسمت میتوانید تغییر دهید. ، لینک را با http وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'validate' => 'url',
            'default' => 'https://www.hamkarwp.com'

        ),
        array(
            'id' => 'cpright_bg_dark',
            'required' => array('remove_cpright', '=', 'inline-block'),
            'title' => 'پس زمینه باکس کپی رایت فوتر تیره',
            'subtitle' => 'پس زمینه باکس کپی رایت فوتر تیره را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 38*38',
            'type' => 'background',
            'class' => 'dnone_v5',
            'url' => true,
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-color' => false,
            'background-attachment' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/footer_bg_cpright.png')
        ),

        array(
            'id' => 'counter_shop',
            'title' => 'نمایش آمار فروشگاه',
            'subtitle' => 'فعال یا غیرفعال سازی آمار فروشگاه در فوتر',
            'default' => 'inherit',
            'class' => 'dnone_v5',
            'type' => 'button_set',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'shop_counter_1comment_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون تعداد محصول برای فروش در  سایت ',
            'subtitle' => 'تصویر  تعداد محصول برای فروش در سایت را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer05.png'),
        ),
        array(
            'id' => 'shop_counter_1comment_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان تعداد محصول برای فروش   ',
            'class' => 'dnone_v5',
            'subtitle' => 'عنوان تعداد محصول برای فروش  را وارد کنید..',
            'type' => 'text',
            'default' => 'محصول برای فروش  '
        ),
        array(
            'id' => 'shop_counter_2comment_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون تعداد رضایت کامل از خرید ',
            'subtitle' => 'تصویر  تعداد محصول برای فروش در سایت را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer01.png'),
        ),
        array(
            'id' => 'shop_counter_2comment_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان تعداد رضایت کامل از خرید   ',
            'subtitle' => 'عنوان تعداد رضایت کامل از خرید  را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'رضایت کامل از خرید '
        ),
        array(
            'id' => 'shop_counter_posts_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون تعداد مطالب سایت',
            'subtitle' => 'تصویر آیکون تعداد مطالب سایت را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'class' => 'dnone_v5',
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer02.png'),
        ),
        array(
            'id' => 'shop_counter_posts_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان تعداد مطالب ',
            'class' => 'dnone_v5',
            'subtitle' => 'عنوان تعداد مطالب را وارد کنید..',
            'type' => 'text',
            'default' => 'مطالب آموزشی رایگان'
        ),
        array(
            'id' => 'shop_counter_comment_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون تعداد دیدگاه های سایت ',
            'subtitle' => 'تصویر آیکون تعداد سفارش دیدگاه های سایت را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer06.png'),
        ),
        array(
            'id' => 'shop_counter_comment_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان تعداد دیدگاه های سایت ',
            'subtitle' => 'عنوان تعداد دیدگاه های سایت را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'دیدگاه ثبت شده'
        ),

        array(
            'id' => 'shop_counter_earning_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون کل درآمد فروشگاه',
            'subtitle' => 'تصویر آیکون درآمد فروشگاه را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'url' => true,
            'class' => 'dnone_v5',
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer01.png'),
        ),
        array(
            'id' => 'shop_counter_earning_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان کل درآمد ',
            'subtitle' => 'عنوان کل درآمد را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'کل درآمد فروشگاه'
        ),
        array(
            'id' => 'show_sales',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'مبلغ کل درآمد فروشگاه',
            'subtitle' => 'مبلغ کل درآمد فروشگاه را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => '595.000 تومان'

        ),
        array(
            'id' => 'shop_counter_support_icon',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'آیکون تعداد درخواست پشتیبانی',
            'subtitle' => 'تصویر آیکون تعداد درخواست پشتیبانی را آپلود یا آدرس را وارد کنید.. اندازه پیشنهادی 50*50',
            'type' => 'media',
            'class' => 'dnone_v5',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/footer03.png'),
        ),
        array(
            'id' => 'shop_counter_support_title',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'عنوان تعداد درخواست پشتیبانی ',
            'subtitle' => 'عنوان تعداد درخواست پشتیبانی را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => 'درخواست پشتیبانی'
        ),
        array(
            'id' => 'support_counter',
            'required' => array('counter_shop', '=', 'inherit'),
            'title' => 'تعداد درخواست پشتیبانی',
            'subtitle' => 'تعداد درخواست پشتیبانی را وارد کنید..',
            'type' => 'text',
            'class' => 'dnone_v5',
            'default' => '59662'

        ),
        array(
            'id' => 'footer_v2_0000001',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('footer_style_page', '=', 'template-part/footers/footer-v1'),
            'title' => ' تنظیمات فوتر سبک یک',
        ),

        array(
            'id' => 'bg_top_footer',
            'title' => 'رنگ پس زمینه فوتر بالایی',
            'subtitle' => 'رنگ پس زمینه فوتر بالایی را از این قسمت انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
        ),
        array(
            'id' => 'bg_center_footer',
            'title' => 'رنگ پس زمینه فوتر میانی',
            'subtitle' => 'رنگ پس زمینه فوتر میانی را از این قسمت انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
        ),
        array(
            'id' => 'bg_bottom_footer',
            'title' => 'رنگ پس زمینه فوتر پایینی',
            'subtitle' => 'رنگ پس زمینه فوتر پایینی را از این قسمت انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff',),
        ),
        array(
            'id' => 'bg_cpright',
            'title' => 'رنگ پس زمینه باکس کپی رایت طراح',
            'subtitle' => 'رنگ پس زمینه باکس کپی رایت طراح را از این قسمت انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#bdbdbd',),
        ),
        array(
            'id' => 'title_color_cpright',
            'title' => 'رنگ متن باکس کپی رایت طراح',
            'subtitle' => 'رنگ متن باکس کپی رایت طراح را از این قسمت انتخاب کنید..',
            'type' => 'color',
            'class' => 'dnone_v5',
            'default' => '#fff'
        ),
        array(
            'id' => 'footer_v1_backup_bg',
            'title' => 'تغییر رنگ پس زمینه دکمه بازگشت به بالا',
            'subtitle' => 'از این بخش می توانید رنگ " پس زمینه دکمه بازگشت به بالا " را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f87700',),
        ),
        array(
            'id' => 'footer_v2_00001',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('footer_style_page', '=', 'template-part/footers/footer-v2'),
            'title' => ' تنظیمات فوتر سبک دو',
        ),
        array(
            'id' => 'footer_v2_001',
            'title' => 'رنگ پس زمینه فوتر بالایی',
            'subtitle' => 'از این بخش می توانید رنگ " پس زمینه فوتر بالایی " را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#33353b',),
        ),
        array(
            'id' => 'footer_v2_001_center',
            'title' => 'رنگ پس زمینه فوتر میانی',
            'subtitle' => 'رنگ پس زمینه فوتر میانی را انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#4a4c51',),
        ),
        array(
            'id' => 'footer_v2_001_botton',
            'title' => 'رنگ پس زمینه فوتر پایینی',
            'subtitle' => 'رنگ پس زمینه فوتر میانی پایینی انتخاب کنید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#33353b',),
        ),
        array(
            'id' => 'footer_v2_14',
            'title' => 'تغییر رنگ پس زمینه دکمه بازگشت به بالا',
            'subtitle' => 'از این بخش می توانید رنگ " پس زمینه دکمه بازگشت به بالا " را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#666',),
        ),
        array(
            'id' => 'footer_v3_00001',
            'type' => 'section',
            'class' => 'dnone_v5',
            'indent' => true,
            'required' => array('footer_style_page', '=', 'template-part/footers/footer-v3'),
            'title' => ' تنظیمات فوتر سبک سه',
        ),
        array(
            'id' => 'footer_v3_0001',
            'title' => 'تغییر پس زمینه در فوتر',
            'subtitle' => 'از این بخش می توانید تصویر " پس زمینه فوتر " را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#353a42',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/footer-bg.png'
            )
        ),
        array(
            'id' => 'footer__sponsor__text',
            'title' => 'متن اسپانسر',
            'class' => 'dnone_v5',
            'subtitle' => 'متن اسپانسر را وارد کنید. ، شما میتوانید از تگ های html برای این قسمت استفاده کنید..',
            'type' => 'textarea',
            'default' => 'سیگما پلاس بر روی سرورهای قدرتمند <a href="https://clients.netafraz.com/aff.php?aff=7271" target="blank" >نت افراز</a> میزبانی میشود.'
        ),
        array(
            'id' => 'address_footer3_icon',
            'title' => 'آیکون آدرس فوتر',
            'class' => 'dnone_v5',
            'subtitle' => 'از این قسمت می توانید آیکون بخش آدرس فوتر را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => 'fal fa-map-marker'
        ),
        array(
            'id' => 'support_footer3_icon',
            'title' => 'آیکون پشتیبانی فوتر',
            'class' => 'dnone_v5',
            'subtitle' => 'از این قسمت می توانید آیکون بخش پشتیبانی فوتر را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => 'fal fa-phone'
        ),
        array(
            'id' => 'footer_v3_email',
            'title' => 'آدرس ایمیل فوتر',
            'class' => 'dnone_v5',
            'subtitle' => 'آدرس ایمیل خود را جهت نمایش پایین اطلاعات تماس وارد کنید!',
            'type' => 'text',
            'default' => 'info@hamkarwp.com'
        ),
        array(
            'id' => 'email_footer3_icon',
            'title' => 'آیکون ایمیل فوتر',
            'class' => 'dnone_v5',
            'subtitle' => 'از این قسمت می توانید آیکون بخش ایمیل فوتر را تغییر دهید. - توجه فرمایید که آیکون های این بخش از پک های fontawesome و icons8 پشتیبانی می کند',
            'type' => 'text',
            'default' => 'fal fa-envelope-o'
        ),
        array(
            'id' => 'footer_v3_title_col1',
            'class' => 'dnone_v5',
            'title' => 'عنوان ابزارک ستون یک فوتر سبک سه ( اطلاعات تماس )',
            'subtitle' => 'عنوان ابزارک ستون یک فوتر سبک سه را در اینجا وارد کنید!',
            'type' => 'text',
            'default' => 'اطلاعات تماس'
        ),
        array(
            'id' => 'footer_v3_title_col4',
            'class' => 'dnone_v5',
            'title' => 'عنوان ابزارک ستون سه فوتر سبک سه ( منوی راهنمای خرید )',
            'subtitle' => 'عنوان ابزارک ستون چهار فوتر سبک سه را در اینجا وارد کنید!',
            'type' => 'text',
            'default' => 'راهنمای خرید'
        ),
        array(
            'id' => 'footer_v3_newslatter-title',
            'class' => 'dnone_v5',
            'title' => 'عنوان بخش عضویت در خبرنامه',
            'subtitle' => 'عنوان بخش عضویت در خبرنامه را در این بخش وارد کنید!',
            'type' => 'text',
            'default' => 'عضویت در خبرنامه سیگماپلاس'
        ),
        array(
            'id' => 'footer_v3_12',
            'title' => 'رنگ متن کپی رایت   ',
            'class' => 'dnone_v5',
            'subtitle' => 'از این بخش می توانید رنگ " متن کپی رایت " را تغییر دهید..',
            'type' => 'color',
            'default' => '#aeaeb1'
        ),
        array(
            'id' => 'footer_v3_14',
            'title' => 'تغییر رنگ پس زمینه دکمه بازگشت به بالا',
            'subtitle' => 'از این بخش می توانید رنگ " پس زمینه دکمه بازگشت به بالا " را تغییر دهید..',
            'type' => 'background',
            'class' => 'dnone_v5',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f93c64',),
        ),
        array(
            'id' => 'facebook_color_ft3',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون فیسیوک',
            'subtitle' => 'رنگ آیکون فیسبوک موجود در فوتر سبک سه را مشخص کنید.',
            'type' => 'color',
            'default' => '#a1a1a6'
        ),
        array(
            'id' => 'instagram_color_ft3',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون اینستاگرام',
            'subtitle' => 'رنگ آیکون اینستاگرام موجود در فوتر سبک سه را مشخص کنید.',
            'type' => 'color',
            'default' => '#a1a1a6'
        ),
        array(
            'id' => 'telegram_color_ft3',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون تلگرام',
            'subtitle' => 'رنگ آیکون تلگرام موجود در فوتر سبک سه را مشخص کنید.',
            'type' => 'color',
            'default' => '#a1a1a6'
        ),
        array(
            'id' => 'youtube_color_ft3',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون یوتیوب',
            'subtitle' => 'رنگ آیکون یوتیوب موجود در فوتر سبک سه را مشخص کنید.',
            'type' => 'color',
            'default' => '#a1a1a6'
        ),
        array(
            'id' => 'twitter_color_ft3',
            'class' => 'dnone_v5',
            'title' => 'رنگ آیکون توییتر',
            'subtitle' => 'رنگ آیکون توییتر موجود در فوتر سبک سه را مشخص کنید.',
            'type' => 'color',
            'default' => '#a1a1a6'
        ),
    ),

));

// -> START Post Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات مطالب',
    'id' => 'post_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-pencil',
    'fields' => array(
        array(
            'id' => 'section_post',
            'title' => 'تنظیمات مطالب',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'blog_page_layout',
            'title' => 'حالت نمایش آرشیو مطالب سایت',
            'subtitle' => 'از این قسمت میتوانید سبک باکسی یا تمام عرض صفحه آرشیو مطالب را مشخص کنید.',
            'type' => 'button_set',
            'default' => '',
            'options' => array(
                '' => 'جعبه ای',
                '-fluid' => 'تمامی عرض',
            ),
        ),       
        array(
            'id' => 'blog_sidebar',
            'type' => 'radio',
            'title' => 'سایدبار صفحه آرشیو مطالب',
            'subtitle' => 'از این قسمت میتوانید سبک نمایش سایدبار صفحه آرشیو مطالب را مشخص کنید. این تنظیمات برای صفحه جستجوی مطالب ، صفحه نویسنده وبرچسب ها اعمال خواهد شد.',
            'default' => 'right-sidebar',
            'options' => array(
                'left-sidebar' => 'سایدبار چپ',
                'right-sidebar' => 'سایدبار راست',
                'none-sidebar' => 'بدون سایدبار',
            ),
        ),            
        array(
            'id' => 'show_box_dl',
            'type' => 'button_set',
            'default' => 'inherit',
            'title' => 'فعال یا غیرفعال سازی باکس دانلود مطالب',
            'subtitle' => 'نمایش یا مخفی سازی اسلایدر باکس دانلود مطالب سایت را مشخص کنید.!',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'box_dl_image',
            'required' => array('show_box_dl', '=', 'inherit'),
            'title' => 'آیکون باکس دانلود',
            'subtitle' => 'تصویر مورد نظر را جهت نمایش آپلود کنید. ، اندازه استاندارد : 300*300',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => get_template_directory_uri() . '/assets/img/download.png',
        ),
        array(
            'id' => 'box_dl_title',
            'title' => 'متن عنوان باکس دانلود',
            'required' => array('show_box_dl', '=', 'inherit'),
            'subtitle' => 'شما میتوانید متن عنوان باکس دانلود مطالب را از این قسمت تغییر دهید...',
            'type' => 'text',
            'default' => 'دانلود و اطلاعات بیشتر'
        ),
        array(
            'id' => 'box_dl_content',
            'required' => array('show_box_dl', '=', 'inherit'),
            'title' => 'توضیحات پیش از دانلود',
            'subtitle' => 'توضیحات بیش از دانلود باکس دانلود را در این قسمت وارد کنید.، سعی کنید. بصورت لیستی این آیتم ها را قرار دهید..',
            'default' => '<ul>
							<li>جهت دانلود سریع از VPN استفاده نکنید..</li>
							<li>تمامی فایل ها قبل از درج بررسی شده اند.</li>
							<li>لینک دانلود از دو سرور مختلف است.</li>
							<li>امکان قطع دانلود فایل ها وجود دارد.</li>
							<li>جهت دانلود از IDM استفاده کنید..</li>
							<li>در صورت نیاز با ما تماس بگیرید.</li>
							</ul>',
            'type' => 'textarea',
        ),
        array(
            'id' => 'relate_post_title',
            'title' => 'عنوان مطالب مرتبط',
            'subtitle' => 'عنوان مطالب مرتبط برای نوشته ها را مشخص کنید..',
            'type' => 'text',
            'default' => 'مطالب زیر را حتما بخوانید:'
        ),
        array(
            'id' => 'show_box_pass',
            'title' => 'کلمه عبور فایل باکس دانلود',
            'subtitle' => 'کلمه عبور باکس دانلود را فعال یا غیرفعال کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_box_meta',
            'title' => 'متای باکس دانلود مطالب',
            'subtitle' => 'متای باکس شامل حجم و نوع فایل و... است که میتوانید از این بخش غیرفعال کنید..',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'telegram_channel',
            'title' => 'نمایش باکس کانال تلگرام',
            'subtitle' => 'مشخص کنید. که باکس کانال تلگرام در پایین مطالب نمایش داده شود یا خیر',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'text_box_telegram',
            'required' => array('telegram_channel', '=', 'inline'),
            'title' => 'متن باکس کانال تلگرام',
            'subtitle' => 'متن باکس کانال تلگرام را مشخص کنید.',
            'type' => 'text',
            'default' => 'راه آسان‌تری برای ارتباط با کاربران‌مان پیدا کرده‌ایم :)'
        ),
        array(
            'id' => 'text_btn_box_telegram',
            'required' => array('telegram_channel', '=', 'inline'),
            'title' => 'متن دکمه کانال تلگرام',
            'subtitle' => 'متن دکمه کانال تلگرام را مشخص کنید.',
            'type' => 'text',
            'default' => 'عضویت در کانال'

        ),
        array(
            'id' => 'link_btn_channel',
            'required' => array('telegram_channel', '=', 'inline'),
            'title' => 'لینک دکمه کانال تلگرام',
            'subtitle' => 'لینک دکمه کانال تلگرام را وارد کنید.. لینک را حتما با http یا https وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => 'https://telegram.me/hamkarwp'
        ),
        array(
            'id' => 'show_thumnail',
            'title' => 'نمایش تصویر شاخص در توضیحات ',
            'subtitle' => 'مشخص کنید. که میخواهید تصویر شاخص مطالب در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'cat',
            'title' => 'نمایش دسته بندی مطلب',
            'subtitle' => 'مشخص کنید. که میخواهید دسته بندی در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'date',
            'title' => 'نمایش تاریخ ارسال',
            'subtitle' => 'مشخص کنید. که میخواهید تاریخ ارسال در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'author',
            'title' => 'نمایش نام نویسنده',
            'subtitle' => 'مشخص کنید. که میخواهید نام نویسنده در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'view',
            'title' => 'نمایش تعداد بازدید',
            'subtitle' => 'مشخص کنید. که میخواهید تعداد بازدید مطالب در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'tags',
            'title' => 'نمایش برچسب ها',
            'subtitle' => 'مشخص کنید. که میخواهید برچسب مطالب در نوشته های وب سایت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'user_auther_box',
            'title' => 'نمایش باکس نویسنده سایت',
            'subtitle' => 'مشخص کنید. که باکس نویسنده در پایین مطالب نمایش داده شود یا خیر',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'ralated_post',
            'title' => 'نمایش مطالب مرتبط',
            'subtitle' => 'مشخص کنید. که آیا میخواهید مطالب مرتبط با نوشته ها در بخش پایینی نوشته ها نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
    ),
));

// start loop post setting

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات لوپ مطالب',
    'id' => 'loops_posts_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'post_style_loop',
            'type' => 'select',
            'title' => 'استایل لوپ مطالب سایت',
            'subtitle' => 'شما میتوانید براساس ساختار سایت خود سبک نمایش لوپ مطالب خود را مشخص کنید!',
            'options' => array(
                'template-part/content/loop/post/style01' => 'استایل یک',
                'template-part/content/loop/post/style02' => 'استایل دو',
                'template-part/content/loop/post/style03' => 'استایل سه',
                'template-part/content/loop/post/style04' => 'استایل چهار',
            ),
            'default' => 'template-part/content/loop/post/style01'
        ),
        array(
            'id' => 'show_img_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی تصاویر مطالب',
            'subtitle' => 'شما میتوانید تصاویر مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی عنوان مطالب',
            'subtitle' => 'شما میتوانید عنوان مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_desc_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی توضیحات مطالب',
            'subtitle' => 'شما میتوانید توضیحات مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_cat_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی دسته بندی مطالب',
            'subtitle' => 'شما میتوانید دسته بندی مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_veiws_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی بازدید مطالب',
            'subtitle' => 'شما میتوانید بازدید مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_btn_loop_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'فعال / غیرفعال سازی دکمه ادامه مطالب',
            'subtitle' => 'شما میتوانید دکمه ادامه مطالب لوپ مطالب سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
        array(
            'id' => 'tite_loop_color_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'رنگ عنوان لوپ مطالب استایل یک',
            'subtitle' => 'رنگ عنوان لوپ مطالب استایل یک را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#666666'
        ),
        array(
            'id' => 'des_loop_color_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'رنگ توضیحات لوپ مطالب استایل یک',
            'subtitle' => 'رنگ توضیحات لوپ مطالب استایل یک را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#666666'
        ),
        array(
            'id' => 'cat_loop_color_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'رنگ دسته بندی و تعداد بازدید لوپ مطالب استایل یک',
            'subtitle' => 'رنگ دسته بندی لوپ مطالب استایل یک را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#666666'
        ),
        array(
            'id' => 'btn_loop_color_v1',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style01'),
            'title' => 'رنگ دکمه ادامه مطلب لوپ مطالب استایل یک',
            'subtitle' => 'رنگ دکمه ادامه مطلب لوپ مطالب استایل یک را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'show_img_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی تصاویر مطالب',
            'subtitle' => 'شما میتوانید تصاویر مطالب لوپ مطالب سبک یک دو از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_avatar_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی آواتار مطالب',
            'subtitle' => 'شما میتوانید آواتار مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),          
        array(
            'id' => 'show_title_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی عنوان مطالب',
            'subtitle' => 'شما میتوانید عنوان مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_desc_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی توضیحات مطالب',
            'subtitle' => 'شما میتوانید توضیحات مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_date_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی تاریخ مطالب',
            'subtitle' => 'شما میتوانید تاریخ مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_comments_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی دیدگاه مطالب',
            'subtitle' => 'شما میتوانید دیدگاه مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_btn_loop_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'فعال / غیرفعال سازی دکمه ادامه مطالب',
            'subtitle' => 'شما میتوانید دکمه ادامه مطالب لوپ مطالب سبک دو را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ), 
        array(
            'id' => 'tite_loop_color_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'رنگ عنوان لوپ مطالب استایل دو',
            'subtitle' => 'رنگ عنوان لوپ مطالب استایل دو را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#666666'
        ),
        array(
            'id' => 'des_loop_color_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'رنگ توضیحات لوپ مطالب استایل دو',
            'subtitle' => 'رنگ توضیحات لوپ مطالب استایل دو را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'cat_loop_color_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'رنگ تاریخ و تعداد دیدگاه مطلب',
            'subtitle' => 'رنگ تاریخ و تعداد دیدگاه مطلب مطالب استایل دو را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#666666'
        ),
        array(
            'id' => 'btn_loop_color_v2',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style02'),
            'title' => 'رنگ دکمه ادامه مطلب لوپ مطالب استایل دو',
            'subtitle' => 'رنگ دکمه ادامه مطلب لوپ مطالب استایل دو را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#e92b5f'
        ),        
        array(
            'id' => 'show_img_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی تصاویر مطالب',
            'subtitle' => 'شما میتوانید تصاویر مطالب لوپ مطالب سبک یک سه از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_avatar_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی آواتار مطالب',
            'subtitle' => 'شما میتوانید آواتار مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),          
        array(
            'id' => 'show_title_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی عنوان مطالب',
            'subtitle' => 'شما میتوانید عنوان مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_author_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی نویسنده مطالب',
            'subtitle' => 'شما میتوانید توضیحات مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_date_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی تاریخ مطالب',
            'subtitle' => 'شما میتوانید تاریخ مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_comments_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی دیدگاه مطالب',
            'subtitle' => 'شما میتوانید دیدگاه مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_veiws_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی بازدید مطالب',
            'subtitle' => 'شما میتوانید بازدید مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_cat_loop_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'فعال / غیرفعال سازی دسته بندی مطالب',
            'subtitle' => 'شما میتوانید دسته بندی مطالب لوپ مطالب سبک سه را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),         
        array(
            'id' => 'tite_loop_color_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'رنگ عنوان لوپ مطالب استایل سه',
            'subtitle' => 'رنگ عنوان لوپ مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#444444'
        ),
        array(
            'id' => 'author_loop_color_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'رنگ نام نویسنده لوپ مطالب استایل سه',
            'subtitle' => 'رنگ نام نویسنده لوپ مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'meta_loop_color_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'رنگ تاریخ و تعداد دیدگاه و بازدید مطلب',
            'subtitle' => 'رنگ تاریخ و تعداد دیدگاه و بازدید مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'meta_icon_loop_color_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'رنگ آیکون تاریخ و تعداد دیدگاه و بازدید مطلب',
            'subtitle' => 'رنگ آیکون تاریخ و تعداد دیدگاه و بازدید مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#03A9F4'
        ),        
        array(
            'id' => 'cat_loop_bg_v3',
            'title' => 'رنگ پس زمینه دسته بندی لوپ مطالب استایل سه',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'subtitle' => 'رنگ پس زمینه دسته بندی لوپ مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#F44336',),
        ),        
        array(
            'id' => 'cat_loop_color_v3',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style03'),
            'title' => 'رنگ دسته بندی لوپ مطالب استایل سه',
            'subtitle' => 'رنگ دسته بندی لوپ مطالب استایل سه را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ), 
        array(
            'id' => 'show_img_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی تصاویر مطالب',
            'subtitle' => 'شما میتوانید تصاویر مطالب لوپ مطالب سبک یک چهار از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی عنوان مطالب',
            'subtitle' => 'شما میتوانید عنوان مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_author_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی نویسنده مطالب',
            'subtitle' => 'شما میتوانید توضیحات مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_date_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی تاریخ مطالب',
            'subtitle' => 'شما میتوانید تاریخ مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_veiws_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی بازدید مطالب',
            'subtitle' => 'شما میتوانید بازدید مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_cat_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی دسته بندی مطالب',
            'subtitle' => 'شما میتوانید دسته بندی مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),    
        array(
            'id' => 'show_btn_loop_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'فعال / غیرفعال سازی دکمه ادامه مطالب',
            'subtitle' => 'شما میتوانید دکمه ادامه مطالب لوپ مطالب سبک چهار را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'tite_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ عنوان لوپ مطالب استایل چهار',
            'subtitle' => 'رنگ عنوان لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#444444'
        ),
        array(
            'id' => 'author_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ نام نویسنده لوپ مطالب استایل چهار',
            'subtitle' => 'رنگ نام نویسنده لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'des_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ نام توضیحات لوپ مطالب استایل چهار',
            'subtitle' => 'رنگ نام توضیحات لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),       
        array(
            'id' => 'date_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ تاریخ لوپ مطالب استایل چهار',
            'subtitle' => 'رنگ تاریخ لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),             
        array(
            'id' => 'meta_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ تعداد دیدگاه و بازدید مطلب',
            'subtitle' => 'رنک تعداد دیدگاه و بازدید مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#777777'
        ),
        array(
            'id' => 'meta_icon_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ آیکون تاریخ و تعداد دیدگاه و بازدید مطلب',
            'subtitle' => 'رنگ آیکون تاریخ و تعداد دیدگاه و بازدید مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#d6ae6c'
        ),        
        array(
            'id' => 'btn_loop_bg_v4',
            'title' => 'رنگ پس زمینه دکمه ادامه مطالب استایل چهار',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'subtitle' => 'رنگ پس زمینه دکمه ادامه مطلب لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#d6ae6c',),
        ),        
        array(
            'id' => 'btn_loop_color_v4',
            'required' => array('post_style_loop', '=', 'template-part/content/loop/post/style04'),
            'title' => 'رنگ  دکمه ادامه مطلب لوپ مطالب استایل چهار',
            'subtitle' => 'رنگ دکمه ادامه مطلب لوپ مطالب استایل چهار را از این قسمت میتوانید تغییر دهید.',
            'type' => 'color',
            'default' => '#ffffff'
        ),         
    ),
));

// -> START Footer Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات تبلیغات',
    'id' => 'ads_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-check',
    'fields' => array(
        array(
            'id' => 'ads_section',
            'title' => 'تنظیمات تبلیغات',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'side_ads',
            'title' => 'فعال سازی تبلیغات سایدبار',
            'subtitle' => 'مشخص کنید. که میخواهید تبلیغات در سایدبار نمایش داده شود یا خیر',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'ads_side_banner',
            'required' => array('side_ads', '=', 'inherit'),
            'title' => 'تصویر بنر سایدبار',
            'subtitle' => 'تصویر بنر مورد نظر را جهت نمایش آپلود کنید. ، اندازه استاندارد : 300*300',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/ads300-1.png'),
        ),
        array(
            'id' => 'ads_side_link',
            'required' => array('side_ads', '=', 'inherit'),
            'title' => 'لینک بنر سایدبار',
            'subtitle' => 'لینک بنر تبلیغاتی سایدبار را مشخص کنید.. لینک ترجیحا با http وارد شود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/'
        ),
        array(
            'id' => 'ads_side_target',
            'required' => array('side_ads', '=', 'inherit'),
            'title' => 'هدف لینک بنر سایدبار',
            'subtitle' => 'تارگت (هدف ) لینک بنر را مشخص کنید.. پیش فرض : در پنجره جدید',
            'type' => 'button_set',
            'default' => '_blank',
            'options' => array(
                '_blank' => 'در پنجره جدید',
                '_self' => 'در همان پنجره',
            ),
        ),
        array(
            'id' => 'show_ads_product',
            'title' => 'فعال سازی تبلیغات پایین نوشته ها و محصولات سایت',
            'subtitle' => 'تبلیغات در پایین توضیحات محصولات و مطالب نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'ads_post_link',
            'required' => array('show_ads_product', '=', 'inherit'),
            'title' => 'لینک بنر ادامه مطلب',
            'subtitle' => 'لینک بنر تبلیغاتی ادامه مطلب را مشخص کنید.. لینک ترجیحا با http وارد شود.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/shop'
        ),
        array(
            'id' => 'single_ads_image',
            'required' => array('show_ads_product', '=', 'inherit'),
            'title' => 'تصویر بنر ادامه مطلب',
            'subtitle' => 'تصویر بنر تبلیغات ادامه مطلب را آپلود کنید. ، اندازه استاندارد : 728*80',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/ads728.png'),
        ),
        array(
            'id' => 'single_ads_target',
            'required' => array('show_ads_product', '=', 'inherit'),
            'title' => 'هدف لینک بنر ادامه مطلب',
            'subtitle' => 'تارگت (هدف ) لینک بنر را مشخص کنید.. پیش فرض : در پنجره جدید',
            'type' => 'button_set',
            'default' => '_blank',
            'options' => array(
                '_blank' => 'در پنجره جدید',
                '_self' => 'در همان پنجره',
            ),
        ),

    ),
));


// -> START shop Setting

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات ووکامرس',
    'id' => 'woo_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-shopping-cart-sign',
    'fields' => array(
    ),
));


Redux::setSection($opt_name, array(
    'title' => 'تنظیمات تک محصول',
    'id' => 'shop_setting',
    'subsection' => true,
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'products_style_page',
            'type' => 'select',
            'title' => 'سبک نمایش جزییات محصول',
            'subtitle' => 'شما میتوانید براساس ساختار سایت خود سبک نمایش محصولات خود را مشخص کنید!',
            'options' => array(
                'template-part/content/product/signle-product-style01/single' => 'استایل یک (ویژه محصولات دانلودی)',
                'template-part/content/product/signle-product-style02/single' => 'استایل دو (ویژه محصولات فیزیکی)',
                'template-part/content/product/signle-product-style03/single' => 'استایل سه (ویژه دوره آموزشی)',
                'template-part/content/product/signle-product-style04/single' => 'استایل چهار (سبک جدید محصول دانلودی )',
            ),
            'default' => 'template-part/content/product/signle-product-style02/single'
        ),
        array(
            'id' => 'woocommerce_post_1',
            'type' => 'section',
            'indent' => true,
            'title' => ' تنظیمات بخش عمومی صفحه فروشگاه',
        ),

        //style 04

        array(
            'id' => 'single_product_color1_v4',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'رنگ اصلی تک محصول سبک چهار',
            'subtitle' => 'رنگ اصلی تص محصول سبک دانلودی را از این قسمت میتوانید وارد کنید.',
            'default' => '#d6ae6d',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),
        array(
            'id' => 'single_product_demo_v4',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'پس زمینه دکمه پیشنمایش فارسی',
            'subtitle' => 'رنگ پس زمینه دکمه پیش نمایش فارسی محصول را انتخاب کنید.',
            'default' => '#17c5e3',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),
        array(
            'id' => 'single_product_demo_en_v4',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'پس زمینه دکمه پیشنمایش لاتین',
            'subtitle' => 'رنگ پس زمینه دکمه پیش نمایش لاتین محصول را انتخاب کنید.',
            'default' => '#ff5721',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),        
        array(
            'id' => 'sales_count_v4',
            'title' => 'فعال سازی تعداد فروش',
            'subtitle' => 'نمایش / عدم نمایش تعداد فروش محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),        

        array(
            'id' => 'price_count_v4',
            'title' => 'فعال سازی قیمت محصول ',
            'subtitle' => 'نمایش / عدم نمایش قیمت محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),  
        
        array(
            'id' => 'date_active_v4',
            'title' => 'فعال سازی تاریخ انتشار  ',
            'subtitle' => 'نمایش / عدم نمایش تاریخ انتشار ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ), 

        array(
            'id' => 'update_active_v4',
            'title' => 'فعال سازی تاریخ بروزرسانی  ',
            'subtitle' => 'نمایش / عدم نمایش تاریخ بروزرسانی ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ), 

        array(
            'id' => 'demo_btn_active_v4',
            'title' => 'فعال سازی دکمه پیشنمایش   ',
            'subtitle' => 'نمایش / عدم نمایش دکمه پیش نمایش  ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ), 
        
        
        array(
            'id' => 'add_cart_active_v4',
            'title' => 'فعال سازی دکمه سبد خرید',
            'subtitle' => 'نمایش / عدم نمایش دکمه افزودن به سبد خرید ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ), 

        array(
            'id' => 'badge_right_active_v4',
            'title' => 'فعال سازی مدال محصولات سمت راست',
            'subtitle' => 'نمایش / عدم نمایش مدال های محصولات کنار تصویر شاخص ( سمت راست ) ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ), 
        
        array(
            'id' => 'comment_tab_active_v4',
            'title' => 'فعال سازی تب نظرات کاربران',
            'subtitle' => 'نمایش / عدم نمایش تب نظرات محصولات ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),         
        
        array(
            'id' => 'support_tab_active_v4',
            'title' => 'فعال سازی تب پشتیبانی محصولات',
            'subtitle' => 'نمایش / عدم نمایش تب پشتیبانی محصولات ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),             
        
        array(
            'id' => 'seller_tab_active_v4',
            'title' => 'فعال سازی تب اطلاعات فروشنده ',
            'subtitle' => 'نمایش / عدم نمایش تب اطلاعات فروشنده ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),          

        array(
            'id' => 'wishlist_nav_active_v4',
            'title' => 'فعال سازی آیکون علاقه مندی  ',
            'subtitle' => 'نمایش / عدم نمایش آیکون علاقه مندی محصولات   ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),          

        array(
            'id' => 'share_nav_active_v4',
            'title' => 'فعال سازی آیکون اشتراک گذاری   ',
            'subtitle' => 'نمایش / عدم نمایش آیکون اشتراک گذاری محصولات   ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),             

        array(
            'id' => 'url_nav_active_v4',
            'title' => 'فعال سازی آیکون لینک کوتاه  ',
            'subtitle' => 'نمایش / عدم نمایش آیکون لینک کوتاه محصولات   ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),          
        
        
        array(
            'id' => 'salles_sidebar_active_v4',
            'title' => 'فعال سازی تعداد فروش سایدبار ',
            'subtitle' => 'نمایش / عدم نمایش تعداد فروش سایدبار    ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),              

        array(
            'id' => 'price_sidebar_active_v4',
            'title' => 'فعال سازی قیمت محصول سایدبار ',
            'subtitle' => 'نمایش / عدم نمایش قیمت محصول در سایدبار    ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),             

        array(
            'id' => 'medal_sidebar_active_v4',
            'title' => 'فعال سازی مدال محصول سایدبار ',
            'subtitle' => 'نمایش / عدم نمایش مدال محصول در سایدبار    ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),          

        array(
            'id' => 'license_sidebar_active_v4',
            'title' => 'فعال سازی متن لایسنس محصول در سایدبار ',
            'subtitle' => 'نمایش / عدم متن لایسنس محصول در سایدبار    ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),          

        array(
            'id' => 'license_text_sidebar_v4',
            'title' => 'محتوای لایسنس محصولات سایدبار',
            'subtitle' => 'برای درج عنوان محتوا از تگ span و برای نمایش لیست نکات و لایسنس  از تگ ul < li استفاده نمایید.',
            'required' => array('license_sidebar_active_v4', '=', 'block'),
            'default' => '<span>با خرید این محصول از مزایای زیر بهره&zwnj;مند می&zwnj;شوید:</span> <ul> <li>دسترسی به فایل محصول به صورت مادام&zwnj;العمر</li> <li>۶ ماه پشتیبانی کاملا رایگان و تضمین شده</li> </ul>',
            'type' => 'editor',
        ),

        array(
            'id' => 'addcart_sidebar_active_v4',
            'title' => 'فعال سازی دکمه افزودن به سبد خرید سایدبار ',
            'subtitle' => 'نمایش / عدم نمایش دکمه افزودن به سبد خرید در سایدبار ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),   

        array(
            'id' => 'after_addcart_text_v4',
            'title' => 'متن محتوای بعد از دکمه افزودن به سبد خرید',
            'subtitle' => 'در این قسمت میتوانید محتوا و نکات قبل یا بعد از خرید را برای محصولات خود وارد کنید. برای عدم نمایش محتوایی قرار ندهید.',
            'required' => array('license_sidebar_active_v4', '=', 'block'),
            'default' => 'خرید محصول توسط کلیه کارت های شتاب امکان پذیر است و بلافاصله پس از خرید، لینک دانلود محصول در اختیار شما قرار خواهد گرفت.',
            'type' => 'editor',
        ),

        array(
            'id' => 'meta_sidebar_active_v4',
            'title' => 'فعال / غیرفعال سازی متای محصولات ',
            'subtitle' => 'شما میتوانید متای محصولات شامل حجم ، تعداد دیدگاه ، بازدید و... را از ین قسمت غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),   

        array(
            'id' => 'tags_sidebar_active_v4',
            'title' => 'فعال سازی برچسب های محصولات ',
            'subtitle' => 'نمایش / عدم نمایش برچسب محصولات در سایدبار ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),  
        
        array(
            'id' => 'related_active_v4',
            'title' => 'فعال سازی محصولات مرتبط ',
            'subtitle' => 'نمایش / عدم نمایش محصولات مرتبط در پایین جزییات محصول ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style04/single'),
        ),  


        //style 04
        
        array(
            'id' => 'teacher_active_v3',
            'title' => 'فعال سازی اطلاعات مدرس',
            'subtitle' => 'فعال / غیرفعال سازی اطللاعات مدرس در سایدبار دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),          

        array(
            'id' => 'teacher_active_meta_v3',
            'title' => 'فعال سازی آواتار و نام مدرس',
            'subtitle' => 'فعال / غیرفعال سازی آواتار و نام مدرس در سایدبار دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),   

        array(
            'id' => 'teacher_phone_active_v3',
            'title' => 'فعال سازی بخش شماره تماس مدرس',
            'subtitle' => 'فعال / غیرفعال سازی بخش شماره تماس مدرس در سایدبار دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),   

        array(
            'id' => 'courese_sales_active_v3',
            'title' => 'فعال سازی بخش تعداد دانشجو',
            'subtitle' => 'فعال / غیرفعال سازی بخش تعداد دانشجو دوره در سایدبار دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),   

        array(
            'id' => 'courese_3meta_active_v3',
            'title' => 'فعال سازی ۳ متای دوره',
            'subtitle' => 'فعال / غیرفعال سازی زمان ، تعداد جلسه و امتیاز دوره در سایدبار',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),   

        array(
            'id' => 'courese_qiuck_active_v3',
            'title' => 'فعال سازی منوی دسترسی سریع دوره',
            'subtitle' => 'فعال / غیرفعال سازی منوی دسترسی سریع به بخش های دوره در سایدبار',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),   

        array(
            'id' => 'courese_buy_active_v3',
            'title' => 'فعال سازی قیمت و دکمه خرید دوره',
            'subtitle' => 'فعال / غیرفعال سازی قیمت و دکمه خرید دوره در سایدبار',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ), 

        array(
            'id' => 'courese_badge_active_v3',
            'title' => 'فعال سازی مدال های دوره',
            'subtitle' => 'فعال / غیرفعال سازی مدال های دوره در سایدبار',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ), 

        array(
            'id' => 'courese_date_publish_active_v3',
            'title' => 'فعال سازی تاریخ انتشار دوره',
            'subtitle' => 'فعال / غیرفعال سازی تاریخ انتشار دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),     
        
        array(
            'id' => 'courese_date_update_active_v3',
            'title' => 'فعال سازی تاریخ بروزرسانی دوره',
            'subtitle' => 'فعال / غیرفعال سازی تاریخ بروزرسانی دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),             
        
        array(
            'id' => 'courese_views_active_v3',
            'title' => 'فعال سازی تعداد بازدید دوره',
            'subtitle' => 'فعال / غیرفعال سازی تعداد بازدید دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),               
        
        array(
            'id' => 'courese_cm_active_v3',
            'title' => 'فعال سازی تعداد دیدگاه دوره',
            'subtitle' => 'فعال / غیرفعال سازی تعداد دیدگاه دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),              
        
        array(
            'id' => 'courese_cat_active_v3',
            'title' => 'فعال سازی دسته بندی دوره',
            'subtitle' => 'فعال / غیرفعال سازی دسته بندی دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),    


        array(
            'id' => 'courese_share_active_v3',
            'title' => 'فعال سازی اشتراک گذاری دوره',
            'subtitle' => 'فعال / غیرفعال سازی اشتراک گذاری دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),         

        array(
            'id' => 'courese_bookmart_active_v3',
            'title' => 'فعال سازی دکمه علاقه مندی دوره',
            'subtitle' => 'فعال / غیرفعال سازی دکمه افزودن به علاقه مندی دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),      

        array(
            'id' => 'courese_tag_active_v3',
            'title' => 'فعال سازی برچسب دوره',
            'subtitle' => 'فعال / غیرفعال سازی برچسب دوره',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),      
        
        array(
            'id' => 'courese_related_active_v3',
            'title' => 'فعال سازی دوره های مرتبط',
            'subtitle' => 'فعال / غیرفعال سازی دوره های مرتبط',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),  

        array(
            'id' => 'courese_parts_active_v3',
            'title' => 'فعال سازی سرفصل دوره ها',
            'subtitle' => 'فعال / غیرفعال سازی سرفصل های دوره ها  ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),  
        
        array(
            'id' => 'courese_comments_active_v3',
            'title' => 'فعال سازی نظرات دوره ها  ',
            'subtitle' => 'فعال / غیرفعال سازی نظرات دوره ها',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),  
        
        //style 02
        array(
            'id' => 'single_product_full_width',
            'title' => 'سبک نمایش تک محصول',
            'subtitle' => 'از این قسمت میتوانید مشخص کنید که صفحه محصولات بصورت تمام عرض یا باکسی باشد.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'باکسی',
                'disable' => 'تمام عرض',
            )
        ),  
        array(
            'id' => 'single_product_des_font_size',
            'type' => 'select',
            'title' => 'اندازه فونت توضیحات محصول',
            'subtitle' => 'از این قسمت میتوانید فونت اندازه توضیحات محصول را انتخاب کنید.',
            'options' => array(
                '14px' => '14px',
                '15px' => '15px',
                '16px' => '16px',
                '17px' => '17px',
                '18px' => '18px',
                '19px' => '19px',
                '20px' => '20px',
            ),
            'default' => '14px',
        ),        
        array(
            'id' => 'single_courses_popup_part',
            'title' => 'فعال / غیرفعال سازی پاپ آپ ویدئو جلسات',
            'subtitle' => 'از این قسمت میتوانید پاپ آپ نمایش ویدئو جلسات محصولات آموزشی را فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style03/single'),
        ),          
        array(
            'id' => 'signle_product_v2_atcive_default_tab',
            'title' => 'فعال سازی تب های پیشفرض ووکامرس',
            'subtitle' => 'با فعال سازی این بخش شما میتوانید تب های اختصاصی جدید را به تب های سبک محصول دیجیتال اضافه کنید.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),          
        array(
            'id' => 'single_product_color1_v2',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'رنگ اولیه محصول سبک فیزیکی',
            'subtitle' => 'رنگ اولیه تک محصول سبک دانلودی را از این قسمت میتوانید وارد کنید.',
            'default' => '#05aced',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'single_product_color2_v2',
            'required' => array('cart_style', '=', 'template-part/cart-fix'),
            'type' => 'color',
            'title' => 'رنگ ثانویه محصول سبک فیزیکی',
            'subtitle' => 'رنگ ثانویه تک محصول سبک دانلودی را از این قسمت میتوانید وارد کنید.',
            'default' => '#009688',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),        
        array(
            'id' => 'vendor_show_sgm',
            'title' => 'فعال سازی فروشنده',
            'subtitle' => 'نمایش نام فروشنده در صفحه محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'vendor_sgm_subtitle',
            'title' => 'متن زیر عنوان فروشنده',
            'subtitle' => 'متن زیر عنوان فروشنده را وارد کنید!',
            'type' => 'text',
            'required' => array(
                array('vendor_show_sgm', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'ارسال کالا از انبار فروشنده',
        ),
        array(
            'id' => 'stock_show_sgm',
            'title' => 'فعال سازی وضعیت موجودی کالا',
            'subtitle' => 'نمایش  وضعیت موجودی انبار در صفحه محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array(
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
        ),
        array(
            'id' => 'stock_sgm_subtitle',
            'title' => 'متن زیر عنوان موجود در انبار',
            'subtitle' => 'متن زیر عنوان موجود در انبار را وارد کنید.',
            'type' => 'text',
            'required' => array(
                array('stock_show_sgm', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'آماده ارسال از انبار فروشگاه',
        ),
        array(
            'id' => 'out_stock_sgm_subtitle',
            'title' => 'متن زیر عنوان عدم موجود در انبار',
            'subtitle' => 'متن زیر عنوان عدم موجود در انبار را وارد کنید.',
            'type' => 'text',
            'required' => array(
                array('stock_show_sgm', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'این محصول در انبار فروشگاه موجود نیست.',
        ),
        array(
            'id' => 'guarantee_active',
            'title' => 'فعال سازی متن گارانتی',
            'subtitle' => 'نمایش متن گارانتی محصولات در صفحه محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'guarantee_bold_title',
            'title' => 'متن ابتدایی گارانتی محصولات',
            'type' => 'text',
            'required' => array(
                array('guarantee_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'گارانتی',
        ),
        array(
            'id' => 'guarantee_title',
            'title' => 'متن کامل گارانتی محصولات',
            'type' => 'text',
            'required' => array(
                array('guarantee_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'بازگشت وجه و اصالت کالا',
        ),
        array(
            'id' => 'guarantee_subtitle',
            'title' => 'زیر عنوان گارانتی محصولات',
            'type' => 'text',
            'required' => array(
                array('guarantee_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'همراه با گارانتی ارائه بهترین محصول',
        ),
        array(
            'id' => 'delivery_active',
            'title' => 'فعال سازی متن ارسال و پرداخت محصول',
            'subtitle' => 'نمایش متن ارسال محصول در صفحه محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'delivery_bold_title',
            'title' => 'متن ابتدایی بخش ارسال محصولات',
            'type' => 'text',
            'required' => array(
                array('delivery_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'امکان',
        ),
        array(
            'id' => 'delivery_title',
            'title' => 'متن کامل بخش ارسال محصولات',
            'type' => 'text',
            'required' => array(
                array('delivery_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'تحویل و پرداخت در محل',
        ),
        array(
            'id' => 'delivery_subtitle',
            'title' => 'زیر عنوان بخش ارسال محصولات',
            'type' => 'text',
            'required' => array(
                array('delivery_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'با تمامی کارت های عضو شتاب',
        ),
        array(
            'id' => 'total_sale_sgm_active',
            'title' => 'نمایش / عدم نمایش تعداد فروش محصول',
            'subtitle' => 'نمایش متن ارسال محصول در صفحه محصول',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'gaurantee_time_active',
            'title' => 'نمایش / عدم نمایش مدت گارانتی',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'gaurantee_time_title',
            'title' => 'عنوان مدت گارانتی محصول',
            'type' => 'text',
            'required' => array(
                array('gaurantee_time_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'این کالا دارای ضمانت بازگت وجه به مدت یک هفته است.',
        ),
        array(
            'id' => 'country_send_active',
            'title' => 'نمایش / عدم ارسال به تمامی نقاط کشور',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'country_send_title',
            'title' => 'عنوان ارسال به تمامی نقاط کشور',
            'type' => 'text',
            'required' => array(
                array('country_send_active', '=', 'block'),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
            ),
            'default' => 'ارسال به تمامی نقاط کشور',
        ),
        array(
            'id' => 'badges_dgs_active',
            'title' => 'فعال / غیرفعال مدال محصولات',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
                array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),        
        array(
            'id' => 'comment_tab_active',
            'title' => 'فعال / غیرفعال سازی تب نظرات',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'more_dec_tab_active',
            'title' => 'فعال / غیرفعال سازی تب سایر مشخصات',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'seller_tab_active',
            'title' => 'فعال / غیرفعال سازی تب فروشنده',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'related_active',
            'title' => 'فعال / غیرفعال سازی محصولات مرتبط ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),
        array(
            'id' => 'tags_active',
            'title' => 'فعال / غیرفعال سازی برچسب محصولات ',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style02/single'),
        ),

        //style 01 start
        array(
            'id' => 'license_productv2',
            'title' => 'نمایش لایسنس استفاده از محصولات',
            'subtitle' => 'مشخص کنید. که آیا محتوای لایسنس یا قوانین محصولات نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'title_license',
            'title' => 'عنوان قوانین استفاده از محصول',
            'required' => array('license_productv2', '=', 'inherit'),
            'subtitle' => 'عنوان قوانین استفاده از محصول که در سایدبار کناری محصولات نمایش داده میشود را وارد کنید..',
            'default' => 'قوانین استفاده از محصول',
            'type' => 'text',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'img_license',
            'required' => array('license_productv2', '=', 'inherit'),
            'title' => 'تصویر قوانین استفاده از محصول',
            'subtitle' => 'تصویر ایکون قوانین استفاده از محصول را آپلود کنید. ، اندازه پیشنهاد 100*100 پیکس میباشد.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/license.svg'),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'title_detial',
            'title' => 'عنوان جزییات محصول',
            'subtitle' => 'عنوان جزییات محصول  که در سایدبار کناری محصولات نمایش داده میشود را وارد کنید..',
            'default' => 'جزئیات بیشتر و خرید محصول',
            'type' => 'text',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'img_detial',
            'title' => 'تصویر ایکون جزییات محصول',
            'subtitle' => 'تصویر ایکون جزییات محصول آپلود کنید. ، اندازه پیشنهاد 100*100 پیکس میباشد.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/info.svg'),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'license_product',
            'title' => 'نمایش لایسنس محصولات',
            'subtitle' => 'مشخص کنید. که آیا محتوای لایسنس محصول بصورت کامل نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'license_content',
            'required' => array('license_product', '=', 'inherit'),
            'title' => 'محتوای لایسنس محصولات',
            'subtitle' => 'محتوای لایسنس محصولات را در این قسمت وارد کنید.، سعی کنید. بصورت لیستی این آیتم ها را قرار دهید..',
            'default' => '<ul>
                        	<li>بسته نصبی + راهنمای نصب فارسی</li>
                        	<li>بی نهایت فونت زیبای فارسی</li>
                        	<li>لایسنس رایگان فونت ایرانسنس</li>
                        	<li>درگاه های پرداخت واسط و مستقیم</li>
                        	<li>پشتیبانی 24 ساعته محصولات</li>
                        	<li>محصول اورجینال با آپدیت رایگان</li>
                        	<li>بازگشت وجه بدون قید وشرط</li>
                        	</ul>',
            'type' => 'textarea',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'payment_img_active',
            'title' => 'نمایش تصویر درگاه های پرداخت محصولات',
            'subtitle' => 'مشخص کنید. که آیا تصویر درگاه های پرداخت نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'payment_img_title',
            'required' => array('payment_img_active', '=', 'inherit'),
            'title' => 'عنوان بخش تصویر پرداخت آنلاین',
            'subtitle' => 'عنوان بخش پرداخت در سایدبار کناری محصولات نمایش داده میشود را وارد کنید..',
            'default' => 'پرداخت امن با کلیه کارت های عضو شتاب',
            'type' => 'text',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'payment_img',
            'required' => array('payment_img_active', '=', 'inherit'),
            'title' => 'تصویر درگاه های پرداخت',
            'subtitle' => 'تصویر مورد نظر را برای بخش درگاه های پرداخت آپلود و انتخاب کنید..',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/shopping-cart.png'),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'woocommerce_show_hide',
            'type' => 'section',
            'indent' => true,
            'title' => ' تنظیمات بخش نمایش / پنهان ',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'show_price',
            'title' => 'فعال سازی حالت کاتالوگ',
            'subtitle' => 'با فعال سازی این قابلیت امکان خرید آنلاین محصولات غیرفعال شده و محصولات جنبه معرفی و کاتالوگ خواهند گرفت!',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'غیرفعال',
                'none' => 'فعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'show_demo_en',
            'title' => 'نمایش دکمه های پایین قیمت گذاری',
            'subtitle' => 'مشخص کنید. که آیا میخواهید دکمه هایی مانند پیشنمایش فارسی ، انگلیسی ، راهنمای کار با محصول در پایین سبد خرید نمایش داده شود یا خیر',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'info_product',
            'title' => 'نمایش اطلاعات محصول',
            'subtitle' => 'مشخص کنید. که اطلاعات محصول مانند حجم ، تاریخ ارسال و...  در صفحه جزییات محصول نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'info_product',
            'title' => 'نمایش اطلاعات محصول',
            'subtitle' => 'مشخص کنید. که اطلاعات محصول مانند حجم ، تاریخ ارسال و...  در صفحه جزییات محصول نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'vendor_show',
            'title' => 'نمایش باکس فروشنده',
            'subtitle' => 'مشخص کنید. که باکس فروشنده در صفحه جزییات محصول نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'vendor_show_btn',
            'title' => 'نمایش دکمه محصولات بیشتر طراح',
            'subtitle' => 'مشخص کنید. که دکمه محصولات بیشتر در صفحه جزییات محصول نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'sales',
            'title' => 'نمایش تعداد فروش محصول',
            'subtitle' => 'مشخص کنید. که میخواهید تعداد خرید محصولات در سایدبار کناری محصول نمایش داده شود یا خیر',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'update_show',
            'title' => 'نمایش تاریخ آخرین بروزرسانی',
            'subtitle' => 'مشخص کنید. که آیا میخواهید تاریخ آخرین بروزرسانی در جزییات محصول نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'support_show',
            'title' => 'نمایش دکمه پشتیبانی',
            'subtitle' => 'فعال یا غیرفعال سازی نمایش دکمه پشتیبانی',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),

        array(
            'id' => 'report_show',
            'title' => 'نمایش دکمه گزارش محصول',
            'subtitle' => 'فعال یا غیرفعال سازی نمایش دکمه گزارش محصول بصورت پاپ آپ',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'report_title',
            'title' => 'متن دکمه گزارش',
            'required' => array('report_show', '=', 'inherit'),
            'subtitle' => 'شماره تماس پشتیبانی هدر پنل کاربری را وارد کنید..',
            'type' => 'text',
            'default' => 'گزارش محصول',
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'support_link',
            'title' => 'لینک دکمه گزارش محصصول',
            'subtitle' => 'لینک مورد نظر برای دکمه گزارش محصول را در این بخش وارد کنید.!',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/submit-ticket',
            'required' => array('report_show', '=', 'inherit'),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
        array(
            'id' => 'urlshort_show',
            'title' => 'نمایش لینک کوتاه',
            'subtitle' => 'فعال یا غیرفعال سازی نمایش لینک کوتاه',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
            'required' => array('products_style_page', '=', 'template-part/content/product/signle-product-style01/single'),
        ),
    ),

));

Redux::setSection($opt_name, array(
    'title' => 'تنظیمات آرشیو محصولات',
    'id' => 'archive_products_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'free_products_checkout',
            'title' => 'فعال سازی تسویه حساب محصولات رایگان',
            'subtitle' => 'با فعال سازی این قابلیت محصولات رایگان نیز مانند سایر محصولات دارای دکمه افزودن به سبد خرید و تسویه حساب عادی ووکامرس خواهند شد.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),    
        array(
            'id' => 'free_product_text',
            'title' => 'متن سفارشی برای محصولات رایگان',
            'subtitle' => 'بصورت یپشفرض برای محصولات با قیمت صفر متن رایگان نمایش داده میشود شما میتوانید این متن را از این تغییر دهید. مثلا : تماس بگیرید.',
            'type' => 'text',
            'default' => 'تماس بگیرید!',
        ),        
        array(
            'id' => 'sold_out_product_text',
            'title' => 'متن سفارشی برای محصولات تمام شده',
            'subtitle' => 'شما میتوانید متن سفارشی را محصولات تمام شده در لیست آرشیو محصولات وارد کنید.',
            'type' => 'text',
            'default' => 'تمام شد!',
        ),                
        array(
            'id' => 'shop_page_layout',
            'title' => 'حالت نمایش صفحه فروشگاه و آرشیو محصولات',
            'subtitle' => 'از این قسمت میتوانید سبک باکسی یا تمام عرض صفحه فروشگاه و آرشیو محصولات را مشخص کنید.',
            'type' => 'button_set',
            'default' => '',
            'options' => array(
                '' => 'جعبه ای',
                '-fluid' => 'تمامی عرض',
            ),
        ),     
        array(
            'id' => 'shop_descreption',
            'title' => 'فعال / غیرفعال سازی توضیحات دسته بندی محصولات',
            'subtitle' => 'از این قسمت میتوانید توضیحات مربوط به دسته بندی محصولات را فغال / غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),           
        array(
            'id' => 'shop_sidebar',
            'type' => 'radio',
            'title' => 'سایدبار صفحه فروشگاه',
            'subtitle' => 'از قسمت میتوانید حالت نمایش سایدبار صفحه فروشگاه یا آرشیو محصولات را تغییر دهید.',
            'default' => 'right-sidebar',
            'options' => array(
                'left-sidebar' => 'سایدبار چپ',
                'right-sidebar' => 'سایدبار راست',
                'none-sidebar' => 'بدون سایدبار',
            ),
        ),       
    ),
));


Redux::setSection($opt_name, array(
    'title' => 'تنظیمات لوپ محصولات',
    'id' => 'loops_products_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'products_style_loops',
            'type' => 'select',
            'title' => 'سبک نمایش لوپ محصولات',
            'subtitle' => 'تنظیمات این بخش برای نمایش آرشیو محصولات ، آرشیو برند ها و دسته و برچسب محصولات اعمال میشود.',
            'options' => array(
                'template-part/content/loop/product/style01' => 'استایل یک (ویژه محصولات دانلودی)',
                'template-part/content/loop/product/style02' => 'استایل دو (ویژه محصولات فیزیکی)',
                'template-part/content/loop/product/style03' => 'استایل سه (ویژه دوره محصولات دانلودی)',
                'template-part/content/loop/product/style04' => 'استایل چهار (ویژه دوره محصولات دانلودی)',
                'template-part/content/loop/product/style05' => 'استایل پنج (ویژه دوره دوره آموزشی)',
            ),
            'default' => 'template-part/content/loop/product/style02'
        ),
        array(
            'id' => 'show_img_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی تصاویر محصولات',
            'subtitle' => 'شما میتوانید تصاویر لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی عنوان محصولات',
            'subtitle' => 'شما میتوانید عنوان لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_desc_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی توضیحات محصولات',
            'subtitle' => 'شما میتوانید توضیحات لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_cat_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی دسته بندی محصولات',
            'subtitle' => 'شما میتوانید دسته بندی لوپ محصولات سبک یک را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_price_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی قیمت محصولات',
            'subtitle' => 'شما میتوانید قیمت لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_btn_product_loop_v1',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style01'),
            'title' => 'فعال / غیرفعال سازی دکمه جزییات محصول ',
            'subtitle' => 'شما میتوانید دکمه جزییات محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
//style 02

        array(
            'id' => 'show_img_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی تصاویر محصولات',
            'subtitle' => 'شما میتوانید تصاویر لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی عنوان محصولات',
            'subtitle' => 'شما میتوانید عنوان لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_en_title_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی عنوان اانگلیسی محصولات',
            'subtitle' => 'شما میتوانید عنوان لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'show_price_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی قیمت محصولات',
            'subtitle' => 'شما میتوانید قیمت لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_cart_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی دکمه افزودن به سبد خرید محصولات',
            'subtitle' => 'شما میتوانید دکمه افزودن به سبد خرید محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_discount_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی درصد تخفیف محصولات',
            'subtitle' => 'شما میتوانید درصد تخفیف لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_qviews_product_loop_v2',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style02'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده سریع محصول ',
            'subtitle' => 'شما میتوانید دکمه مشاهده سریع محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
        
//style 03

        array(
            'id' => 'show_img_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی تصاویر محصولات',
            'subtitle' => 'شما میتوانید تصاویر لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی عنوان محصولات',
            'subtitle' => 'شما میتوانید عنوان لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_cat_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی دسته بندی محصولات',
            'subtitle' => 'شما میتوانید دسته بندی لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'show_price_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی قیمت محصولات',
            'subtitle' => 'شما میتوانید قیمت لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_cart_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده جزییات محصولات',
            'subtitle' => 'شما میتوانید دکمه جزییات محصول را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_discount_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی درصد تخفیف محصولات',
            'subtitle' => 'شما میتوانید درصد تخفیف لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_qviews_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده سریع محصول ',
            'subtitle' => 'شما میتوانید دکمه مشاهده سریع محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
        array(
            'id' => 'show_sale_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی تعداد خرید محصول ',
            'subtitle' => 'شما میتوانید تعداد خرید سریع محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ), 
        array(
            'id' => 'show_date_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی تاریخ انتشار محصول ',
            'subtitle' => 'شما میتوانید تاریخ انتشار محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_vendor_product_loop_v3',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style03'),
            'title' => 'فعال / غیرفعال سازی  فروشنده محصول ',
            'subtitle' => 'شما میتوانید دکمه فروشنده را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   

//style 04

        array(
            'id' => 'show_img_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی تصاویر محصولات',
            'subtitle' => 'شما میتوانید تصاویر لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی عنوان محصولات',
            'subtitle' => 'شما میتوانید عنوان لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_en_title_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی عنوان انگلیسی محصولات',
            'subtitle' => 'شما میتوانید عنوان انگلیسی لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_desc_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی توضیحات محصولات',
            'subtitle' => 'شما میتوانید توضیحات لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'show_cat_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی دسته بندی محصولات',
            'subtitle' => 'شما میتوانید دسته بندی لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'show_price_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی قیمت محصولات',
            'subtitle' => 'شما میتوانید قیمت لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_cart_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده جزییات محصولات',
            'subtitle' => 'شما میتوانید دکمه جزییات محصول را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_discount_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی درصد تخفیف محصولات',
            'subtitle' => 'شما میتوانید درصد تخفیف لوپ محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_qviews_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده سریع محصول ',
            'subtitle' => 'شما میتوانید دکمه مشاهده سریع محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
        array(
            'id' => 'show_sale_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی تعداد خرید محصول ',
            'subtitle' => 'شما میتوانید تعداد خرید سریع محصولات را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ), 
        array(
            'id' => 'show_vendor_product_loop_v4',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style04'),
            'title' => 'فعال / غیرفعال سازی  فروشنده محصول ',
            'subtitle' => 'شما میتوانید دکمه فروشنده را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   

//style 05

        array(
            'id' => 'show_img_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی تصاویر دوره',
            'subtitle' => 'شما میتوانید تصاویر لوپ دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'show_title_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی عنوان دوره',
            'subtitle' => 'شما میتوانید عنوان لوپ دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     
        array(
            'id' => 'show_en_title_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی عنوان انگلیسی دوره',
            'subtitle' => 'شما میتوانید عنوان انگلیسی لوپ دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_wishlist_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی علاقه مندی دوره',
            'subtitle' => 'شما میتوانید علاقه مندی دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),           
        array(
            'id' => 'show_desc_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی اطلاعات دوره',
            'subtitle' => 'شما میتوانید اطلاعات دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'show_badge_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی مدال دوره ها',
            'subtitle' => 'شما میتوانید مدال لوپ دوره ها را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),      
        array(
            'id' => 'show_avatar_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی آواتار مدرس   ',
            'subtitle' => 'شما میتوانید آواتار مدرس را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),           
        array(
            'id' => 'show_cart_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی دکمه مشاهده جزییات محصولات',
            'subtitle' => 'شما میتوانید دکمه جزییات محصول را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'show_qviews_product_loop_v5',
            'required' => array('products_style_loops', '=', 'template-part/content/loop/product/style05'),
            'title' => 'فعال / غیرفعال سازی دکمه افزودن به سبد دوره ',
            'subtitle' => 'شما میتوانید دکمه افزودن به سبد خرید دوره را از این قسمت فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
    ),
));


// -> START font Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات فونت',
    'id' => 'font_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-fontsize',
    'fields' => array(
        array(
            'id' => 'font_family_section',
            'title' => 'تنظیمات تایپوگرافی قالب',
            'type' => 'section',
            'indent' => true
        ),
/*        array(
            'id' => 'body_font_custom',
            'title' => 'فعال سازی فونت سفارشی بدنه سایت',
            'subtitle' => 'از این قسمت میتوانید فونت سفارشی برای بدنه سایت خود انتخاب کنید.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),    
        array(
            'id' => 'lists_font_custom_name',
            'required' => array('body_font_custom', '=', 'enable'),
            'title' => 'نام فونت',
            'subtitle' => 'نام فونت سفارشی را در این قسمت وارد کنید!',
            'type' => 'text',
            'placeholder' => 'Iransans'
        ),
        array(
            'id' => 'lists_font_custom_fft',
            'type'      => 'upload',
            'title' => 'آپلود فایل ttf فونت ',
            'subtitle'  => 'فایل ttf فونت مورد نظر را از این قسمت آپلود کنید.',
            'max_file_upload' => 5
        ),        */
        array(
            'id' => 'body_font',
            'type' => 'select',
            'title' => 'فونت بدنه سایت',
            'subtitle' => 'از بین فونت های موجود یک فونت را برای فونت بدنه سایت خود انتخاب کنید!',
            'options' => array(
                'sahelfont' => 'ساحل (جدید)',
                'gandomfont' => 'گندم (جدید)',
                'tanhafont' => 'تنها (جدید)',
                'parsatofont' => 'پرستو (جدید)',
                'nahidfont' => 'ناهید (جدید)',
                'IRANSans' => 'ایرانسنس',
                'iranyekan' => 'ایران یکان',
                'naskhfont' => 'دریود نسخ',
                'tahoma' => 'تاهوما',
                'samimwp' => 'سمیم',
                'yekanwp' => 'یکان',
                'shabnamwp' => 'شبنم',
                'vazirwp' => 'وزیر',
                'koodakwp' => 'کودک',
                'mitrawp' => 'میترا',
                'nazaninwp' => 'نازنین',
            ),
            'default' => 'IRANSans',
        ),
/*        array(
            'id' => 'header_font_custom',
            'title' => 'فعال سازی فونت سفارشی هدر سایت',
            'subtitle' => 'از این قسمت میتوانید فونت سفارشی برای هدر سایت خود انتخاب کنید.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),     */
        array(
            'id' => 'head_font',
            'type' => 'select',
            'title' => 'فونت هدینگ های سایت',
            'subtitle' => 'از بین فونت های موجود ه فونت را برای فونت هدینگ سایت خود انتخاب کنید!',
            'options' => array(
                'sahelfont' => 'ساحل (جدید)',
                'gandomfont' => 'گندم (جدید)',
                'tanhafont' => 'تنها (جدید)',
                'parsatofont' => 'پرستو (جدید)',
                'nahidfont' => 'ناهید (جدید)',
                'IRANSans' => 'ایرانسنس',
                'iranyekan' => 'ایران یکان',
                'naskhfont' => 'دریود نسخ',
                'tahoma' => 'تاهوما',
                'samimwp' => 'سمیم',
                'yekanwp' => 'یکان',
                'shabnamwp' => 'شبنم',
                'vazirwp' => 'وزیر',
                'koodakwp' => 'کودک',
                'mitrawp' => 'میترا',
                'nazaninwp' => 'نازنین',
            ),
            'default' => 'IRANSans',
        ),
/*        array(
            'id' => 'lists_font_custom',
            'title' => 'فعال سازی فونت سفارشی لیست های سایت',
            'subtitle' => 'از این قسمت میتوانید فونت سفارشی برای لیست سایت خود انتخاب کنید.',
            'type' => 'button_set',
            'default' => 'disable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ), */
        array(
            'id' => 'lists_font',
            'type' => 'select',
            'title' => 'فونت لیست ها یا منوهای سایت',
            'subtitle' => 'از بین فونت های موجود یک فونت را برای فونت لیست ها یا منوهای سایت خود انتخاب کنید!',
            'options' => array(
                'sahelfont' => 'ساحل (جدید)',
                'gandomfont' => 'گندم (جدید)',
                'tanhafont' => 'تنها (جدید)',
                'parsatofont' => 'پرستو (جدید)',
                'nahidfont' => 'ناهید (جدید)',
                'IRANSans' => 'ایرانسنس',
                'iranyekan' => 'ایران یکان',
                'naskhfont' => 'دریود نسخ',
                'tahoma' => 'تاهوما',
                'samimwp' => 'سمیم',
                'yekanwp' => 'یکان',
                'shabnamwp' => 'شبنم',
                'vazirwp' => 'وزیر',
                'koodakwp' => 'کودک',
                'mitrawp' => 'میترا',
                'nazaninwp' => 'نازنین',
            ),
            'default' => 'IRANSans',
        ),
    )));

// -> START User Dashbaard Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات بخش کاربران',
    'id' => 'dashbaord_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-user',
));
// -> START LastPass Setting
Redux::setSection($opt_name, array(
    'title' => 'بازنشانی تغییر رمز',
    'id' => 'lost_pass_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'lostt_style_page',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای صفحه فراموشی رمز عبور خود انتخاب کنید..',
            'options' => array(
                'dashboard/last-password/last-password-style-one' => 'استایل یک',
                'dashboard/last-password/last-password-style-two' => 'استایل دو',
                'dashboard/last-password/last-password-style-three' => 'استایل سه',
                'dashboard/last-password/last-password-style-four' => 'استایل چهار',
            ),
            'default' => 'dashboard/last-password/last-password-style-four'
        ),
        array(
            'id' => 'lost_section_v1',
            'required' => array('lostt_style_page', '=', 'dashboard/last-password/last-password-style-one'),
            'title' => 'تنظیمات صفحه فراموشی عبور سبک یک',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'reset_page_back',
            'title' => 'رنگ پس زمینه صفحه فراموشی رمز عبور',
            'subtitle' => 'رنگ پس زمینه صفحه فراموشی رمز عبور را انتخاب کنید...',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#2dc1e5',),
        ),
        array(
            'id' => 'reset_form_back',
            'title' => 'رنگ پس زمینه فرم',
            'subtitle' => 'رنگ پس زمینه فرم فراموشی عبور - سبک یک',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#ffffff',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/loginwp.png'),
        ),
        array(
            'id' => 'lost_section_v2',
            'required' => array('lostt_style_page', '=', 'dashboard/last-password/last-password-style-two'),
            'title' => 'تنظیمات صفحه فراموشی عبور سبک دو',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'reset_v2_bg',
            'title' => 'اعمال تصویر برای کل صفحه',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه فراموشی رمز عبور سایت را آپلود یا آدرس را وارد کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg_v2.jpg'),
        ),
        array(
            'id' => 'lost_pass_v2_left_box_back_photo',
            'title' => 'اعمال تصویر پس زمینه برای کادر - سمت چپ',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه فراموشی رمز عبور سمت چپ را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg-final-1.png'),
        ),
        array(
            'id' => 'content_reset_form_text',
            'title' => 'متن بالای فرم فراموشی عبور',
            'subtitle' => 'متن بالای فرم فراموشی عبور را وارد کنید!',
            'default' => 'برای دسترسی به امکانات پنل کاربری ورود به سایت ضروری است ، از طریق فرم زیر با استفاده از مشخصات موجود وارد پنل کاربری شوید.',
            'type' => 'text',
        ),
        array(
            'id' => 'lost_image_v2',
            'title' => 'لوگوی سایت در توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/logo-light.png'),
        ),
        array(
            'id' => 'losst_user_image_v2',
            'title' => 'تصویر آدمک بخش فراموشی رمز عبور در سایت توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک تصویر سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/boy-150x150.png'),
        ),
        array(
            'id' => 'content_reset',
            'title' => 'محتوای توضیحات بخش فراموشی کلمه عبور سایت',
            'subtitle' => 'محتوای توضیحات بخش فراموشی کلمه عبور را در این قسمت وارد کنید.، سعی کنید. بصورت لیستی این آیتم ها را قرار دهید..',
            'default' => '<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا از مرورگرهای مطمئن و بروز مانند گوگل کروم و فایرفاکس استفاده کنید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا کلمه عبور خود را در فواصل زمانی کوتاه تغییر دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;این سایت هرگز اطلاعات محرمانه شما را از طریق ایمیل درخواست نمی کند. در صورت رخداد این مورد، سریعا به ما اطلاع دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا به آدرس صفحه توجه داشته باشید که بر روی دامنه Hamkarwp.com باشد. در غیر این صورت اکیدا توصیه می&zwnj;شود از وارد کردن اطلاعات ورود خودداری فرمایید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp; پوسته فروشگاهی سیگما پلاس توسط تیم همکار وردپرس کدنویسی شده و تنها در وب سایت ژاکت بفروش رسیده قابل خرید و پشتیبانی می باشد.</span></p>',
            'type' => 'editor',
        ),
        array(
            'id' => 'content_reset_btn_text',
            'title' => 'متن دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'متن دکمه اطلاعات بیشتر مصفحه را وارد کنید.!',
            'default' => 'برای مشاهده نکات بیشتر کلیک کنید.!',
            'type' => 'text',
        ),
        array(
            'id' => 'content_reset_btn_link',
            'title' => 'لینک دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'لینک دکمه اطلاعات بیش این صفحه را وارد کنید.!.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/'
        ),
        array(
            'id' => 'lost_section_v3',
            'required' => array('lostt_style_page', '=', 'dashboard/last-password/last-password-style-three'),
            'title' => 'تنظیمات صفحه فراموشی عبور سبک سه',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'lost_pass_v3_box_back',
            'title' => 'تغییر پس زمینه در صفحه فراموشی رمز عبور',
            'subtitle' => 'از این بخش می توانید سبک صفحه فراموشی رمز عبور را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-image' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#E0E0E0'),

        ),
        array(
            'id' => 'lost_pass_v13_box_back',
            'title' => 'تغییر پس زمینه در کادر فراموشی رمز عبور',
            'subtitle' => 'از این بخش می توانید سبک کادر فراموشی رمز عبور را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-image' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#0140C3',)
        ),
        array(
            'id' => 'lost_section_v4',
            'required' => array('lostt_style_page', '=', 'dashboard/last-password/last-password-style-four'),
            'title' => 'تنظیمات صفحه فراموشی عبور سبک چهار',
            'type' => 'section',
            'indent' => true
        ),
        array(
            'id' => 'lost_pass_v4_full_back',
            'title' => 'رنگ پس زمینه کل صفحه فراموشی رمز عبور',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کل صفحه فراموشی رمز عبور را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942',)
        ),
        array(
            'id' => 'lost_pass_v4_back',
            'title' => 'رنگ پس زمینه کادر فراموشی رمز',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کادر فراموشی رمز عبور را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942'),
        ),
        array(
            'id' => 'lost_pass_v4_back_border_top_color',
            'title' => 'تعیین رنگ حاشیه بالا',
            'subtitle' => 'از این قسمت می توانید رنگ حاشیه بالای کادر فراموشی رمز عبور را تغییر دهید..',
            'type' => 'color',
            'default' => '#79a6fe'
        ),
    ),
));


// -> START register Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات صفحه عضویت ',
    'id' => 'register_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'regiss_style_page',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای صفحه عضویت در سایت خود انتخاب کنید..',
            'options' => array(
                'dashboard/register/register-style-one' => 'استایل یک',
                'dashboard/register/register-style-two' => 'استایل دو',
                'dashboard/register/register-style-three' => 'استایل سه',
                'dashboard/register/register-style-four' => 'استایل چهار',
            ),
            'default' => 'dashboard/register/register-style-four'
        ),
        array(
            'id' => 'regiss_v1_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('regiss_style_page', '=', 'dashboard/register/register-style-one'),
            'title' => 'تنظیمات صفحه عضویت سبک شماره یک',
        ),
        array(
            'id' => 'register_container_bg',
            'title' => 'رنگ پس زمینه فرم ثبت نام',
            'subtitle' => 'رنگ پس زمینه فرم ثبت را از اینجا انتخاب کنید.!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#ffffff',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/loginwp.png'),
        ),
        array(
            'id' => 'register_page_back',
            'title' => 'رنگ پس زمینه صفحه عضویت',
            'subtitle' => 'رنگ پس زمینه صفحه عضویت را انتخاب کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#2dc1e5',),
        ),
        array(
            'id' => 'regiss_v1_full_2',
            'type' => 'section',
            'indent' => true,
            'required' => array('regiss_style_page', '=', 'dashboard/register/register-style-two'),
            'title' => 'تنظیمات صفحه عضویت سبک شماره دو',
        ),
        array(
            'id' => 'register_v2_bg',
            'title' => 'اعمال تصویر برای کل صفحه',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه عضویت سایت را آپلود یا آدرس را وارد کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg_v2.jpg'),
        ),
        array(
            'id' => 'register_v2_left_box_back_photo',
            'title' => 'اعمال تصویر پس زمینه برای کادر - سمت چپ',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه عضویت سمت چپ را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg-final-1.png'),
        ),
        array(
            'id' => 'register_user_image_v2',
            'title' => 'تصویر آدمک بخش عضویت در سایت توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک تصویر سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/boy-150x150.png'),
        ),
        array(
            'id' => 'content_register_form_text',
            'title' => 'متن بالای فرم عضویت',
            'subtitle' => 'متن بالای فرم عضویت را وارد کنید!',
            'default' => 'برای دسترسی به امکانات پنل کاربری ورود به سایت ضروری است ، از طریق فرم زیر با استفاده از مشخصات موجود وارد پنل کاربری شوید.',
            'type' => 'text',
        ),
        array(
            'id' => 'register_image_v2',
            'title' => 'لوگوی سایت در توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/logo-light.png'),
        ),
        array(
            'id' => 'register_user_image_v2',
            'title' => 'تصویر آدمک بخش عضویت در سایت توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک تصویر سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/boy-150x150.png'),
        ),
        array(
            'id' => 'content_register',
            'title' => 'محتوای توضیحات بخش عضویت در سایت',
            'subtitle' => 'محتوای توضیحات بخش عضویت در را در این قسمت وارد کنید.، سعی کنید. بصورت لیستی این آیتم ها را قرار دهید..',
            'default' => '<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا از مرورگرهای مطمئن و بروز مانند گوگل کروم و فایرفاکس استفاده کنید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا کلمه عبور خود را در فواصل زمانی کوتاه تغییر دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;این سایت هرگز اطلاعات محرمانه شما را از طریق ایمیل درخواست نمی کند. در صورت رخداد این مورد، سریعا به ما اطلاع دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا به آدرس صفحه توجه داشته باشید که بر روی دامنه Hamkarwp.com باشد. در غیر این صورت اکیدا توصیه می&zwnj;شود از وارد کردن اطلاعات ورود خودداری فرمایید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp; پوسته فروشگاهی سیگما پلاس توسط تیم همکار وردپرس کدنویسی شده و تنها در وب سایت ژاکت بفروش رسیده قابل خرید و پشتیبانی می باشد.</span></p>',
            'type' => 'editor',
        ),
        array(
            'id' => 'content_register_btn_text',
            'title' => 'متن دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'متن دکمه اطلاعات بیشتر مصفحه را وارد کنید.!',
            'default' => 'برای مشاهده نکات بیشتر کلیک کنید.!',
            'type' => 'text',
        ),
        array(
            'id' => 'content_register_btn_link',
            'title' => 'لینک دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'لینک دکمه اطلاعات بیش این صفحه را وارد کنید.!.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/'
        ),
        array(
            'id' => 'register_v3_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('regiss_style_page', '=', 'dashboard/register/register-style-three'),
            'title' => 'تنظیمات صفحه عضویت سبک شماره سه',
        ),
        array(
            'id' => 'register_v3_box_back',
            'title' => 'رنگ پس زمینه کادر صفحه عضویت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کادر عضویت را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#074cca',),
        ),
        array(
            'id' => 'register_v3_full_back',
            'title' => 'رنگ پس زمینه کل صفحه عضویت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کل صفحه عضویت را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#E0E0E0',),
        ),
        array(
            'id' => 'regiss_v4_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('regiss_style_page', '=', 'dashboard/register/register-style-four'),
            'title' => 'تنظیمات صفحه عضویت سبک شماره چهار',
        ),
        array(
            'id' => 'register_v4_back',
            'title' => 'رنگ پس زمینه کادر عضویت در سایت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کادر صفحه عضویت را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942',),
        ),
        array(
            'id' => 'register_v4_full_back',
            'title' => 'رنگ پس زمینه کل صفحه صفحه عضویت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کل صفحه صفحه عضویت را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942',),
        ),
        array(
            'id' => 'register_v4_back_border_top_color',
            'title' => 'تعیین رنگ حاشیه بالا',
            'subtitle' => 'از این قسمت می توانید رنگ حاشیه بالای کادر صفحه عضویت را تغییر دهید..',
            'type' => 'color',
            'default' => '#79a6fe'
        ),
    )
));

// -> START Loign Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات صفحه ورود ',
    'id' => 'login_setting',
    'customizer_width' => '400px',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'logiin_style_page',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای صفحه ورود به سایت خود انتخاب کنید..',
            'options' => array(
                'dashboard/login/login-style-one' => 'استایل یک',
                'dashboard/login/login-style-two' => 'استایل دو',
                'dashboard/login/login-style-three' => 'استایل سه',
                'dashboard/login/login-style-four' => 'استایل چهار',
            ),
            'default' => 'dashboard/login/login-style-four'
        ),
        array(
            'id' => 'logiin_v1_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('logiin_style_page', '=', 'dashboard/login/login-style-one'),
            'title' => 'تنظیمات صفحه ورود سبک شماره یک',
        ),
        array(
            'id' => 'logiin_page_back',
            'title' => 'رنگ پس زمینه صفحه ورود',
            'subtitle' => 'رنگ پس زمینه صفحه ورود را انتخاب کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#2dc1e5',),
        ),
        array(
            'id' => 'logiin_container_bg',
            'title' => 'رنگ پس زمینه فرم ورود',
            'subtitle' => 'رنگ پس زمینه فرم ورود را از اینجا انتخاب کنید.!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#ffffff',
                'background-image' => '' . get_template_directory_uri() . '/assets/img/loginwp.png'),
        ),
        array(
            'id' => 'logiin_2_title1',
            'type' => 'section',
            'indent' => true,
            'required' => array('logiin_style_page', '=', 'dashboard/login/login-style-two'),
            'title' => 'تنظیمات صفحه ورود سبک شماره دو',
        ),
        array(
            'id' => 'logiin_v2_bg',
            'title' => 'اعمال تصویر برای کل صفحه',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه ورود سایت را آپلود یا آدرس را وارد کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg_v2.jpg'),
        ),
        array(
            'id' => 'logiin_v2_left_box_back_photo',
            'title' => 'اعمال تصویر پس زمینه برای کادر - سمت چپ',
            'subtitle' => 'تصویر پس زمینه نسخه دو صفحه ورود سمت چپ را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-color' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/login_bg-final-1.png'),
        ),
        array(
            'id' => 'logiin_user_image_v2',
            'title' => 'تصویر آدمک بخش عضویت در سایت توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک تصویر سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/boy-150x150.png'),
        ),
        array(
            'id' => 'content_logiin_form_text',
            'title' => 'متن بالای فرم ورود به سایت',
            'subtitle' => 'متن بالای فرم ورود را وارد کنید!',
            'default' => 'برای دسترسی به امکانات پنل کاربری ورود به سایت ضروری است ، از طریق فرم زیر با استفاده از مشخصات موجود وارد پنل کاربری شوید.',
            'type' => 'text',
        ),
        array(
            'id' => 'logiin_image_v2',
            'title' => 'لوگوی سایت در توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/logo-light.png'),
        ),
        array(
            'id' => 'logiin_user_image_v2',
            'title' => 'تصویر آدمک بخش عضویت در سایت توضیحات سمت چپ',
            'subtitle' => 'شما میتوانید یک تصویر سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید.. ',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/boy-150x150.png'),
        ),
        array(
            'id' => 'content_logiin',
            'title' => 'محتوای توضیحات بخش ورود در سایت',
            'subtitle' => 'محتوای توضیحات بخش عضویت در را در این قسمت وارد کنید.، سعی کنید. بصورت لیستی این آیتم ها را قرار دهید..',
            'default' => '<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا از مرورگرهای مطمئن و بروز مانند گوگل کروم و فایرفاکس استفاده کنید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا کلمه عبور خود را در فواصل زمانی کوتاه تغییر دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;این سایت هرگز اطلاعات محرمانه شما را از طریق ایمیل درخواست نمی کند. در صورت رخداد این مورد، سریعا به ما اطلاع دهید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp;لطفا به آدرس صفحه توجه داشته باشید که بر روی دامنه Hamkarwp.com باشد. در غیر این صورت اکیدا توصیه می&zwnj;شود از وارد کردن اطلاعات ورود خودداری فرمایید.</span></p>
	<p style="text-align: right;"><span style="color: #ffffff;"><i class="fal fa-angle-left" aria-hidden="true"></i>&nbsp; پوسته فروشگاهی سیگما پلاس توسط تیم همکار وردپرس کدنویسی شده و تنها در وب سایت ژاکت بفروش رسیده قابل خرید و پشتیبانی می باشد.</span></p>',
            'type' => 'editor',
        ),
        array(
            'id' => 'content_logiin_btn_text',
            'title' => 'متن دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'متن دکمه اطلاعات بیشتر مصفحه را وارد کنید.!',
            'default' => 'برای مشاهده نکات بیشتر کلیک کنید.!',
            'type' => 'text',
        ),
        array(
            'id' => 'content_logiin_btn_link',
            'title' => 'لینک دکمه اطلاعات بیشتر صفحه',
            'subtitle' => 'لینک دکمه اطلاعات بیش این صفحه را وارد کنید.!.',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/'
        ),
        array(
            'id' => 'logiin_33_t_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('logiin_style_page', '=', 'dashboard/login/login-style-three'),
            'title' => 'تنظیمات صفحه ورود سبک شماره سه',
        ),
        array(
            'id' => 'logiin_v3_box_back',
            'title' => 'رنگ پس زمینه کادر صفحه ورود',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کادر ورود را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#074cca',),
        ),
        array(
            'id' => 'logiin_v3_full_back',
            'title' => 'رنگ پس زمینه کل صفحه ورود',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کل صفحه ورود را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#E0E0E0',),
        ),
        array(
            'id' => 'logiin_v4_full',
            'type' => 'section',
            'indent' => true,
            'required' => array('logiin_style_page', '=', 'dashboard/login/login-style-four'),
            'title' => 'تنظیمات صفحه ورود سبک شماره چهار',
        ),
        array(
            'id' => 'logiin_v4_full_back',
            'title' => 'رنگ پس زمینه کل صفحه صفحه ورود',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کل صفحه صفحه ورود را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942',),
        ),
        array(
            'id' => 'logiin_v4_back',
            'title' => 'رنگ پس زمینه کادر ورود در سایت',
            'subtitle' => 'از این قسمت می توانید رنگ پس زمینه کادر صفحه ورود را تغییر دهید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#212942',),
        ),
        array(
            'id' => 'logiin_v4_back_border_top_color',
            'title' => 'تعیین رنگ حاشیه بالا',
            'subtitle' => 'از این قسمت می توانید رنگ حاشیه بالای کادر صفحه ورود را تغییر دهید..',
            'type' => 'color',
            'default' => '#79a6fe'
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => 'پنل فروشندگان',
    'id' => 'vendor_setting',
    'subsection' => true,
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'dokan-show',
            'title' => 'غیرفعال سازی پنل فروشندگان',
            'subtitle' => 'تنها در صورتی این بخش را غیرفعال کنید. که تصمیم داشته باشید بخش فروشندگان سایت را حذف کنید. ،همچنین پس از غیرفعال سازی این بخش افزونه  دکان را نیز حذف نمایید.',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'vendor_panel_style',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای پنل فروشندگان خود انتخاب کنید..',
            'subtitle' => 'این طرح برای صفحات داخلی پنل کاربران و صفحاتی که قالب آن ها Dokan Panel تنظیم شده باشد!',
            'options' => array(
                'dashboard/vendor/vendor-v1' => 'استایل یک',
                'dashboard/vendor/vendor-v2' => 'استایل دو',
            ),
            'default' => 'dashboard/vendor/vendor-v2'
        ),
        array(
            'id' => 'dokan_btn_title',
            'title' => 'عنوان دکمه پنل فروشندگان',
            'subtitle' => 'عنوان دکمه پنل فروشندگان را وارد کنید!',
            'type' => 'text',
            'required' => array('dokan-show', '=', 'block'),
            'default' => 'ورود به پنل فروشندگان',
        ),
        array(
            'id' => 'dokan_btn_link',
            'title' => 'لینک دکمه پنل فروشندگان',
            'subtitle' => 'لینک دکمه پنل فروشندگان را وارد کنید!',
            'type' => 'text',
            'required' => array('dokan-show', '=', 'block'),
            'default' => '' . get_site_url() . '/dashboard'
        ),
        array(
            'id' => 'dokan_btn_icon',
            'title' => 'آیکون دکمه پنل فروشندگان',
            'subtitle' => 'آیکون دکمه پشتیبانی فروشندگان را از این قسمت وارد کنید!',
            'type' => 'text',
            'required' => array('dokan-show', '=', 'block'),
            'default' => 'fal fa-hourglass-1',
        ),
        array(
            'id' => 'dokan_btn_icon',
            'title' => 'آیکون دکمه پنل فروشندگان',
            'subtitle' => 'آیکون دکمه پشتیبانی فروشندگان را از این قسمت وارد کنید!',
            'type' => 'text',
            'required' => array('dokan-show', '=', 'block'),
            'default' => 'fal fa-hourglass-1',
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => 'پنل کاربران',
    'subsection' => true,
    'id' => 'user_setting_panel',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'active_woo_my_account_nav',
            'title' => 'فعال سازی منوی پیشفرض ووکامرس',
            'subtitle' => 'با غیرفعال سازی این بخش منوی پیشفرض حساب من ووکامرس از منوی کاربران حذف شده و شما میتوانید منوی سفارشی که از قسمت نمایش / فهرست ها / مدیریت جایگاه ها به عنوان منوی پنل کاربری انتخاب کرده اید را نمایش دهید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'بله',
                'disbale' => 'خیر',
            ),
        ),     
        array(
            'id' => 'panel_logo',
            'title' => 'لوگوی پنل کاربری',
            'subtitle' => 'شما میتوانید یک لوگو سفارشی از کتابخانه پرونده چند رسانه ای خود انتخاب کنید..  اندازه پیشنهادی : 40*40',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/favicon-v2.png'),
        ),
        array(
            'id' => 'user_panel_style_index',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای صفحه داخلی پنل کاربران خود انتخاب کنید..',
            'subtitle' => 'این طرح برای صفحات داخلی پنل کاربران و صفحاتی که قالب آن ها Profile New Sigma تنظیم شده باشد!',
            'options' => array(
                'dashboard/user/panel-v1' => 'استایل یک',
                'dashboard/user/panel-v2' => 'استایل دو',
            ),
            'default' => 'dashboard/user/panel-v1'
        ),
        array(
            'id' => 'user_panel_style',
            'type' => 'select',
            'title' => 'یک طرح از بین طرح های موجود برای صفحه پنل کاربران خود انتخاب کنید..',
            'desc' => 'با انتخاب هر طرح تنظیمات مربوطه نمایش داده شده و آن طرح به عنوان طرح پنل کاربران انتخاب میشود!',
            'options' => array(
                'dashboard/user/dashboard-v1' => 'استایل یک',
                'dashboard/user/dashboard-v2' => 'استایل دو',
            ),
            'default' => 'dashboard/user/dashboard-v1'
        ),
        array(
            'id' => 'section_01_01_general',
            'title' => 'تنظیمات عمومی پنل کاربران',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'welcome_panel_active',
            'title' => 'نمایش پیغام خوش آمدگویی پنل کاربری',
            'subtitle' => 'پیغام خوش آمدگویی در ابتدای پنل کاربری نمایش داده شود یا خیر؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'بله',
                'none' => 'خیر',
            ),
        ),
        array(
            'id' => 'codeoff_active',
            'title' => 'نمایش باکس تخفیف در پنل کاربری',
            'subtitle' => 'مشخص کنید که آیا میخواهید باکس تخفیف در پنل کاربری نمایش داده شود؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'codeoff_panel',
            'title' => 'کد تخفیف پنل کاربری',
            'required' => array('codeoff_active', '=', 'inherit'),
            'subtitle' => 'کد تخفیف پنل کاربری را جهت نمایش به کاربران وارد کنید..',
            'type' => 'text',
            'default' => 'HiSigmaZhaket'
        ),
        array(
            'id' => 'codeoff_panel_icon',
            'title' => 'آیکون کد تخفیف پنل کاربری',
            'required' => array('codeoff_active', '=', 'inherit'),
            'subtitle' => 'آیکون مورد نظر را برای کد تخفیف پنل کاربری را وارد کنید.. تمامی ایکون های Font Awesome پشتیبانی می شود. بصورت fal fa-send وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-gift'
        ),
        array(
            'id' => 'codeoff_title_panel',
            'required' => array('codeoff_active', '=', 'inherit'),
            'title' => 'متن کد تخفیف پنل کاربری',
            'subtitle' => 'متن کد تخفیف پنل کاربری را جهت نمایش به کاربران وارد کنید..',
            'type' => 'text',
            'default' => 'کد تخفیف فعال ۲۰ درصدی برای خرید های بعدی شما'
        ),
        array(
            'id' => 'usermeta_box_panel',
            'title' => 'باکس تعداد خرید ، سفارش ، تیکت و ...',
            'subtitle' => 'نمایش / مخفی سازی لینک باکس عملکرد کاربر در پنل کاربری',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'usermeta_title_01',
            'title' => 'عنوان تعداد نظرات',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'subtitle' => 'عنوان مورد نظر را بخش تعداد نظرات کاربر را وارد کنید!',
            'type' => 'text',
            'default' => 'نظرات ثبت شده',
        ),
        array(
            'id' => 'usermeta_title_02',
            'title' => 'عنوان تعداد محصولات خریداری شده',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'subtitle' => 'عنوان مورد نظر را بخش تعداد محصولات خریداری شده کاربر را وارد کنید!',
            'type' => 'text',
            'default' => 'محصولات خریداری شده',
        ),
        array(
            'id' => 'usermeta_link_02',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'title' => 'لینک تعداد محصولات خریداری شده',
            'subtitle' => 'لینک تعداد محصولات خریداری شده را وارد کنید!',
            'type' => 'text',
            'default' => '' . get_site_url() . '/my-account/downloads'
        ),
        array(
            'id' => 'usermeta_title_03',
            'title' => 'عنوان تعداد تیکت های پشتیبانی ',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'subtitle' => 'عنوان مورد نظر را بخش تعداد تیکت های پشتیبانی کاربر را وارد کنید!',
            'type' => 'text',
            'default' => 'تیکت های پشتیبانی',
        ),
        array(
            'id' => 'usermeta_link_03',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'title' => 'لینک تعداد تیکت های پشتیبانی',
            'subtitle' => 'لینک تعداد تیکت های پشتیبانی را وارد کنید!',
            'type' => 'text',
            'default' => '' . get_site_url() . '/tickets'
        ),
        array(
            'id' => 'usermeta_title_04',
            'title' => 'عنوان مبلغ سفارشات انجام شده  ',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'subtitle' => 'عنوان مورد نظر را بخش تعداد محصولات خریداری شده کاربر را وارد کنید!',
            'type' => 'text',
            'default' => 'سفارشات انجام شده',
        ),
        array(
            'id' => 'usermeta_link_04',
            'required' => array('usermeta_box_panel', '=', 'block'),
            'title' => 'لینک مبلغ سفارشات انجام شده',
            'subtitle' => 'لینک مبلغ سفارشات انجام شده را وارد کنید!',
            'type' => 'text',
            'default' => '' . get_site_url() . '/my-account/orders'
        ),
        array(
            'id' => 'notif_active',
            'title' => 'نمایش باکس اعلان در پنل کاربری',
            'subtitle' => 'مشخص کنید که آیا میخواهید باکس اعلان در پنل کاربری نمایش داده شود؟',
            'type' => 'button_set',
            'default' => 'block',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'notif_title_panel',
            'required' => array('notif_active', '=', 'block'),
            'title' => 'عنوان بخش آخرین اطلاعیه ها',
            'subtitle' => 'عنوان بخش آخرین اطلاعیه ها را وارد کنید..',
            'type' => 'text',
            'default' => 'آخرین اعلان ها'
        ),
        array(
            'id' => 'notif_cat_panel',
            'required' => array('notif_active', '=', 'block'),
            'title' => 'دسته بندی بخش آخرین اطلاعیه ها',
            'subtitle' => 'آیدی دسته بندی مورد نظر که میخواهید مطالب آن دسته بندی به عنوان آخرین اطلاعیه ها در این بخش نمایش داده شود را وارد کنید..',
            'type' => 'select',
            'data' => 'categories',
            'default' => '23'
        ),
        array(
            'id' => 'notif_counter_panel',
            'required' => array('notif_active', '=', 'block'),
            'title' => 'تعداد اطلاعیه ها جهت نمایش ',
            'subtitle' => 'تعداد اطلاعیه ها جهت نمایش را وارد کنید..',
            'type' => 'text',
            'default' => '3'
        ),
        array(
            'id' => 'section_01_0101',
            'title' => 'تنظیمات پنل کاربری نسخه یک',
            'type' => 'section',
            'indent' => true,
            'required' => array('user_panel_style', '=', 'dashboard/user/dashboard-v1'),
        ),
        array(
            'id' => 'show_support_phone',
            'title' => 'نمایش شماره تماس پشتیبانی ',
            'subtitle' => 'فعال یا غیرفعال سازی شماره تماس پشتیبانی در هدر پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'supp_phone',
            'title' => 'شماره تماس پشتیبانی',
            'subtitle' => 'شماره تماس پشتیبانی هدر پنل کاربری را وارد کنید..',
            'type' => 'text',
            'required' => array('show_support_phone', '=', 'inherit'),
            'default' => '5652-021',
        ),
        array(
            'id' => 'show_deposit',
            'title' => 'نمایش موجودی کاربر',
            'subtitle' => 'فعال یا غیرفعال سازی موجودی کاربر در هدر پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'section_01_01',
            'title' => 'تنظیمات پنل های اصلی پنل کاربری نسخه دو',
            'type' => 'section',
            'indent' => true,
            'required' => array('user_panel_style', '=', 'dashboard/user/dashboard-v2'),
        ),
        array(
            'id' => 'telegram_box_panel',
            'title' => 'نمایش لینک باکس اول شبکه های اجتماعی',
            'subtitle' => 'نمایش / مخفی سازی لینک باکس اول شبکه های اجتماعی در پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'social_01_icon',
            'title' => 'آیکون باکس شبکه اجتماعی اول',
            'required' => array('telegram_box_panel', '=', 'inherit'),
            'subtitle' => 'آیکون باکس شبکه اجتماعی اول را وارد کنید.. تمامی ایکون های Font Awesome پشتیبانی می شود. بصورت fal fa-send وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-send',
        ),
        array(
            'id' => 'telegram_panel',
            'required' => array('telegram_box_panel', '=', 'inherit'),
            'title' => 'لینک باکس شبکه اجتماعی اول',
            'subtitle' => 'لینک باکس شبکه اجتماعی اول را وارد کنید..',
            'type' => 'text',
            'default' => 'https://telegram.me/hamkarwp'
        ),
        array(
            'id' => 'head_telegram_panel',
            'required' => array('telegram_box_panel', '=', 'inherit'),
            'title' => 'عنوان باکس شبکه اجتماعی اول',
            'subtitle' => 'عنوان باکس شبکه اجتماعی اول را وارد کنید..',
            'type' => 'text',
            'default' => 'کانال تلگرام وب سایت'
        ),
        array(
            'id' => 'subtitle_telegram_panel',
            'required' => array('telegram_box_panel', '=', 'inherit'),
            'title' => 'زیر عنوان باکس شبکه اجتماعی اول',
            'subtitle' => 'زیر عنوان باکس شبکه اجتماعی اول را وارد کنید..',
            'type' => 'text',
            'default' => 'با عضویت در کانال تلگرام ما همیشه بروز باشید.'
        ),
        array(
            'id' => 'social_01_icon_bg',
            'title' => 'رنگ پس زمینه باکس شبکه اجتماعی اول',
            'required' => array('telegram_box_panel', '=', 'inherit'),
            'subtitle' => 'رنگ پس زمینه باکس شبکه اجتماعی اول را وارد کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#2196F3',)
        ),
        array(
            'id' => 'instagram_box_panel',
            'title' => 'نمایش لینک باکس دوم شبکه های اجتماعی',
            'subtitle' => 'نمایش / مخفی سازی لینک باکس دوم شبکه های اجتماعی در پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'social_02_icon',
            'title' => 'آیکون باکس شبکه اجتماعی دوم ',
            'required' => array('instagram_box_panel', '=', 'inherit'),
            'subtitle' => 'آیکون باکس شبکه اجتماعی دوم را وارد کنید.. تمامی ایکون های Font Awesome پشتیبانی می شود. بصورت fal fa-send وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-instagram'
        ),
        array(
            'id' => 'instagram_panel',
            'required' => array('instagram_box_panel', '=', 'inherit'),
            'title' => 'لینک باکس  شبکه اجتماعی دوم',
            'subtitle' => 'لینک باکس را وارد کنید..',
            'type' => 'text',
            'default' => 'http://instagram.com/hamakrwpcom'
        ),
        array(
            'id' => 'head_instagram_panel',
            'required' => array('instagram_box_panel', '=', 'inherit'),
            'title' => 'عنوان باکس  شبکه اجتماعی دوم',
            'subtitle' => 'عنوان باکس را وارد کنید..',
            'type' => 'text',
            'default' => 'صفحه اینستاگرام ما'
        ),
        array(
            'id' => 'subtitle_instagram_panel',
            'required' => array('instagram_box_panel', '=', 'inherit'),
            'title' => 'زیر عنوان باکس شبکه اجتماعی دوم',
            'subtitle' => 'زیر عنوان باکس اینستاگرام را وارد کنید..',
            'type' => 'text',
            'default' => 'با عضویت در کانال تلگرام ما همیشه بروز باشید.'
        ),
        array(
            'id' => 'social_02_icon_bg',
            'title' => 'رنگ پس زمینه باکس شبکه اجتماعی دوم',
            'required' => array('instagram_box_panel', '=', 'inherit'),
            'subtitle' => 'رنگ پس زمینه باکس شبکه اجتماعی دوم را وارد کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#7232bd',)
        ),
        array(
            'id' => 'blog_box_active',
            'title' => 'نمایش باکس آخرین مطالب در پنل کاربری',
            'subtitle' => 'مشخص کنید که آیا میخواهید باکس آخرین مطالب در پنل کاربری نمایش داده شود؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'blog_title_panel',
            'required' => array('blog_box_active', '=', 'inherit'),
            'title' => 'عنوان بخش آخرین مطالب',
            'subtitle' => 'عنوان بخش آخرین مطالب را وارد کنید..',
            'type' => 'text',
            'default' => 'آخرین مطالب'
        ),
        array(
            'id' => 'blog_cat_panel',
            'required' => array('blog_box_active', '=', 'inherit'),
            'title' => 'دسته بندی بخش آخرین مطالب',
            'subtitle' => ' دسته بندی مورد نظر که میخواهید مطالب آن دسته بندی به عنوان آخرین مطالب در این بخش نمایش داده شود را وارد کنید..',
            'type' => 'select',
            'data' => 'categories',
            'required' => array('blog_box_active', '=', 'inherit'),
            'default' => '1'
        ),
        array(
            'id' => 'blog_count_panel',
            'required' => array('blog_box_active', '=', 'inherit'),
            'title' => 'تعداد مطالب جهت نمایش',
            'subtitle' => 'تعداد مطالب جهت نمایش را وارد کنید..',
            'type' => 'text',
            'default' => '4'
        ),
        array(
            'id' => 'blog_btn_title_panel',
            'required' => array('blog_box_active', '=', 'inherit'),
            'title' => 'متن دکمه مطالب بیشتر',
            'subtitle' => 'متن دکمه مطالب بیشتر بخش آخرین مطالب را وارد کنید..',
            'type' => 'text',
            'default' => 'مشاهده مطالب بیشتر'
        ),
        array(
            'id' => 'blog_btn_link_panel',
            'required' => array('blog_box_active', '=', 'inherit'),
            'title' => 'لینک دکمه مطالب بیشتر',
            'subtitle' => 'لینک دکمه مطالب بیشتر بخش آخرین مطالب را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/blog'
        ),
        array(
            'id' => 'deposit_panel_active',
            'title' => 'نمایش باکس موجودی در پنل کاربری',
            'subtitle' => 'مشخص کنید که آیا میخواهید باکس موجودی در پنل کاربری نمایش داده شود؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'deposit_panel_title',
            'title' => 'عنوان باکس موجودی پنل کاربری',
            'required' => array('deposit_panel_active', '=', 'inherit'),
            'subtitle' => 'عنوان باکس موجودی پنل کاربری را اینجا میتوانید تغییر دهید!',
            'type' => 'text',
            'default' => 'موجودی شما :'
        ),
        array(
            'id' => 'deposit_panel_link',
            'required' => array('deposit_panel_active', '=', 'inherit'),
            'title' => 'لینک شارژ حساب پنل موجودی',
            'subtitle' => 'لینک شارژ حساب بخش موجودی حساب را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/echarge'
        ),
        array(
            'id' => 'deposit_panel_icon',
            'title' => 'آیکون باکس موجودی پنل کاربری ',
            'required' => array('deposit_panel_active', '=', 'inherit'),
            'subtitle' => 'آیکون باکس موجودی پنل کاربری را وارد کنید.. تمامی ایکون های Font Awesome پشتیبانی می شود. بصورت fal fa-send وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-money'
        ),
        array(
            'id' => 'deposit_panel_bg',
            'title' => 'رنگ پس زمینه باکس موجودی پنل کاربری',
            'required' => array('deposit_panel_active', '=', 'inherit'),
            'subtitle' => 'رنگ پس زمینه باکس موجودی پنل کاربری را انتخاب کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#428bca',)
        ),
        array(
            'id' => 'section_01_01_panel',
            'title' => 'تنظیمات هدر پنل کاربری دو',
            'type' => 'section',
            'indent' => true,
            'required' => array('user_panel_style', '=', 'dashboard/user/dashboard-v2'),
        ),
        array(
            'id' => 'panel_box_top_menu',
            'title' => 'نمایش منوی دسترسی سریع در هدر پنل کاربران',
            'subtitle' => 'مشخص کنید که آیا میخواهید منوی دسترسی سریع در هدر در پنل کاربری نمایش داده شود؟',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'menu_panel_01_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره یک',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-support'
        ),
        array(
            'id' => 'menu_panel_01_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره یک',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'ارسال تیکت'
        ),
        array(
            'id' => 'menu_panel_01_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره یک',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/submit-ticket'
        ),
        array(
            'id' => 'menu_panel_02_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره دو',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-money'
        ),
        array(
            'id' => 'menu_panel_02_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره دو',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'شارژ حساب '
        ),
        array(
            'id' => 'menu_panel_02_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره دو',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/echarge'
        ),
        array(
            'id' => 'menu_panel_03_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره سه',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-shopping-cart'
        ),
        array(
            'id' => 'menu_panel_03_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره سه',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'خرید های من'
        ),
        array(
            'id' => 'menu_panel_03_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره سه',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/my-account/downloads'
        ),
        array(
            'id' => 'menu_panel_04_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره چهار',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-users'
        ),
        array(
            'id' => 'menu_panel_04_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره چهار',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'بازاریابی '
        ),
        array(
            'id' => 'menu_panel_04_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره چهار',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/affiliate-dashboard'
        ),
        array(
            'id' => 'menu_panel_05_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره پنج',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-paypal'
        ),
        array(
            'id' => 'menu_panel_05_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره پنج',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'پرداخت آنلاین'
        ),
        array(
            'id' => 'menu_panel_05_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره پنج',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/payment'
        ),
        array(
            'id' => 'menu_panel_06_icon',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'آیکون منوی شماره شش',
            'subtitle' => 'کد آیکون مورد نظر را جهت نمایش از آدرس https://fontawesome.com/v4.7.0/icons/ دریافت کرده و وارد کنید..',
            'type' => 'text',
            'default' => 'fal fa-heart'
        ),
        array(
            'id' => 'menu_panel_06_title',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'عنوان منوی شماره شش',
            'subtitle' => 'عنوان مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'default' => 'علاقه مندی ها'
        ),
        array(
            'id' => 'menu_panel_06_link',
            'required' => array('panel_box_top_menu', '=', 'inherit'),
            'title' => 'لینک منوی شماره شش',
            'subtitle' => 'لینک صفحه مورد نظر را جهت نمایش وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/favorits'
        ),
        array(
            'id' => 'search_v2_show',
            'title' => 'نمایش فرم جستجو در هدر پنل کاربری',
            'subtitle' => 'نمایش / مخفی سازی نمایش فرم جستجو در هدر پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'cart_v2_show',
            'title' => 'نمایش سبد خرید در هدر پنل کاربری',
            'subtitle' => 'نمایش / مخفی سازی سبد خرید در هدر پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'panel_menu_v2_show',
            'title' => 'نمایش منوی کابری ',
            'subtitle' => 'نمایش بخش منوی کاربران در سمت چپ هدر پنل کاربری',
            'type' => 'button_set',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
    ),

));


Redux::setSection($opt_name, array(
    'title' => ' منوی اصلی ',
    'subsection' => true,
    'class' => 'dnone_v5',
    'id' => 'menu_setting_main',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'megamenu_info',
            'type' => 'info',
            'desc' => __('برای آشنایی با نحوه ساخت مگامنو ', 'redux-framework-demo') . '<a href="http://doc.hamkarwp.com/sigma/faq-sigma/how-create-mega-menu-sigma/" target="_blank">این آموزش را بخوانید!</a>',
        ),
        array(
            'id' => 'section_main_menu',
            'title' => 'تنظیمات منوی اصلی',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'menu_item_color_v1',
            'title' => 'رنگ آیتم های اصلی منو ( هدر یک )',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'menu_item_color_v23',
            'title' => 'رنگ آیتم های اصلی منو ( هدر دو و سه )',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#d2d2d2'
        ),
        array(
            'id' => 'menu_bg',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
            'title' => 'رنگ پس زمینه زیرمنوها ',
            'subtitle' => 'این رنگ برای زیرمنوهای آبشاری و پس زمینه مگامنوها اعمال میشود.',
        ),
        array(
            'id' => 'menu_item_color',
            'title' => 'رنگ آیتم های زیرمنوی منو اصلی',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'megamenu_bg',
            'required' => array('home_v3_start_active', '=', 'inherit'),
            'title' => 'تصویر پس زمینه مگامنو',
            'subtitle' => 'از این قسمت می توانید" تصویر پس زمینه مگامنو سایت " را تغییر دهید.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-color' => false,
            'background-attachment' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/mega_menu_bg.jpg'
            )
        ),
        array(
            'id' => 'menu_item_color_hover',
            'title' => 'رنگ هوور پس زمینه زیرمنوها',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f9f9f9'),
        ),
        array(
            'id' => 'title_cloumn_color',
            'title' => 'رنگ عناوین ستون های مگامنو',
            'subtitle' => 'این رنگ تنها برای عناوین ستون های مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'title_cloumn_border',
            'title' => 'رنگ حاشیه بالای آیتم های زیرمنو',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#399bff'
        ),
    ),
));
Redux::setSection($opt_name, array(
    'title' => ' منوی تاپ بار ',
    'class' => 'dnone_v5',
    'subsection' => true,
    'id' => 'menu_setting_top',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'topbar_menu_item_color_v1',
            'title' => 'رنگ آیتم های تاپ منو ( هدر یک )',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'topbar_menu_item_color_v23',
            'title' => 'رنگ آیتم های تاپ منو ( هدر دو و سه )',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری و مگامنو اعمال میشود!',
            'type' => 'color',
            'default' => '#d2d2d2'
        ),
        array(
            'id' => 'menu_bg_topbar',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
            'title' => 'رنگ پس زمینه زیرمنوهای تاپ منو ',
            'subtitle' => 'این رنگ برای زیرمنوهای آبشاری تاپ منو اعمال میشود.',
        ),
        array(
            'id' => 'menu_item_color_topbar',
            'title' => 'رنگ آیتم های زیرمنوی تاپ منو',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری اعمال میشود!',
            'type' => 'color',
            'default' => '#555555'
        ),
        array(
            'id' => 'menu_item_color_hover_topbar',
            'title' => 'رنگ هوور پس زمینه زیرمنوها',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری اعمال میشود!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f9f9f9'),
        ),
        array(
            'id' => 'title_cloumn_border_topbar',
            'title' => 'رنگ حاشیه بالای آیتم های زیرمنو',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری اعمال میشود!',
            'type' => 'color',
            'default' => '#399bff'
        ),
    ),
));
Redux::setSection($opt_name, array(
    'title' => ' منوی کاربران  ',
    'subsection' => true,
    'class' => 'dnone_v5',    
    'id' => 'menu_setting_user',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_main_user',
            'title' => 'تنظیمات منوی کاربران ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'menu_bg_user',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
            'title' => 'رنگ پس زمینه منوی کاربران',
            'subtitle' => 'این رنگ برای زیرمنو یا آیتم های منوی کاربران هدر سایت اعمال میشود.',
        ),
        array(
            'id' => 'menu_item_color_hover_topbar',
            'title' => 'رنگ هوور پس زمینه منوی کاربران',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی آبشاری اعمال میشود!',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#f9f9f9'),
        ),
        array(
            'id' => 'menu_item_color_user',
            'title' => 'رنگ آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی کاربران اعمال میشود!',
            'type' => 'color',
            'default' => '#555555'
        ),
        array(
            'id' => 'title_cloumn_border_user',
            'title' => 'رنگ حاشیه میانی آیتم های زیرمنوی کاربران',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی کاربران اعمال میشود!',
            'type' => 'color',
            'default' => '#f5f5f5'
        ),
        array(
            'id' => 'user_menu_icon_color',
            'title' => 'رنگ آیکون های آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی کاربران اعمال میشود!',
            'type' => 'color',
            'default' => '#888888'
        ),
    ),
));

Redux::setSection($opt_name, array(
    'title' => ' استایل پنل کاربران  ',
    'subsection' => true,
    'id' => 'menu_setting_panel',
    'customizer_width' => '400px',
    'fields' => array(
        array(
            'id' => 'section_main_panel',
            'title' => 'تنظیمات منوی پنل کاربران',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'select_panel_menu',
            'type' => 'button_set',
            'default' => 'v1',
            'title' => 'انتخاب نوع پنل کاربران',
            'options' => array(
                'v1' => 'تنظیمات پنل کاربران نسخه یک',
                'v2' => 'تنظیمات پنل کاربران نسخه دو',
            ),
        ),
        array(
            'id' => 'user_menu_v1_bg',
            'required' => array('select_panel_menu', '=', 'v1'),
            'title' => 'رنگ پس زمینه آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک روشن یا سبک شماره یک اعمال خواهد شد.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
        ),
        array(
            'id' => 'user_menu_v1_title',
            'title' => 'رنگ آیتم های منوی پنل کاربران',
            'required' => array('select_panel_menu', '=', 'v1'),
            'subtitle' => 'این رنگ برای  پنل کاربران سبک روشن یا سبک شماره یک اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'user_menu_v1_icon',
            'required' => array('select_panel_menu', '=', 'v1'),
            'title' => 'رنگ آیکون آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک روشن یا سبک شماره یک اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'panel_bg_header',
            'type' => 'background',
            'required' => array('select_panel_menu', '=', 'v2'),
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
            'title' => 'رنگ پس زمینه هدینگ پنل کاربری نسخه تیره',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
        ),
        array(
            'id' => 'menu_user_panel_bg_header',
            'type' => 'background',
            'required' => array('select_panel_menu', '=', 'v2'),
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#07080b'),
            'title' => 'رنگ پس زمینه هدینگ منوی پنل کاربری نسخه تیره',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
        ),
        array(
            'id' => 'menu_user_panel_bg',
            'required' => array('select_panel_menu', '=', 'v2'),
            'title' => 'رنگ پس زمینه منوی پنل کاربران استایل تیره',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#12131a'),
        ),
        array(
            'id' => 'menu_item_color_user_panel',
            'title' => 'رنگ آیتم های منوی پنل کاربران',
            'required' => array('select_panel_menu', '=', 'v2'),
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#8287a9'
        ),
        array(
            'id' => 'menu_user_panel_item_hover',
            'required' => array('select_panel_menu', '=', 'v2'),
            'title' => 'رنگ پس زمینه هوور آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#1dc499'),
        ),
        array(
            'id' => 'menu_user_panel_item_color_hover',
            'required' => array('select_panel_menu', '=', 'v2'),
            'title' => 'رنگ هوور آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#ffffff'
        ),
        array(
            'id' => 'user_panel_title_color',
            'required' => array('select_panel_menu', '=', 'v2'),
            'title' => 'رنگ عناوین منوهای پنل کاربران',
            'subtitle' => 'این رنگ برای  پنل کاربران سبک تیره یا سبک شماره دو اعمال خواهد شد.',
            'type' => 'color',
            'default' => '#515574'
        ),
        array(
            'id' => 'user_panel_icon_color',
            'required' => array('select_panel_menu', '=', 'v2'),
            'title' => 'رنگ آیکون های منوهای پنل کاربران',
            'subtitle' => 'این رنگ برای آیکون های منوی های پایین مانند دسترسی سریع و... اعمال خواهد شد!',
            'type' => 'color',
            'default' => '#1ccacc'
        ),
    ),
));
// -> START Social Setting

Redux::setSection($opt_name, array(
    'title' => ' تنظیمات نسخه موبایل  ',
    'id' => 'menu_setting_mobile',
    'customizer_width' => '400px',
    'icon' => 'el el-iphone-home',
    'fields' => array(
        array(
            'id' => 'menu_section_mobile',
            'title' => 'تنظیمات منوی موبایل ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'logo_mobile',
            'title' => 'لوگوی نسخه موبایل',
            'subtitle' => 'با توجه به ساختار منوی موبایل حتما از آیکون خود برای نسخه موبایل استفاده کنید. اندازه پیشنهادی 50*50 میباشد.',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/favicon-v2.png'),
        ),
        array(
            'id' => 'mobile_login_page',
            'title' => 'برگه دکمه ورود و عضویت نسخه موبایل',
            'type' => 'select',
            'data' => 'pages',
            'default' => '' . get_site_url() . '/?p=1771',
            'subtitle' => 'از این بخش می توانید برگه دکمه عضویت را وارد کنید..',
        ),
        array(
            'id' => 'userarea_mobile',
            'title' => 'ناحیه ورود کاربر موبایل',
            'type' => 'button_set',
            'default' => 'enable',
            'subtitle' => 'این بخش میتوانید بخش ورود و پروفایل کاربر در نسخه موبایل را فعال یا غیرفعال کنید.',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),          
        array(
            'id' => 'cart_icon_mobile',
            'title' => 'آیکون سبد خرید موبایل',
            'type' => 'button_set',
            'default' => 'enable',
            'subtitle' => 'این بخش میتوانید آیکون سبد خرید نسخه موبایل را فعال یا غیرفعال کنید.',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),  
        array(
            'id' => 'wishlist_icon_mobile',
            'title' => 'آیکون علاقه مندی موبایل',
            'type' => 'button_set',
            'default' => 'enable',
            'subtitle' => 'این بخش میتوانید آیکون علاقه مندی نسخه موبایل را فعال یا غیرفعال کنید.',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'search_icon_mobile',
            'title' => 'آیکون جستجو موبایل',
            'type' => 'button_set',
            'default' => 'enable',
            'subtitle' => 'این بخش میتوانید آیکون جستجو نسخه موبایل را فعال یا غیرفعال کنید.',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),   
        array(
            'id' => 'add_cart_mobile',
            'title' => 'سبد خرید چسبان نسخه موبایل تک محصول',
            'subtitle' => 'از این قسمت میتوانید سبد خرید چسبان نسخه موبایل تک محصول را فعال یا غیرفعال کنید.',
            'type' => 'button_set',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),         
        array(
            'id' => 'popup_options_active_mobile',
            'type' => 'button_set',
            'title' => 'پاپ آپ خبرنامه در موبایل',
            'subtitle' => 'از این بخش میتوانید پاپ آپ خبرنامه در نسخه ریسپانسیو را مدیریت کنید.!',
            'default' => 'none',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),    
        array(
            'id' => 'socials_box_mobile',
            'type' => 'button_set',
            'title' => 'نمایش دکمه آیکون های اجتماعی ثابت در نسخه ریسپانسیو',
            'subtitle' => 'از این بخش میتوانید آیکون ثابت سمت چپ سایت در نسخه ریسپانسیو را مدیریت کنید.! لینک هر کدام از این آیکون ها از قسمت تنظیمات شبکه های اجتماعی تغییر پیدا میکند.',
            'default' => 'none',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'social_active_mobile',
            'type' => 'button_set',
            'title' => 'آیکون های شبکه اجتماعی در موبایل',
            'subtitle' => 'از این بخش میتوانید آیکون های شبکه اجتماعی در موبایل را مدیریت کنید.!',
            'default' => 'enable',
            'options' => array(
                'enable' => 'فعال',
                'disable' => 'غیرفعال',
            ),
        ),            
        array(
            'id' => 'cart_active_mobile',
            'type' => 'button_set',
            'title' => 'آیکون سبد خرید در موبایل',
            'subtitle' => 'از این بخش میتوانید آیکون ثابت سبد خرید در موبایل را مدیریت کنید.!',
            'default' => 'inherit',
            'options' => array(
                'inherit' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),        
        array(
            'id' => 'mobilemenu_header_bg',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'background-color' => '#ffffff'),
            'title' => 'رنگ پس زمینه هدینگ منوی موبایل',
            'subtitle' => 'این رنگ برای بخش بالای منوی موبایل اعمال خواهد شد!',
        ),
        array(
            'id' => 'mobilemenu_header_title',
            'title' => 'رنگ متن خوش آمدگویی',
            'subtitle' => 'این رنگ برای متن خوش آمدگویی اعمال میشود!',
            'type' => 'color',
            'default' => '#8C8B8B'
        ),
        array(
            'id' => 'mobilemenu_header_btn',
            'title' => 'رنگ دکمه هدر منوی موبایل',
            'subtitle' => 'این دکمه در هنگام عدم ورود با عنوان ورود یا عضویت و پس از ورود به عنوان پنل کاربران نمایش داده میشود.',
            'type' => 'color',
            'default' => '#ff7f68'
        ),
        array(
            'id' => 'mobilemenu_bg',
            'type' => 'color_gradient',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'background-image' => false,
            'default' => array(
                'from' => '#ed5565',
                'to' => '#ed7f5d',
            ),
            'title' => 'رنگ پس زمینه بدنه منوی موبایل',
            'subtitle' => 'این رنگ برای بخش اصلی آیتم های منوی موبایل اعمال خواهد شد!',
        ),
        array(
            'id' => 'mobilemenu_iteme',
            'title' => 'رنگ آیتم های منوی کاربران',
            'subtitle' => 'این رنگ برای تمای آیتم های منوی کاربران اعمال میشود!',
            'type' => 'color',
            'default' => '#ffffff'
        ),
    ),
));



Redux::setSection($opt_name, array(
    'title' => ' شبکه های اجتماعی ',
    'id' => 'social_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-share',
    'class' => 'dnone_v5',
    'fields' => array(
        array(
            'id' => 'section_menu_social',
            'title' => 'تنظیمات شبکه های اجتماعی  ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => 'heaader_v1_0012',
            'title' => 'نمایش باکس شبکه های اجتماعی در هدر ',
            'subtitle' => 'با غیرفعال سازی این بخش نمایش تمامی آیکون های شبکه های اجتماعی در سایت غیرفعال میگردد.',
            'type' => 'button_set',
            'default' => 'block',
            'class' => 'dnone_v5',
            'options' => array(
                'block' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0013',
            'title' => 'فعال سازی نمایش آیکون یوتیوب در سایت',
            'required' => array('heaader_v1_0012', '=', 'block'),
            'subtitle' => 'از این بخش می توانید آیکون یوتیوب را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0014',
            'title' => 'فعال سازی نمایش آیکون اینستاگرام در سایت',
            'required' => array('heaader_v1_0012', '=', 'block'),
            'subtitle' => 'از این بخش می توانید آیکون اینستاگرام را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0015',
            'title' => 'فعال سازی نمایش آیکون فیسبوک در سایت',
            'required' => array('heaader_v1_0012', '=', 'block'),
            'subtitle' => 'از این بخش می توانید آیکون فیسبوک را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0016',
            'required' => array('heaader_v1_0012', '=', 'block'),
            'title' => 'فعال سازی نمایش آیکون تلگرام در سایت',
            'subtitle' => 'از این بخش می توانید آیکون تلگرام را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'default' => 'inline',
            'class' => 'dnone_v5',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
        array(
            'id' => 'heaader_v1_0017',
            'required' => array('heaader_v1_0012', '=', 'block'),
            'title' => 'فعال سازی نمایش آیکون توییتر در سایت',
            'subtitle' => 'از این بخش می توانید آیکون توییتر را نمایش یا پنهان کنید.',
            'type' => 'button_set',
            'class' => 'dnone_v5',
            'default' => 'inline',
            'options' => array(
                'inline' => 'فعال',
                'none' => 'غیرفعال',
            ),
        ),
    )
));
// -> START 404 Setting
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات صفحه 404',
    'id' => '404_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-remove',
    'fields' => array(
        array(
            'id' => 'section_menu_404',
            'title' => 'تنظیمات صفحه 404 ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => '404_bg',
            'title' => 'اعمال تصویر یا رنگ برای پس زمینه صفحه 404',
            'subtitle' => 'تصویر یا رنگ برای پس زمینه صفحه 404 را انتخاب کنید..',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-attachment' => false,
            'default' => array(
                'background-color' => '#24344c',
                'background-image' => '' . get_template_directory_uri() . ''),
        ),
        array(
            'id' => '404_title',
            'title' => 'عنوان صفحه 404',
            'subtitle' => 'عنوان صفحه 404 را وارد کنید..',
            'type' => 'text',
            'default' => '404'
        ),
        array(
            'id' => '404_subtitle',
            'title' => 'زیر عنوان صفحه 404',
            'subtitle' => 'زیر عنوان صفحه 404 را وارد کنید..',
            'type' => 'text',
            'default' => 'صفحه ای که شما دنبال آن میگردید ، وجود ندارد!'
        ),
        array(
            'id' => '404_btn_link',
            'title' => 'لینک دکمه بازگشت به صفحه اصلی',
            'subtitle' => 'لینک دکمه بازگشت به صفحه اصلی صفحه 404 را وارد کنید..',
            'type' => 'text',
            'validate' => 'url',
            'default' => '' . get_site_url() . '/'
        ),
        array(
            'id' => '404_btn_title',
            'title' => 'عنوان دکمه بازگشت به صفحه اصلی',
            'subtitle' => 'عنوان دکمه بازگشت به صفحه اصلی صفحه 404 را وارد کنید..',
            'type' => 'text',
            'default' => 'بازگشت به صفحه اصلی'
        ),
    )
));
// -> START Cooming Soon Setting
        /*
Redux::setSection($opt_name, array(
    'title' => 'تنظیمات صفحه به زودی',
    'id' => '403_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-phone-alt',
    'fields' => array(
        array(
            'id' => '403_info',
            'type' => 'info',
            'desc' => __('برای آشنایی با نحوه فعال سازی حالت تعمیر و نگهداری ', 'redux-framework-demo') . '<a href="http://doc.hamkarwp.com/sigma/faq-sigma/how-enable-maintenance-site/" target="_blank">این آموزش را بخوانید!</a>',
        ),  
        array(
            'id' => 'error-v5_10',
            'type' => 'info',
            'notice' => false,
            'class' => 'error_v5',
            'icon' => 'el el-info-circle',
            'subtitle' => '<div class="alert-v5"><i class="el el-remove-circle"></i><h4>توجه!</h4><p>تنظیمات این بخش در نسخه جدید منسوخ شده است. شما میتوانید هدر ، فوتر و دموی سفارشی خود را با استفاده از المان های اختصاصی سیگما پلاس و در المنتور پیاده سازی کنید.</p><a href="http://doc.hamkarwp.com/sigma/faq-sigma/training-video-works-with-the-new-features-of-sigma-plus/" target="_blank">مشاهده فیلم آموزشی کار با نسخه جدید سیگما</a></div>',
            'required' => array('homepages_style_page', '=', 'template-part/content/home/home-v1'),
        ),        
        array(
            'id' => 'section_menu_403',
            'title' => 'تنظیمات صفحه به زودی ',
            'type' => 'section',
            'indent' => true,
        ),
        array(
            'id' => '403_bg_page',
            'title' => 'تصویر پس زمینه صفحه به زودی',
            'type' => 'background',
            'background-repeat' => false,
            'background-position' => false,
            'background-size' => false,
            'background-color' => false,
            'background-attachment' => false,
            'default' => array(
                'background-image' => '' . get_template_directory_uri() . '/assets/img/maintenance_bg.png'
            )
        ),
        array(
            'id' => 'logo_403',
            'title' => 'لوگو یا آیکون بالای صفحه را مشخص کنید.!',
            'type' => 'media',
            'url' => true,
            'compiler' => 'true',
            'default' => array('url' => '' . get_template_directory_uri() . '/assets/img/icon-light.png'),
        ),
        array(
            'id' => 'title_403_page',
            'title' => 'عنوان صفحه',
            'type' => 'text',
            'default' => 'ما در حال راه اندازی نسخه جدید سایت هستیم!'
        ),
        array(
            'id' => 'sub_title_403_page',
            'title' => 'زیر عنوان صفحه',
            'type' => 'text',
            'default' => 'به زودی با کلی امکانات در دسترس شما خواهیم بود. از شکیبانی شما متشکریم.'
        ),
        array(
            'id' => 'title_contact_403_page',
            'title' => 'عنوان مشخصات تماس',
            'type' => 'text',
            'default' => 'راه های ارتباط با ما :'
        ),
        array(
            'id' => 'phone_403_page',
            'title' => 'شماره تماس',
            'type' => 'text',
            'default' => '02185689555'
        ),
        array(
            'id' => 'email_403_page',
            'title' => 'آدرس ایمیل',
            'type' => 'text',
            'default' => 'info@hamkarwp.com'
        ),
        array(
            'id' => 'btn_title_403_page',
            'title' => 'متن دکمه تماس با ما',
            'type' => 'text',
            'default' => 'فرم تماس با ما با مواقع ضروری'
        ),
        array(
            'id' => 'title_modal_403_page',
            'title' => 'عنوان پاپ آپ تماس',
            'type' => 'text',
            'default' => 'ارتباط با ما'
        ),
        array(
            'id' => 'dec_modal_403_page',
            'title' => 'توضیحات پاپ آپ تماس',
            'type' => 'textarea',
            'default' => 'لطفا تا زمان راه اندازی سایت درخواست خود را از طریق این فرم به ما ارسال کنید ، در کوتاه ترین زمان ممکن پاسخگوی شما عزیزان خواهیم بود.'
        ),
    
    ),
));
    */
// -> START Custom Code Setting
Redux::setSection($opt_name, array(
    'title' => 'کدهای سفارشی',
    'id' => 'custom_code_setting',
    'customizer_width' => '400px',
    'icon' => 'el el-css',
    'fields' => array(
        array(
            'id' => 'section_menu_code',
            'title' => 'کدهای سفارشی',
            'type' => 'section',
            'indent' => true,
        ),

        array(
            'id' => 'custom_css',
            'type' => 'ace_editor',
            'title' => 'کدهای سفارشی css',
            'subtitle' => 'هرگونه کد css سفارشی برای سیگما را در این باکس وارد کنید. تا تغییرات را سریع تر از همه جا در سایت خود اعمال کنید..',
            'mode' => 'css',
            'theme' => 'monokai',
        ),
        array(
            'id' => 'custom_js',
            'type' => 'ace_editor',
            'title' => 'کدهای سفارشی js',
            'subtitle' => 'هرگونه کد js سفارشی برای سیگما را در این باکس وارد کنید. تا تغییرات را سریع تر از همه جا در سایت خود اعمال کنید..',
            'mode' => 'javascript',
            'theme' => 'monokai',
        ),
    )

));


/*
		 * <--- END SECTIONS
		 */


/*
		 *
		 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
		 *
		 */

/*
		*
		* --> Action hook examples
		*
		*/

// If Redux is running as a plugin, this will remove the demo notice and links
//add_action( 'redux/loaded', 'remove_demo' );

// Function to test the compiler hook and demo CSS output.
// Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
//add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

// Change the arguments after they've been declared, but before the panel is created
//add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

// Change the default value of a field after it's been set, but before it's been useds
//add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

// Dynamically add a section. Can be also used to modify sections/fields
//add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
if (!function_exists('compiler_action')) {
    function compiler_action($options, $css, $changed_values)
    {
        echo '<h1>The compiler hook has run!</h1>';
        echo "<pre>";
        print_r($changed_values); // Values that have changed since the last save
        echo "</pre>";
        //print_r($options); //Option values
        //print_r($css); // Compiler button_setor CSS values  compiler => array( CSS button_setORS )
    }
}

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')) {
    function redux_validate_callback_function($field, $value, $existing_value)
    {
        $error = false;
        $warning = false;

        //do your validation
        if ($value == 1) {
            $error = true;
            $value = $existing_value;
        } elseif ($value == 2) {
            $warning = true;
            $value = $existing_value;
        }

        $return['value'] = $value;

        if ($error == true) {
            $field['msg'] = 'your custom error message';
            $return['error'] = $field;
        }

        if ($warning == true) {
            $field['msg'] = 'your custom warning message';
            $return['warning'] = $field;
        }

        return $return;
    }
}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')) {
    function redux_my_custom_field($field, $value)
    {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if (!function_exists('dynamic_section')) {
    function dynamic_section($sections)
    {
        //$sections = array();
        $sections[] = array(
            'title' => __('Section via hook', 'redux-framework-demo'),
            'subtitle' => __('<p class="subtitleription">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo'),
            'icon' => 'el el-paper-clip',
            // Leave this as a blank section, no options just some intro text set above.
            'fields' => array()
        );

        return $sections;
    }
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if (!function_exists('change_arguments')) {
    function change_arguments($args)
    {
        //$args['dev_mode'] = false;

        return $args;
    }
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if (!function_exists('change_defaults')) {
    function change_defaults($defaults)
    {
        $defaults['str_replace'] = 'Testing filter hook!';

        return $defaults;
    }
}

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if (!function_exists('remove_demo')) {
    function remove_demo()
    {
        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if (class_exists('ReduxFrameworkPlugin')) {
            remove_filter('plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2);

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
        }
    }
}

